@@ -22,62 +22,61 @@
  *
  * HUBzero is a registered trademark of Purdue University.
  *
- * @package		hubzero-cms
- * @author		Shawn Rice <zooley@purdue.edu>
+ * @package   hubzero-cms
+ * @author    Shawn Rice <zooley@purdue.edu>
  * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
- * @license		http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
+ * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  */
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Controller class for citations
  */
-class CitationsControllerCitations extends \Hubzero\Component\AdminController
+class CitationsControllerCitations extends Hubzero_Controller
 {
 	/**
 	 * List citations
-	 *
-	 * @return		 void
+	 * 
+	 * @return     void
 	 */
 	public function displayTask()
 	{
 		// Get configuration
 		$config = JFactory::getConfig();
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 
 		$this->view->filters = array();
 
 		// Get paging variables
-		$this->view->filters['limit']	 = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.limit',
-			'limit',
-			$config->getValue('config.list_limit'),
+		$this->view->filters['limit']    = $app->getUserStateFromRequest(
+			$this->_option . '.' . $this->_controller . '.limit', 
+			'limit', 
+			$config->getValue('config.list_limit'), 
 			'int'
 		);
-		$this->view->filters['start']	 = $app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.limitstart',
-			'limitstart',
-			0,
+		$this->view->filters['start']    = $app->getUserStateFromRequest(
+			$this->_option . '.' . $this->_controller . '.limitstart', 
+			'limitstart', 
+			0, 
 			'int'
 		);
 
 		// Get filters
-		$this->view->filters['sort']	 = trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.sort',
-			'sort',
+		$this->view->filters['sort']     = trim($app->getUserStateFromRequest(
+			$this->_option . '.' . $this->_controller . '.sort', 
+			'sort', 
 			'created DESC'
 		));
-		$this->view->filters['search']		 = urldecode(trim($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.search',
-			'search',
+		$this->view->filters['search']     = urldecode(trim($app->getUserStateFromRequest(
+			$this->_option . '.' . $this->_controller . '.search', 
+			'search', 
 			''
 		)));
 
-		// add published filter
-		$this->view->filters['published'] = array(0,1);
-
 		$obj = new CitationsCitation($this->database);
 
 		// Get a record count
@@ -89,8 +88,8 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		// Initiate paging
 		jimport('joomla.html.pagination');
 		$this->view->pageNav = new JPagination(
-			$this->view->total,
-			$this->view->filters['start'],
+			$this->view->total, 
+			$this->view->filters['start'], 
 			$this->view->filters['limit']
 		);
 
@@ -99,7 +98,7 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		$this->view->types = $ct->getType();
 
 		// Set any errors
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -113,8 +112,8 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 
 	/**
 	 * Create a new citation
-	 *
-	 * @return		 void
+	 * 
+	 * @return     void
 	 */
 	public function addTask()
 	{
@@ -123,223 +122,107 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 
 	/**
 	 * Edit a citation
-	 *
-	 * @return		 void
+	 * 
+	 * @return     void
 	 */
-	public function editTask()
+	public function editTask($row=null)
 	{
-		//stop menu from working?
 		JRequest::setVar('hidemainmenu', 1);
 
-		//force edit layout
 		$this->view->setLayout('edit');
 
-		//get request vars - expecting an array id[]=4232
-		$id = JRequest::getVar('id', array());
-		if (is_array($id))
+		$this->view->config = $this->config;
+
+		if (is_object($row))
 		{
-			$id = (!empty($id)) ? $id[0] : 0;
+			$this->view->type = $row;
+		}
+		else 
+		{
+			// Incoming - expecting an array id[]=4232
+			$id = JRequest::getVar('id', array());
+			$id = (is_array($id) && !empty($id)) ? $id[0] : 0;
+
+			// Load the object
+			$this->view->row = new CitationsCitation($this->database);
+			$this->view->row->load($id);
 		}
 
 		//get all citations sponsors
 		$cs = new CitationsSponsor($this->database);
 		$this->view->sponsors = $cs->getSponsor();
 
-		//get all citation types
-		$ct = new CitationsType($this->database);
-		$this->view->types = $ct->getType();
+		// Load the associations object
+		$assoc = new CitationsAssociation($this->database);
 
-		//empty citation object
-		$this->view->row = new CitationsCitation($this->database);
-
-		//if we have an id load that citation data
-		if (isset($id) && $id != '' && $id != 0)
+		// No ID, so we're creating a new entry
+		// Set the ID of the creator
+		if (!$this->view->row->id) 
 		{
-			// Load the citation object
-			$this->view->row->load( $id );
-
-			// Get the associations
-			$assoc = new CitationsAssociation($this->database);
-			$this->view->assocs = $assoc->getRecords(array('cid' => $id));
-
-			//get sponsors for citation
-			$this->view->row_sponsors = $cs->getCitationSponsor($this->view->row->id);
-
-			//get the citations tags
-			$this->view->tags = CitationFormat::citationTags($this->view->row, JFactory::getDBO(), false);
-
-			//get the badges
-			$this->view->badges = CitationFormat::citationBadges($this->view->row, JFactory::getDBO(), false);
-
-			//parse citation params
-			$this->view->params = new JRegistry($this->view->row->params);
-		}
-		else
-		{
-			//set the creator
 			$this->view->row->uid = $this->juser->get('id');
 
 			// It's new - no associations to get
 			$this->view->assocs = array();
-
+			
 			//array of sponsors - empty
 			$this->view->row_sponsors = array();
-
-			//empty tags and badges arrays
-			$this->view->tags = array();
-			$this->view->badges = array();
-
-			//empty params object
-			$this->view->params = new JRegistry('');
-		}
-
-		//are we padding back the citation data
-		if (isset($this->row))
+		} 
+		else 
 		{
-			$this->view->row = $this->row;
+			// Get the associations
+			$this->view->assocs = $assoc->getRecords(array('cid' => $id));
+			
+			//get sponsors for citation
+			$this->view->row_sponsors = $cs->getCitationSponsor($this->view->row->id);
 		}
 
-		//are we passing back the tags from edit
-		if ($this->tags != '')
-		{
-			$this->tags = explode(',', $this->tags);
-			foreach ($this->tags as $tag)
-			{
-				$this->view->tags[]['raw_tag'] = $tag;
-			}
-		}
+		//get the citations tags
+		$sql = "SELECT t.*
+				FROM #__tags_object to1 
+				INNER JOIN #__tags t ON t.id = to1.tagid 
+				WHERE to1.tbl='citations' 
+				AND to1.objectid={$id}
+				AND to1.label=''";
+		$this->database->setQuery($sql);
+		$this->view->tags = $this->database->loadAssocList();
 
-		//are we passing back the tags from edit
-		if ($this->badges != '')
-		{
-			$this->badges = explode(',', $this->badges);
-			foreach ($this->badges as $badge)
-			{
-				$this->view->badges[]['raw_tag'] = $badge;
-			}
-		}
+		//get the badges
+		$sql = "SELECT t.*
+				FROM #__tags_object to1 
+				INNER JOIN #__tags t ON t.id = to1.tagid 
+				WHERE to1.tbl='citations' 
+				AND to1.objectid={$id}
+				AND to1.label='badge'";
+		$this->database->setQuery($sql);
+		$this->view->badges = $this->database->loadAssocList();
+
+		$ct = new CitationsType($this->database);
+		$this->view->types = $ct->getType();
 
 		// Set any errors
-		if ($this->getError())
+		if ($this->getError()) 
 		{
-			$this->view->setError($this->getError());
+			foreach ($this->getErrors() as $error)
+			{
+				$this->view->setError($error);
+			}
 		}
 
-		//set vars for view
-		$this->view->config = $this->config;
+		$paramsClass = 'JParameter';
+		if (version_compare(JVERSION, '1.6', 'ge'))
+		{
+			$paramsClass = 'JRegistry';
+		}
+		$this->view->params = new $paramsClass($this->view->row->params);
 
 		// Output the HTML
 		$this->view->display();
 	}
 
-	/**
-	 * Publish a citation
-	 * 
-	 * @return void
-	 */
-	public function publishTask()
-	{
-		//get request vars - expecting an array id[]=4232
-		$id = JRequest::getVar('id', array());
-		if (is_array($id))
-		{
-			$id = (!empty($id)) ? $id[0] : 0;
-		}
-
-		//empty citation object
-		$row = new CitationsCitation($this->database);
-		$row->load($id);
-
-		// mark published and save
-		$row->published = 1;
-		if (!$row->save($row))
-		{
-			$this->setError($row->getError());
-			$this->displayTask();
-			return;
-		}
-
-		// Redirect
-		$this->setRedirect(
-			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('CITATION_PUBLISHED')
-		);
-	}
-
-	/**
-	 * Unpublish a citation
-	 * 
-	 * @return void
-	 */
-	public function unpublishTask()
-	{
-		//get request vars - expecting an array id[]=4232
-		$id = JRequest::getVar('id', array());
-		if (is_array($id))
-		{
-			$id = (!empty($id)) ? $id[0] : 0;
-		}
-
-		//empty citation object
-		$row = new CitationsCitation($this->database);
-		$row->load($id);
-
-		// mark unpublished and save
-		$row->published = 0;
-		if (!$row->save($row))
-		{
-			$this->setError($row->getError());
-			$this->displayTask();
-			return;
-		}
-
-		// Redirect
-		$this->setRedirect(
-			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('CITATION_UNPUBLISHED')
-		);
-	}
-
-	/** 
-	* Toggle affliliation 
-	*
-	* @return void
-	*/
-	public function affiliateTask()
-	{
-	// get the id of the citation
-	$id = JRequest::getInt('id', '');
-	$row = new CitationsCitation($this->database);
-	$row->load($id);
-
-	// toggle the affiliation
-	if ($row->affiliated == 1)
-	{
-		$row->affiliated = 0;
-	}
-	elseif ($row->affiliated == 0)
-	{
-		$row->affiliated = 1;
-	}
-
-	if (!$row->save($row))
-		{
-			$this->setError($row->getError());
-			$this->displayTask();
-			return;
-		}
-
-		// Redirect
-		$this->setRedirect(
-			'index.php?option=' . $this->_option . '&controller=' . $this->_controller,
-			JText::_('CITATION_UNPUBLISHED')
-		);
-	}
-
 	/**
 	 * Display stats for citations
-	 *
-	 * @return		 void
+	 * 
+	 * @return     void
 	 */
 	public function statsTask()
 	{
@@ -348,7 +231,7 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		$this->view->stats = $row->getStats();
 
 		// Set any errors
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -362,75 +245,65 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 
 	/**
 	 * Save a citation
-	 *
-	 * @return		 void
+	 * 
+	 * @return     void
 	 */
 	public function saveTask()
 	{
 		// Check for request forgeries
 		JRequest::checkToken() or jexit('Invalid Token');
 
-		$citation = array_map('trim', JRequest::getVar('citation', array(), 'post'));
+		$citation = JRequest::getVar('citation', array(), 'post');
+		$citation = array_map('trim', $citation);
 		$exclude = JRequest::getVar('exclude', '', 'post');
-		$rollover = JRequest::getInt("rollover", 0);
-		$this->tags = trim(JRequest::getVar('tags', ''));
-		$this->badges = trim(JRequest::getVar('badges', ''));
-		$this->sponsors = JRequest::getVar('sponsors', array(), 'post');
-
-		// for checkboxes
-		if (!isset($citation['affiliated']))
-		{
-			$citation['affiliated'] = 0;
-		}
-
-		if (!isset($citation['fundedby']))
-		{
-			$citation['fundeby'] = 0;
-		}
 
 		// Bind incoming data to object
 		$row = new CitationsCitation($this->database);
-		if (!$row->bind($citation))
+		if (!$row->bind($citation)) 
 		{
-			$this->row = $row;
-			$this->setError( $row->getError() );
-			$this->editTask();
+			$this->addComponentMessage($row->getError(), 'error');
+			$this->editTask($row);
 			return;
 		}
 
+		$paramsClass = 'JParameter';
+		if (version_compare(JVERSION, '1.6', 'ge'))
+		{
+			$paramsClass = 'JRegistry';
+		}
+
 		//set params
-		$cparams = new JRegistry($this->_getParams($row->id));
+		$cparams = new $paramsClass($this->_getParams($row->id));
 		$cparams->set('exclude', $exclude);
-		$cparams->set('rollover', $rollover);
 		$row->params = $cparams->toString();
 
 		// New entry so set the created date
-		if (!$row->id)
+		if (!$row->id) 
 		{
-			$row->created = JFactory::getDate()->toSql();
+			$row->created = date('Y-m-d H:i:s', time());
 		}
 
 		// Check content for missing required data
-		if (!$row->check())
+		if (!$row->check()) 
 		{
-			$this->row = $row;
-			$this->setError( $row->getError() );
-			$this->editTask();
+			$this->addComponentMessage($row->getError(), 'error');
+			$this->editTask($row);
 			return;
 		}
 
 		// Store new content
-		if (!$row->store())
+		if (!$row->store()) 
 		{
-			$this->row = $row;
-			$this->setError( $row->getError() );
-			$this->editTask();
+			$this->addComponentMessage($row->getError(), 'error');
+			$this->editTask($row);
 			return;
 		}
 
 		// Incoming associations
 		$arr = JRequest::getVar('assocs', array(), 'post');
+
 		$ignored = array();
+
 		foreach ($arr as $a)
 		{
 			$a = array_map('trim',$a);
@@ -438,36 +311,35 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 			// Initiate extended database class
 			$assoc = new CitationsAssociation($this->database);
 
-			//check to see if we should delete
-			if (isset($a['id']) && $a['tbl'] == '' && $a['oid'] == '')
-			{
-				// Delete the row
-				if (!$assoc->delete($a['id']))
-				{
-					JError::raiseError(500, $assoc->getError());
-					return;
-				}
-			}
-			else if ($a['tbl'] != '' || $a['oid'] != '')
+			if (!$this->_isempty($a, $ignored)) 
 			{
 				$a['cid'] = $row->id;
 
 				// bind the data
-				if (!$assoc->bind($a))
+				if (!$assoc->bind($a)) 
 				{
 					JError::raiseError(500, $assoc->getError());
 					return;
 				}
 
 				// Check content
-				if (!$assoc->check())
+				if (!$assoc->check()) 
 				{
 					JError::raiseError(500, $assoc->getError());
 					return;
 				}
 
 				// Store new content
-				if (!$assoc->store())
+				if (!$assoc->store()) 
+				{
+					JError::raiseError(500, $assoc->getError());
+					return;
+				}
+			} 
+			elseif ($this->_isEmpty($a, $ignored) && !empty($a['id'])) 
+			{
+				// Delete the row
+				if (!$assoc->delete($a['id'])) 
 				{
 					JError::raiseError(500, $assoc->getError());
 					return;
@@ -476,16 +348,24 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		}
 
 		//save sponsors on citation
-		if ($this->sponsors)
-		{
-			$cs = new CitationsSponsor($this->database);
-			$cs->addSponsors($row->id, $this->sponsors);
-		}
+		$sponsors = JRequest::getVar('sponsors', array(), 'post');
+		$cs = new CitationsSponsor($this->database);
+		$cs->addSponsors($row->id, $sponsors);
 
-		//add tags & badges
-		$ct = new CitationTags($row->id);
-		$ct->setTags($this->tags, $this->juser->get('id'), 1, 1, '');
-		$ct->setTags($this->badges, $this->juser->get('id'), 1, 1, 'badge');
+		//citation tags object
+		$ct = new CitationTags($this->database);
+
+		//get the tags
+		$tags = trim(JRequest::getVar('tags', ''));
+
+		//get the badges
+		$badges = trim(JRequest::getVar('badges', ''));
+
+		//add tags
+		$ct->tag_object($this->juser->get("id"), $row->id, $tags, 1, false, "");
+
+		//add badges
+		$ct->tag_object($this->juser->get("id"), $row->id, $badges, 1, false, "badge");
 
 		// Redirect
 		$this->setRedirect(
@@ -496,21 +376,21 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 
 	/**
 	 * Check if an array has any values set other than $ignored values
-	 *
-	 * @param		 array $b			Array to check
-	 * @param		 array $ignored Values to ignore
-	 * @return		 boolean True if empty
+	 * 
+	 * @param      array $b       Array to check
+	 * @param      array $ignored Values to ignore
+	 * @return     boolean True if empty
 	 */
 	private function _isEmpty($b, $ignored=array())
 	{
 		foreach ($ignored as $ignore)
 		{
-			if (array_key_exists($ignore, $b))
+			if (array_key_exists($ignore, $b)) 
 			{
 				$b[$ignore] = NULL;
 			}
 		}
-		if (array_key_exists('id',$b))
+		if (array_key_exists('id',$b)) 
 		{
 			$b['id'] = NULL;
 		}
@@ -518,7 +398,7 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		$e = true;
 		foreach ($values as $v)
 		{
-			if ($v)
+			if ($v) 
 			{
 				$e = false;
 			}
@@ -528,20 +408,20 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 
 	/**
 	 * Remove one or more citations
-	 *
-	 * @return		 void
+	 * 
+	 * @return     void
 	 */
 	public function removeTask()
 	{
 		// Incoming (we're expecting an array)
 		$ids = JRequest::getVar('id', array());
-		if (!is_array($ids))
+		if (!is_array($ids)) 
 		{
-			$ids = array($ids);
+			$ids = array();
 		}
 
 		// Make sure we have IDs to work with
-		if (count($ids) > 0)
+		if (count($ids) > 0) 
 		{
 			// Loop through the IDs and delete the citation
 			$citation = new CitationsCitation($this->database);
@@ -567,13 +447,13 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 				$citation->delete($id);
 
 				//citation tags
-				$ct = new CitationTags($id);
-				$ct->removeAll();
+				$ct = new CitationTags($this->database);
+				$ct->remove_all_tags($id);
 			}
 
 			$message = JText::_('CITATION_REMOVED');
-		}
-		else
+		} 
+		else 
 		{
 			$message = JText::_('NO_SELECTION');
 		}
@@ -585,10 +465,62 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 		);
 	}
 
+	/**
+	 * Get the current citations format
+	 * 
+	 * @return     void
+	 */
+	public function getformatTask()
+	{
+		//get the format being sent via json
+		$format = JRequest::getVar('format', 'apa');
+
+		//include citations format class
+		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_citations' . DS . 'helpers' . DS . 'format.php');
+
+		//new citations format object
+		$cf = new CitationFormat();
+
+		//get the default template for the format being passed in
+		$format_template = $cf->getDefaultFormat($format);
+
+		//return the template
+		echo $format_template;
+	}
+
+	/**
+	 * Get citation template keys
+	 * 
+	 * @return     void
+	 */
+	public function gettemplatekeysTask()
+	{
+		// include citations format class
+		require_once(JPATH_ROOT . DS . 'components' . DS . 'com_citations' . DS . 'helpers' . DS . 'format.php');
+
+		// new citations format object
+		$cf = new CitationFormat();
+
+		// get the keys
+		$keys = $cf->getTemplateKeys();
+
+		// var to hold html data
+		$html = '';
+
+		// create row for each key pair
+		foreach ($keys as $k => $v) 
+		{
+			$html .= "<tr><td>{$v}</td><td>{$k}</td></tr>";
+		}
+
+		//return html
+		echo $html;
+	}
+
 	/**
 	 * Cancel a task (redirects to default task)
 	 *
-	 * @return		 void
+	 * @return     void
 	 */
 	public function cancelTask()
 	{
@@ -601,12 +533,12 @@ class CitationsControllerCitations extends \Hubzero\Component\AdminController
 	/**
 	 * Get the params for a citation
 	 *
-	 * @param		 integer $citation Citation ID
-	 * @return		 integer
+	 * @param      integer $citation Citation ID
+	 * @return     integer
 	 */
-	private function _getParams($citation = 0)
+	private function _getParams($citation)
 	{
-		$this->database->setQuery("SELECT c.params from #__citations c WHERE id=" . $this->database->quote( $citation ));
+		$this->database->setQuery("SELECT c.params from #__citations c WHERE id=" . $citation);
 		return $this->database->loadResult();
 	}
 }
