@@ -30,18 +30,18 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$canDo = ResourcesHelperPermissions::getActions('role');
+$canDo = ResourcesHelper::getActions('role');
 
-JToolBarHelper::title(JText::_('COM_RESOURCES') . ': ' . JText::_('COM_RESOURCES_ROLES'), 'addedit.png');
-if ($canDo->get('core.create'))
+JToolBarHelper::title('<a href="index.php?option=' . $this->option . '">' . JText::_('Resources') . '</a>: <small><small>[' . JText::_('Roles') . ']</small></small>', 'addedit.png');
+if ($canDo->get('core.create')) 
 {
 	JToolBarHelper::addNew();
 }
-if ($canDo->get('core.edit'))
+if ($canDo->get('core.edit')) 
 {
 	JToolBarHelper::editList();
 }
-if ($canDo->get('core.delete'))
+if ($canDo->get('core.delete')) 
 {
 	JToolBarHelper::deleteList();
 }
@@ -49,21 +49,21 @@ if ($canDo->get('core.delete'))
 ?>
 <form action="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>" method="post" name="adminForm" id="adminForm">
 	<fieldset id="filter-bar">
-		<label for="filter_search"><?php echo JText::_('JSEARCH_FILTER'); ?>:</label>
-		<input type="text" name="search" id="filter_search" value="<?php echo $this->escape($this->filters['search']); ?>" placeholder="<?php echo JText::_('COM_RESOURCES_SEARCH_PLACEHOLDER'); ?>" />
-
-		<input type="submit" name="filter_submit" id="filter_submit" value="<?php echo JText::_('COM_RESOURCES_GO'); ?>" />
+		<label for="filter_search"><?php echo JText::_('Search'); ?>:</label>
+		<input type="text" name="search" id="filter_search" value="<?php echo $this->filters['search']; ?>" />
+	
+		<input type="submit" name="filter_submit" id="filter_submit" value="<?php echo JText::_('Go'); ?>" />
 	</fieldset>
 	<div class="clr"></div>
-
-	<table class="adminlist">
+	
+	<table class="adminlist" summary="<?php echo JText::_('A list of resource roles'); ?>">
 		<thead>
 			<tr>
 				<th scope="col"><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count( $this->rows );?>);" /></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_RESOURCES_COL_ID', 'id', @$this->filters['sort_Dir'], @$this->filters['sort'] ); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_RESOURCES_COL_ALIAS', 'alias', @$this->filters['sort_Dir'], @$this->filters['sort'] ); ?></th>
-				<th scope="col"><?php echo JHTML::_('grid.sort', 'COM_RESOURCES_COL_TITLE', 'type', @$this->filters['sort_Dir'], @$this->filters['sort'] ); ?></th>
-				<th scope="col"><?php echo JText::_('COM_RESOURCES_COL_TYPES'); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', JText::_('ID'), 'id', @$this->filters['sort_Dir'], @$this->filters['sort'] ); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', JText::_('Alias'), 'alias', @$this->filters['sort_Dir'], @$this->filters['sort'] ); ?></th>
+				<th scope="col"><?php echo JHTML::_('grid.sort', JText::_('Title'), 'type', @$this->filters['sort_Dir'], @$this->filters['sort'] ); ?></th>
+				<th scope="col"><?php echo JText::_('Types'); ?></th>
 			</tr>
 		</thead>
 		<tfoot>
@@ -80,37 +80,37 @@ for ($i=0, $n=count( $this->rows ); $i < $n; $i++)
 ?>
 			<tr class="<?php echo "row$k"; ?>">
 				<td>
-					<?php if ($canDo->get('core.edit')) { ?>
-						<input type="checkbox" name="id[]" id="cb<?php echo $i; ?>" value="<?php echo $row->id; ?>" onclick="isChecked(this.checked);" />
-					<?php } ?>
+<?php if ($canDo->get('core.edit')) { ?>
+					<input type="checkbox" name="id[]" id="cb<?php echo $i; ?>" value="<?php echo $row->id; ?>" onclick="isChecked(this.checked);" />
+<?php } ?>
 				</td>
 				<td>
 					<?php echo $row->id; ?>
 				</td>
 				<td>
-					<?php if ($canDo->get('core.edit')) { ?>
-						<a href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit&amp;id=<?php echo $row->id; ?>">
-							<span><?php echo $this->escape($row->alias); ?></span>
-						</a>
-					<?php } else { ?>
-						<span>
-							<span><?php echo $this->escape($row->alias); ?></span>
-						</span>
-					<?php } ?>
+<?php if ($canDo->get('core.edit')) { ?>
+					<a href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit&amp;id[]=<?php echo $row->id; ?>">
+						<span><?php echo $this->escape($row->alias); ?></span>
+					</a>
+<?php } else { ?>
+					<span>
+						<span><?php echo $this->escape($row->alias); ?></span>
+					</span>
+<?php } ?>
 				</td>
 				<td>
-					<?php if ($canDo->get('core.edit')) { ?>
-						<a href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit&amp;id=<?php echo $row->id; ?>">
-							<span><?php echo $this->escape($row->title); ?></span>
-						</a>
-					<?php } else { ?>
-						<span>
-							<span><?php echo $this->escape($row->title); ?></span>
-						</span>
-					<?php } ?>
+<?php if ($canDo->get('core.edit')) { ?>
+					<a href="index.php?option=<?php echo $this->option; ?>&amp;controller=<?php echo $this->controller; ?>&amp;task=edit&amp;id[]=<?php echo $row->id; ?>">
+						<span><?php echo $this->escape($row->title); ?></span>
+					</a>
+<?php } else { ?>
+					<span>
+						<span><?php echo $this->escape($row->title); ?></span>
+					</span>
+<?php } ?>
 				</td>
 				<td>
-				<?php
+<?php
 					if ($row->types)
 					{
 						$types = array();
@@ -121,7 +121,7 @@ for ($i=0, $n=count( $this->rows ); $i < $n; $i++)
 						//echo implode(', ', $types);
 						echo count($row->types);
 					}
-				?>
+?>
 				</td>
 			</tr>
 <?php
@@ -137,6 +137,6 @@ for ($i=0, $n=count( $this->rows ); $i < $n; $i++)
 	<input type="hidden" name="boxchecked" value="0" />
 	<input type="hidden" name="sort" value="<?php echo $this->filters['sort']; ?>" />
 	<input type="hidden" name="sort_Dir" value="<?php echo $this->filters['sort_Dir']; ?>" />
-
+	
 	<?php echo JHTML::_('form.token'); ?>
 </form>
\ No newline at end of file
