@@ -30,15 +30,15 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-JToolBarHelper::title(JText::_('COM_SUPPORT_TICKETS') . ': ' . JText::_('COM_SUPPORT_MESSAGES'), 'support.png');
+JToolBarHelper::title( JText::_( 'Support' ).': <small><small>[ '.JText::_( 'Ticket Messages' ).' ]</small></small>', 'support.png' );
 JToolBarHelper::addNew();
 JToolBarHelper::editList();
 JToolBarHelper::deleteList();
 JToolBarHelper::spacer();
-JToolBarHelper::help('messages');
+JToolBarHelper::help('messages.html', true);
 ?>
 <script type="text/javascript">
-function submitbutton(pressbutton)
+function submitbutton(pressbutton) 
 {
 	var form = document.adminForm;
 	if (pressbutton == 'cancel') {
@@ -46,7 +46,7 @@ function submitbutton(pressbutton)
 		return;
 	}
 	// do field validation
-	submitform(pressbutton);
+	submitform( pressbutton );
 }
 </script>
 
@@ -54,9 +54,9 @@ function submitbutton(pressbutton)
 	<table class="adminlist">
 		<thead>
 			<tr>
-				<th scope="col"><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count($this->rows);?>);" /></th>
-				<th scope="col"><?php echo JText::_('COM_SUPPORT_COL_NUM'); ?></th>
-				<th scope="col"><?php echo JText::_('COM_SUPPORT_COL_MESSAGE'); ?></th>
+				<th><input type="checkbox" name="toggle" value="" onclick="checkAll(<?php echo count( $this->rows );?>);" /></th>
+				<th><?php echo JText::_('SUPPORT_COL_NUM'); ?></th>
+				<th><?php echo JText::_('SUPPORT_COL_MESSAGE'); ?></th>
 			</tr>
 		</thead>
 		<tfoot>
@@ -88,5 +88,5 @@ function submitbutton(pressbutton)
 	<input type="hidden" name="task" value="" />
 	<input type="hidden" name="boxchecked" value="0" />
 
-	<?php echo JHTML::_('form.token'); ?>
+	<?php echo JHTML::_( 'form.token' ); ?>
 </form>
