@@ -31,8 +31,9 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-// get the timezone name from offset
-$timezone = timezone_name_from_abbr('',$this->row->time_zone*3600, NULL);
+// Get abbreviated time zone (i.e just the UTC offset)
+$tz = explode(")", EventsHtml::getTimeZoneName($this->row->time_zone));
+$tz = $tz[0].")";
 
 $this->row->content = stripslashes($this->row->content);
 $this->row->content = str_replace('<br />','',$this->row->content);
@@ -43,36 +44,45 @@ if (!empty($this->fields)) {
 	for ($i=0, $n=count( $this->fields ); $i < $n; $i++)
 	{
 		// explore the text and pull out all matches
-		array_push($this->fields[$i], EventsControllerEvents::parseTag($this->row->content, $this->fields[$i][0]));
+		array_push($this->fields[$i], EventsControllerEvent::parseTag($this->row->content, $this->fields[$i][0]));
 		// clean the original text of any matches
 		$this->row->content = str_replace('<ef:'.$this->fields[$i][0].'>'.end($this->fields[$i]).'</ef:'.$this->fields[$i][0].'>','',$this->row->content);
 	}
 	$this->row->content = trim($this->row->content);
 }
 
-$start_date = JHTML::_('date',$this->row->publish_up, 'd M Y', $timezone);
-$stop_date  = JHTML::_('date',$this->row->publish_down, 'd M Y', $timezone);
+$event_up = new EventsDate( $this->row->publish_up );
+$this->row->start_date = EventsHtml::getDateFormat($event_up->year,$event_up->month,$event_up->day,0);
+$this->row->start_time = (defined('_CAL_USE_STD_TIME') && _CAL_USE_STD_TIME == 'YES')
+				 ? $event_up->get12hrTime()
+				 : $event_up->get24hrTime();
+
+$event_down = new EventsDate( $this->row->publish_down );
+$this->row->stop_date = EventsHtml::getDateFormat($event_down->year,$event_down->month,$event_down->day,0);
+$this->row->stop_time = (defined('_CAL_USE_STD_TIME') && _CAL_USE_STD_TIME == 'YES')
+				? $event_down->get12hrTime()
+				: $event_down->get24hrTime();
 
 $html  = "\t".'<li id="event'.$this->row->id.'">'."\n";
 $html .= "\t\t".'<dl class="event-details">'."\n";
-if ($start_date == $stop_date) {
+if ($this->row->start_date == $this->row->stop_date) {
 	if ($this->showdate) {
-		$html .= "\t\t\t".'<dt>'.JHTML::_('date',$this->row->publish_up, 'd M Y', $timezone).'</dt>'."\n";
+		$html .= "\t\t\t".'<dt>'.JHTML::_('date',$this->row->publish_up, '%d %b, %Y', 0).'</dt>'."\n";
 	}
-	$html .= "\t\t\t".'<dd class="starttime">'.JHTML::_('date',$this->row->publish_up, 'g:i a T', $timezone).'&nbsp;' .'</dd>'."\n";
-	$html .= "\t\t\t".'<dd class="endtime">'.strtolower(JText::_('EVENTS_CAL_LANG_TO')).' '.JHTML::_('date',$this->row->publish_down, 'g:i a T', $timezone).'&nbsp;'.'</dd>'."\n";
+	$html .= "\t\t\t".'<dd class="starttime">'.JHTML::_('date',$this->row->publish_up, '%I:%M %p', 0).'&nbsp;'.$tz.'</dd>'."\n";
+	$html .= "\t\t\t".'<dd class="endtime">'.strtolower(JText::_('EVENTS_CAL_LANG_TO')).' '.JHTML::_('date',$this->row->publish_down, '%I:%M %p', 0).'&nbsp;'.$tz.'</dd>'."\n";
 } else {
 	if ($this->showdate) {
-		$html .= "\t\t\t".'<dt class="starttime">'.JHTML::_('date',$this->row->publish_up, JText::_('DATE_FORMAT_HZ1'), $timezone).'</dt>'."\n";
+		$html .= "\t\t\t".'<dt class="starttime">'.JHTML::_('date',$this->row->publish_up, '%d %b, %Y', 0).'</dt>'."\n";
 	}
-	$html .= "\t\t\t".'<dd class="starttime">'.JHTML::_('date',$this->row->publish_up, 'g:i a T', $timezone).'&nbsp;'.'</dd>'."\n";
+	$html .= "\t\t\t".'<dd class="starttime">'.JHTML::_('date',$this->row->publish_up, '%I:%M %p', 0).'&nbsp;'.$tz.'</dd>'."\n";
 	if ($this->showdate) {
-		$html .= "\t\t\t".'<dt class="endtime">'.strtolower(JText::_('EVENTS_CAL_LANG_TO')).' '.JHTML::_('date',$this->row->publish_down, JText::_('DATE_FORMAT_HZ1'), $timezone).'</dt>'."\n";
+		$html .= "\t\t\t".'<dt class="endtime">'.strtolower(JText::_('EVENTS_CAL_LANG_TO')).' '.JHTML::_('date',$this->row->publish_down, '%d %b, %Y', 0).'</dt>'."\n";
 	}
-	$html .= "\t\t\t".'<dd class="endtime">'.JHTML::_('date',$this->row->publish_down, 'g:i a T', $timezone).'&nbsp;'.'</dd>'."\n";
+	$html .= "\t\t\t".'<dd class="endtime">'.JHTML::_('date',$this->row->publish_down, '%I:%M %p', 0).'&nbsp;'.$tz.'</dd>'."\n";
 }
 $html .= "\t\t".'</dl><div class="ewrap">'."\n";
-$html .= "\t\t".'<p class="title"><a href="'. JRoute::_('index.php?option='.$this->option.'&task=details&id='.$this->row->id) .'">'. $this->escape(stripslashes($this->row->title)) .'</a></p>'."\n";
+$html .= "\t\t".'<p class="title"><a href="'. JRoute::_('index.php?option='.$this->option.'&task=details&id='.$this->row->id) .'">'. stripslashes($this->row->title) .'</a></p>'."\n";
 $html .= "\t\t".'<p class="category"><strong>Category:</strong> '. stripslashes($this->categories[$this->row->catid]) .'</p>'."\n";
 $info = '';
 foreach ($this->fields as $field)
@@ -83,7 +93,7 @@ foreach ($this->fields as $field)
 }
 $html .= $info;
 if (!$info) {
-	$html .= "\t\t".'<p class="description">'. \Hubzero\Utility\String::truncate($this->row->content,300) .'</p>'."\n";
+	$html .= "\t\t".'<p class="description">'. Hubzero_View_Helper_Html::shortenText($this->row->content,300,0) .'</p>'."\n";
 }
 $html .= "\t".'</div></li>'."\n";
 
