@@ -31,14 +31,22 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-include_once(JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'quotes.php');
+if (JFactory::getConfig()->getValue('config.debug')) 
+{
+	error_reporting(E_ALL);
+	@ini_set('display_errors','1');
+}
+
+include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . $option . DS . 'tables' . DS . 'quotes.php');
+include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . $option . DS . 'tables' . DS . 'selectedquotes.php');
+ximport('Hubzero_View_Helper_Html');
 
 $controllerName = JRequest::getCmd('controller', JRequest::getCmd('view', 'feedback'));
-if (!file_exists(JPATH_COMPONENT_SITE . DS . 'controllers' . DS . $controllerName . '.php'))
+if (!file_exists(JPATH_COMPONENT . DS . 'controllers' . DS . $controllerName . '.php'))
 {
 	$controllerName = 'feedback';
 }
-require_once(JPATH_COMPONENT_SITE . DS . 'controllers' . DS . $controllerName . '.php');
+require_once(JPATH_COMPONENT . DS . 'controllers' . DS . $controllerName . '.php');
 $controllerName = 'FeedbackController' . ucfirst($controllerName);
 
 // Instantiate controller
