@@ -23,7 +23,7 @@
  * HUBzero is a registered trademark of Purdue University.
  *
  * @package   hubzero-cms
- * @author    Christopher Smoak <csmoak@purdue.edu>
+ * @author    Shawn Rice <zooley@purdue.edu>
  * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
  * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  */
@@ -31,34 +31,50 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-// include tables
-require_once JPATH_COMPONENT_ADMINISTRATOR . DS . 'tables' . DS . 'reason.php';
+if (JFactory::getConfig()->getValue('config.debug')) 
+{
+	error_reporting(E_ALL);
+	@ini_set('display_errors','1');
+}
 
-// include models
-require_once JPATH_COMPONENT_SITE . DS . 'models' . DS . 'tags.php';
-require_once JPATH_COMPONENT_SITE . DS . 'models' . DS . 'log' . DS . 'archive.php';
-require_once JPATH_COMPONENT_SITE . DS . 'models' . DS . 'page' . DS . 'archive.php';
-require_once JPATH_COMPONENT_SITE . DS . 'models' . DS . 'module' . DS . 'archive.php';
+if (version_compare(JVERSION, '1.6', 'lt'))
+{
+	$jacl = JFactory::getACL();
+	$jacl->addACL($option, 'manage', 'users', 'super administrator');
+	$jacl->addACL($option, 'manage', 'users', 'administrator');
+	$jacl->addACL($option, 'manage', 'users', 'manager');
+}
 
-// include helpers
-require_once JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'view.php';
-require_once JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'pages.php';
-require_once JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'document.php';
-require_once JPATH_COMPONENT_SITE . DS . 'helpers' . DS . 'template.php';
+//import needed joomla libs
+jimport('joomla.filesystem.folder');
+jimport('joomla.application.component.view');
 
-//include abstract controller
-require_once JPATH_COMPONENT_SITE . DS . 'controllers' . DS . 'abstract.php';
+//import needed HUBzero libs
+ximport('Hubzero_Group');
+ximport('Hubzero_Group_Helper');
+ximport('Hubzero_Group_InviteEmail');
+ximport('Hubzero_User_Helper');
+ximport('Hubzero_User_Profile');
+ximport('Hubzero_View_Helper_Html');
+ximport('Hubzero_Plugin_Params');
+
+//require needed files
+require_once(JPATH_ADMINISTRATOR . DS . 'components' . DS . $option . DS . 'tables' . DS . 'tags.php');
+require_once(JPATH_ADMINISTRATOR . DS . 'components' . DS . $option . DS . 'tables' . DS . 'log.php');
+require_once(JPATH_ADMINISTRATOR . DS . 'components' . DS . $option . DS . 'tables' . DS . 'reason.php');
+require_once(JPATH_ADMINISTRATOR . DS . 'components' . DS . $option . DS . 'tables' . DS . 'pages.php');
 
 //build controller path and name
 $controllerName = JRequest::getCmd('controller', JRequest::getCmd('view', 'groups'));
-if (!file_exists(JPATH_COMPONENT_SITE . DS . 'controllers' . DS . $controllerName . '.php'))
+if (!file_exists(JPATH_COMPONENT . DS . 'controllers' . DS . $controllerName . '.php'))
 {
 	$controllerName = 'groups';
 }
-require_once(JPATH_COMPONENT_SITE . DS . 'controllers' . DS . $controllerName . '.php');
-$controllerName = 'GroupsController' . ucfirst(strtolower($controllerName));
+require_once(JPATH_COMPONENT . DS . 'controllers' . DS . $controllerName . '.php');
+$controllerName = ucfirst(strtolower($controllerName)) . 'Controller';
 
 // Instantiate controller and execute
 $controller = new $controllerName();
 $controller->execute();
-$controller->redirect();
\ No newline at end of file
+$controller->redirect();
+
