@@ -31,10 +31,12 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Controller class for registration
  */
-class RegisterController extends \Hubzero\Component\SiteController
+class RegisterController extends Hubzero_Controller
 {
 	/**
 	 * Determine task and execute it
@@ -46,7 +48,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 		$app = JFactory::getApplication();
 		$this->jconfig = JFactory::getConfig();
 
-		$juri = JURI::getInstance();
+		$juri =& JURI::getInstance();
 		$this->baseURL = rtrim($juri->base(), DS);
 
 		// Make sure we're using a secure connection
@@ -100,8 +102,8 @@ class RegisterController extends \Hubzero\Component\SiteController
 			return JError::raiseError(500, JText::_('COM_REGISTER_ERROR_GUEST_SESSION_EDITING'));
 		}
 
-		$xprofile = \Hubzero\User\Profile::getInstance($this->juser->get('id'));
-		$jsession = JFactory::getSession();
+		$xprofile =& Hubzero_Factory::getProfile();
+		$jsession =& JFactory::getSession();
 
 		// Get the return URL
 		$return = base64_decode(JRequest::getVar('return', '',  'method', 'base64'));
@@ -117,7 +119,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 
 		$username = JRequest::getVar('username',$xprofile->get('username'),'get');
 
-		$target_xprofile = \Hubzero\User\Profile::getInstance($username);
+		$target_xprofile = Hubzero_User_Profile::getInstance($username);
 
 		$admin = $this->juser->authorize($this->_option, 'manage');
 		$self = ($xprofile->get('username') == $username);
@@ -140,7 +142,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 		$this->_buildTitle();
 
 		// Instantiate a new registration object
-		$xregistration = new RegisterModelRegistration();
+		$xregistration = new Hubzero_Registration();
 
 		if (JRequest::getVar('edit', '', 'post')) 
 		{
@@ -166,7 +168,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 
 		$target_xprofile->loadRegistration($xregistration);
 		
-		$params = JComponentHelper::getParams('com_members');
+		$params =& JComponentHelper::getParams('com_members');
 		
 		$hubHomeDir = rtrim($params->get('homedir'),'/');
 		
@@ -197,7 +199,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 
 		if ($target_xprofile->get('registerDate') == '') 
 		{
-			$target_xprofile->set('registerDate', JFactory::getDate()->toSql());
+			$target_xprofile->set('registerDate', date('Y-m-d H:i:s'));
 		}
 
 		if ($xregistration->get('email') != $target_xprofile->get('email')) 
@@ -224,15 +226,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 				$eview->baseURL = $this->baseURL;
 				$message = $eview->loadTemplate();
 				$message = str_replace("\n", "\r\n", $message);
-
-				$msg = new \Hubzero\Mail\Message();
-				$msg->setSubject($subject)
-				    ->addTo($target_xprofile->get('email'))
-				    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-				    ->addHeader('X-Component', $this->_option)
-				    ->setBody($message);
-
-				if (!$msg->send()) 
+				if (!Hubzero_Toolbox::send_email($target_xprofile->get('email'), $subject, $message)) 
 				{
 					$this->setError(JText::sprintf('COM_REGISTER_ERROR_EMAILING_CONFIRMATION'/*, $hubMonitorEmail*/));
 					// @FIXME: LOG ERROR CONDITION SOMEWHERE
@@ -250,13 +244,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 			$message = $eaview->loadTemplate();
 			$message = str_replace("\n", "\r\n", $message);
 
-			/*$msg = new \Hubzero\Mail\Message();
-			$msg->setSubject($subject)
-			    ->addTo($hubMonitorEmail)
-			    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-			    ->addHeader('X-Component', $this->_option)
-			    ->setBody($message)
-			    ->send();*/
+			// Hubzero_Toolbox::send_email($hubMonitorEmail, $subject, $message);
 			// @FIXME: LOG ACCOUNT UPDATE ACTIVITY SOMEWHERE
 
 			// Determine action based on if the user chaged their email or not
@@ -281,14 +269,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 				$message = $eview->loadTemplate();
 				$message = str_replace("\n", "\r\n", $message);
 
-				$msg = new \Hubzero\Mail\Message();
-				$msg->setSubject($subject)
-				    ->addTo($target_xprofile->get('email'))
-				    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-				    ->addHeader('X-Component', $this->_option)
-				    ->setBody($message);
-
-				if (!$msg->send()) 
+				if (!Hubzero_Toolbox::send_email($target_xprofile->get('email'), $subject, $message)) 
 				{
 					$this->setError(JText::sprintf('COM_REGISTER_ERROR_EMAILING_CONFIRMATION'/*, $hubMonitorEmail*/));
 					// @FIXME: LOG ERROR CONDITION SOMEWHERE
@@ -306,13 +287,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 			$message = $eaview->loadTemplate();
 			$message = str_replace("\n", "\r\n", $message);
 
-			/*$msg = new \Hubzero\Mail\Message();
-			$msg->setSubject($subject)
-			    ->addTo($hubMonitorEmail)
-			    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-			    ->addHeader('X-Component', $this->_option)
-			    ->setBody($message)
-			    ->send();*/
+			// Hubzero_Toolbox::send_email($hubMonitorEmail, $subject, $message);
 			// @FIXME: LOG ACCOUNT UPDATE ACTIVITY SOMEWHERE
 
 			// Determine action based on if the user chaged their email or not
@@ -348,6 +323,8 @@ class RegisterController extends \Hubzero\Component\SiteController
 	 */
 	protected function proxycreate($action='show')
 	{
+		ximport('Hubzero_User_Password');
+		
 		$action = ($action) ? $action : 'show';
 
 		$admin = $this->juser->authorize($this->_option, 'manage');
@@ -380,7 +357,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 		$this->_buildTitle();
 
 		// Instantiate a new registration object
-		$xregistration = new RegisterModelRegistration();
+		$xregistration = new Hubzero_Registration();
 
 		// Show the form if needed
 		if ($action == 'show') 
@@ -404,19 +381,19 @@ class RegisterController extends \Hubzero\Component\SiteController
 			return $this->_show_registration_form($xregistration, 'proxycreate');
 		}
 
-		$xprofile = \Hubzero\User\Profile::getInstance($this->juser->get('id'));
+		$xprofile =& Hubzero_Factory::getProfile();
 
 		// Get some settings
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 		$this->jconfig = $jconfig;
-		$params = JComponentHelper::getParams('com_members');
+		$params =& JComponentHelper::getParams('com_members');
 		$hubHomeDir = rtrim($params->get('homedir'),'/');
 		
 		jimport('joomla.application.component.helper');
-		$config   = JComponentHelper::getParams('com_users');
+		$config   =& JComponentHelper::getParams('com_users');
 		$usertype = $config->get('new_usertype', 'Registered');
 
-		$acl = JFactory::getACL();
+		$acl =& JFactory::getACL();
 
 		// Create a new Joomla user
 		$target_juser = new JUser();
@@ -425,30 +402,12 @@ class RegisterController extends \Hubzero\Component\SiteController
 		$target_juser->set('username', $xregistration->get('login'));
 		$target_juser->set('password_clear','');
 		$target_juser->set('email', $xregistration->get('email'));
-
-		if (version_compare(JVERSION, '1.6', 'lt'))
-		{
-			$target_juser->set('gid', $acl->get_group_id('', $usertype));
-			$target_juser->set('usertype', $usertype);
-		}
-		else
-		{
-			// There's got to be a better way to do this!
-			$db = JFactory::getDbo();
-			$query = $db->getQuery(true)
-				->select('id')
-				->from('#__usergroups')
-				->where('title = ' . $db->quote(trim($usertype)));
-			$db->setQuery($query);
-			$result = $db->loadResult();
-
-			$target_juser->set('groups', array($result));
-		}
-
+		$target_juser->set('gid', $acl->get_group_id('', $usertype));
+		$target_juser->set('usertype', $usertype);
 		$target_juser->save();
 
 		// Attempt to retrieve the new user
-		$target_xprofile = \Hubzero\User\Profile::getInstance($target_juser->get('id'));
+		$target_xprofile = Hubzero_User_Profile::getInstance($target_juser->get('id'));
 		$result = is_object($target_xprofile);
 
 		// Did we successully create an account?
@@ -465,7 +424,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 				$target_xprofile->set('regHost', JRequest::getVar('REMOTE_HOST','','server'));
 			}
 
-			$target_xprofile->set('registerDate', JFactory::getDate()->toSql());
+			$target_xprofile->set('registerDate', date('Y-m-d H:i:s'));
 			$target_xprofile->set('proxyUidNumber', $this->juser->get('id'));
 			$target_xprofile->set('proxyPassword', $xregistration->get('password'));
 
@@ -473,19 +432,9 @@ class RegisterController extends \Hubzero\Component\SiteController
 			$result = $target_xprofile->update();
 		}
 
-		// add member interests
-		$interests = $xregistration->get('interests');
-		if (!empty($interests))
-		{
-			$mt = new MembersTags($this->database);
-			$mt->tag_object($target_xprofile->get('uidNumber'), $target_xprofile->get('uidNumber'), $interests, 1, 1);
-		}
-
 		if ($result) 
 		{
-			$result = \Hubzero\User\Password::changePassword($target_xprofile->get('username'), $xregistration->get('password'));
-			// Now expire the password
-			\Hubzero\User\Password::expirePassword($target_xprofile->get('username'));
+			$result = Hubzero_User_Password::changePassword($target_xprofile->get('username'), $xregistration->get('password'));
 		}
 		
 		// Did we successully create/update an account?
@@ -525,6 +474,8 @@ class RegisterController extends \Hubzero\Component\SiteController
 	 */
 	protected function update()
 	{
+		ximport('Hubzero_Auth_Link');
+		
 		$app = JFactory::getApplication();
 		
 		$force = false;
@@ -553,12 +504,12 @@ class RegisterController extends \Hubzero\Component\SiteController
 		}
 
 		// Instantiate a new registration object
-		$xregistration = new RegisterModelRegistration();
+		$xregistration = new Hubzero_Registration();
 
-		$xprofile    = \Hubzero\User\Profile::getInstance($this->juser->get('id'));
-		$jsession = JFactory::getSession();
+		$xprofile    =& Hubzero_Factory::getProfile();
+		$jsession =& JFactory::getSession();
 
-		$hzal = \Hubzero\Auth\Link::find_by_id($this->juser->get('auth_link_id'));
+		$hzal = Hubzero_Auth_Link::find_by_id($this->juser->get('auth_link_id'));
 
 		if (JRequest::getMethod() == 'POST') 
 		{
@@ -577,13 +528,13 @@ class RegisterController extends \Hubzero\Component\SiteController
 				$xregistration->loadAccount($this->juser);
 			}
 
+			ximport('Hubzero_Auth_Link');
 			$username = $this->juser->get('username');
 			$email = $this->juser->get('email');
 
 			if ($username[0] == '-' && is_object($hzal)) 
 			{
-				$tmp_username = JFactory::getSession()->get('auth_link.tmp_username', '');
-				$xregistration->set('login',$tmp_username);
+				$xregistration->set('login',$hzal->username);
 				$xregistration->set('email',$hzal->email);
 				$xregistration->set('confirmEmail',$hzal->email);
 				$force = true;
@@ -608,7 +559,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 
 		if (!$force && $check && JRequest::getMethod() == 'POST') 
 		{
-			$params = JComponentHelper::getParams('com_members');
+			$params =& JComponentHelper::getParams('com_members');
 			$hubHomeDir = rtrim($params->get('homedir'),'/');
 
 			$updateEmail     = false;
@@ -638,7 +589,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 
 			if ($xprofile->get('registerDate') == '') 
 			{
-				$xprofile->set('registerDate', JFactory::getDate()->toSql());
+				$xprofile->set('registerDate', date('Y-m-d H:i:s'));
 			}
 
 			if ($xregistration->get('email') != $xprofile->get('email')) 
@@ -683,7 +634,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 				$jsession->set('user', $sjuser);
 
 				// Get the session object
-				$table =  JTable::getInstance('session');
+				$table = & JTable::getInstance('session');
 				$table->load($jsession->getId());
 				$table->username = $xprofile->get('username');
 				$table->update();
@@ -704,14 +655,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 				$message = $eview->loadTemplate();
 				$message = str_replace("\n", "\r\n", $message);
 
-				$msg = new \Hubzero\Mail\Message();
-				$msg->setSubject($subject)
-				    ->addTo($xprofile->get('email'))
-				    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-				    ->addHeader('X-Component', $this->_option)
-				    ->setBody($message);
-
-				if (!$msg->send()) 
+				if (!Hubzero_Toolbox::send_email($xprofile->get('email'), $subject, $message)) 
 				{
 					$this->setError(JText::sprintf('COM_REGISTER_ERROR_EMAILING_CONFIRMATION'/*,$hubMonitorEmail*/));
 					// @FIXME: LOG ERROR SOMEWHERE
@@ -731,13 +675,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 				$message = $eaview->loadTemplate();
 				$message = str_replace("\n", "\r\n", $message);
 
-				/*$msg = new \Hubzero\Mail\Message();
-				$msg->setSubject($subject)
-				    ->addTo($hubMonitorEmail)
-				    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-				    ->addHeader('X-Component', $this->_option)
-				    ->setBody($message)
-				    ->send();*/
+				// Hubzero_Toolbox::send_email($hubMonitorEmail, $subject, $message);
 				// @FIXME: LOG ACCOUNT UPDATE ACTIVITY SOMEWHERE
 			}
 
@@ -785,6 +723,10 @@ class RegisterController extends \Hubzero\Component\SiteController
 	 */
 	protected function create()
 	{
+		ximport('Hubzero_Auth_Link');
+
+		global $mainframe;
+
 		// Add the CSS to the template
 		$this->_getStyles();
 
@@ -799,21 +741,12 @@ class RegisterController extends \Hubzero\Component\SiteController
 
 		if (!$this->juser->get('guest') && !$this->juser->get('tmp_user')) 
 		{
-			$app = JFactory::getApplication();
-			$app->redirect("/members/myaccount", JText::_('COM_REGISTER_ERROR_NONGUEST_SESSION_CREATION'), "warning");
-			return;
-		}
-
-		$usersConfig =  JComponentHelper::getParams('com_users');
-		if ($usersConfig->get('allowUserRegistration') == '0') 
-		{
-			JError::raiseError(404, JText::_('JGLOBAL_RESOURCE_NOT_FOUND'));
-			return;
+			return JError::raiseError(500, JText::_('COM_REGISTER_ERROR_NONGUEST_SESSION_CREATION'));
 		}
 
 		if ($this->juser->get('auth_link_id')) 
 		{
-			$hzal = \Hubzero\Auth\Link::find_by_id($this->juser->get('auth_link_id'));
+			$hzal = Hubzero_Auth_Link::find_by_id($this->juser->get('auth_link_id'));
 		}
 		else 
 		{
@@ -821,7 +754,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 		}
 
 		// Instantiate a new registration object
-		$xregistration = new RegisterModelRegistration();
+		$xregistration = new Hubzero_Registration();
 
 		if (JRequest::getMethod() == 'POST') 
 		{
@@ -836,12 +769,13 @@ class RegisterController extends \Hubzero\Component\SiteController
 			{
 				// Get required system objects
 				$user 		= clone(JFactory::getUser());
-				$pathway 	= JFactory::getApplication()->getPathway();
-				$config		= JFactory::getConfig();
-				$authorize	= JFactory::getACL();
-				$document   = JFactory::getDocument();
+				$pathway 	=& $mainframe->getPathway();
+				$config		=& JFactory::getConfig();
+				$authorize	=& JFactory::getACL();
+				$document   =& JFactory::getDocument();
 
 				// If user registration is not allowed, show 403 not authorized.
+				$usersConfig = &JComponentHelper::getParams('com_users');
 				if ($usersConfig->get('allowUserRegistration') == '0') 
 				{
 					JError::raiseError(403, JText::_('Access Forbidden'));
@@ -852,13 +786,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 				$newUsertype = $usersConfig->get('new_usertype');
 				if (!$newUsertype) 
 				{
-					$db = JFactory::getDbo();
-					$query = $db->getQuery(true)
-						->select('id')
-						->from('#__usergroups')
-						->where('title = "Registered"');
-					$db->setQuery($query);
-					$newUsertype = $db->loadResult();
+					$newUsertype = 'Registered';
 				}
 
 				$user->set('username', $xregistration->get('login'));
@@ -873,17 +801,10 @@ class RegisterController extends \Hubzero\Component\SiteController
 
 				// Set some initial user values
 				$user->set('id', 0);
-				if (version_compare(JVERSION, '1.6', 'lt'))
-				{
-					$user->set('usertype', $newUsertype);
-					$user->set('gid', $authorize->get_group_id('', $newUsertype, 'ARO'));
-				}
-				else
-				{
-					$user->set('groups', array($newUsertype));
-				}
+				$user->set('usertype', $newUsertype);
+				$user->set('gid', $authorize->get_group_id('', $newUsertype, 'ARO'));
 
-				$date = JFactory::getDate();
+				$date =& JFactory::getDate();
 				$user->set('registerDate', $date->toMySQL());
 
 				/*
@@ -917,11 +838,11 @@ class RegisterController extends \Hubzero\Component\SiteController
 					*/
 
 					// Get some settings
-					$params = JComponentHelper::getParams('com_members');
+					$params =& JComponentHelper::getParams('com_members');
 					$hubHomeDir = rtrim($params->get('homedir'), '/');
 					
 					// Attempt to get the new user
-					$xprofile = \Hubzero\User\Profile::getInstance($user->get('id'));
+					$xprofile = Hubzero_User_Profile::getInstance($user->get('id'));
 
 					$result = is_object($xprofile);
 					
@@ -952,23 +873,12 @@ class RegisterController extends \Hubzero\Component\SiteController
 							$xprofile->setParam('return', $regReturn);
 						}
 
-						// Unset password here so that change password below can be in charge of setting it initially
-						$xprofile->set('password', '');
 						$result = $xprofile->update();
 					}
 
-					// add member interests
-					$interests = $xregistration->get('interests');
-					$mt = new MembersTags($this->database);
-					if (!empty($interests)) {
-						$mt->tag_object($xprofile->get('uidNumber'), $xprofile->get('uidNumber'), $interests, 1, 1);
-					}
-
 					if ($result) 
 					{
-						$result = \Hubzero\User\Password::changePassword($xprofile->get('uidNumber'), $xregistration->get('password'));
-						// Set password back here in case anything else down the line is looking for it
-						$xprofile->set('password', $xregistration->get('password'));
+						$result = Hubzero_User_Password::changePassword($xprofile->get('uidNumber'), $xregistration->get('password'));
 					}
 					
 					// Did we successfully create/update an account?
@@ -996,14 +906,9 @@ class RegisterController extends \Hubzero\Component\SiteController
 						$message = $eview->loadTemplate();
 						$message = str_replace("\n", "\r\n", $message);
 
-						$msg = new \Hubzero\Mail\Message();
-						$msg->setSubject($subject)
-						    ->addTo($xprofile->get('email'), $xprofile->get('name'))
-						    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-						    ->addHeader('X-Component', $this->_option)
-						    ->setBody($message);
+						$fullEmailAddress = $xprofile->get('name') . " <" . $xprofile->get('email') . ">";
 
-						if (!$msg->send()) 
+						if (!Hubzero_Toolbox::send_email($fullEmailAddress, $subject, $message)) 
 						{
 							$this->setError(JText::sprintf('COM_REGISTER_ERROR_EMAILING_CONFIRMATION'/*, $hubMonitorEmail*/));
 							// @FIXME: LOG ERROR SOMEWHERE
@@ -1021,13 +926,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 					$message = $eaview->loadTemplate();
 					$message = str_replace("\n", "\r\n", $message);
 
-					/*$msg = new \Hubzero\Mail\Message();
-					$msg->setSubject($subject)
-					    ->addTo($hubMonitorEmail)
-					    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-					    ->addHeader('X-Component', $this->_option)
-					    ->setBody($message)
-					    ->send();*/
+					// Hubzero_Toolbox::send_email($hubMonitorEmail, $subject, $message);
 					// @FIXME: LOG ACCOUNT CREATION ACTIVITY SOMEWHERE
 
 					// Instantiate a new view
@@ -1141,7 +1040,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 			default:       $index = 0; break;
 		}
 
-		$hconfig = JComponentHelper::getParams('com_register');
+		$hconfig =& JComponentHelper::getParams('com_register');
 
 		$default = str_pad($default, 4, '-');
 		$configured = $hconfig->get($name);
@@ -1194,7 +1093,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 		// Get the registration object
 		if (!is_object($xregistration)) 
 		{
-			$view->xregistration = new RegisterModelRegistration();
+			$view->xregistration = new Hubzero_Registration();
 		} 
 		else 
 		{
@@ -1203,7 +1102,8 @@ class RegisterController extends \Hubzero\Component\SiteController
 
 		// Push some values to the view
 
-		$password_rules = \Hubzero\Password\Rule::getRules();
+		ximport('Hubzero_Password_Rule');
+		$password_rules = Hubzero_Password_Rule::getRules();
 
 		$view->password_rules = array();
 
@@ -1304,7 +1204,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 		$username = JRequest::getVar('user','','post');
 
 		// Instantiate a new registration object
-		$xregistration = new RegisterModelRegistration();
+		$xregistration = new Hubzero_Registration();
 
 		// Score the password
 		$score = $xregistration->scorePassword($password, $username);
@@ -1358,7 +1258,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 		$username = JRequest::getVar('userlogin', '', 'get');
 
 		// Instantiate a new registration object
-		$xregistration = new RegisterModelRegistration();
+		$xregistration = new Hubzero_Registration();
 
 		// Check the username
 		$usernamechecked = $xregistration->checkusername($username);
@@ -1399,7 +1299,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 			return;
 		}
 
-		$xprofile = \Hubzero\User\Profile::getInstance($this->juser->get('id'));
+		$xprofile =& Hubzero_Factory::getProfile();
 		$login = $xprofile->get('username');
 		$email = $xprofile->get('email');
 		$email_confirmed = $xprofile->get('emailConfirmed');
@@ -1409,9 +1309,10 @@ class RegisterController extends \Hubzero\Component\SiteController
 
 		if (($email_confirmed != 1) && ($email_confirmed != 3)) 
 		{
-			$confirm = RegisterHelperUtility::genemailconfirm();
+			$confirm = Hubzero_Registration_Helper::genemailconfirm();
 
-			$xprofile = new \Hubzero\User\Profile();
+			ximport('Hubzero_User_Profile');
+			$xprofile = new Hubzero_User_Profile();
 			$xprofile->load($login);
 			$xprofile->set('emailConfirmed', $confirm);
 			$xprofile->update();
@@ -1427,14 +1328,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 			$message = $eview->loadTemplate();
 			$message = str_replace("\n", "\r\n", $message);
 
-			$msg = new \Hubzero\Mail\Message();
-			$msg->setSubject($subject)
-			    ->addTo($email)
-			    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-			    ->addHeader('X-Component', $this->_option)
-			    ->setBody($message);
-
-			if (!$msg->send()) 
+			if (!Hubzero_Toolbox::send_email($email, $subject, $message)) 
 			{
 				$this->setError(JText::sprintf('COM_REGISTER_ERROR_EMAILING_CONFIRMATION', $email));
 			}
@@ -1493,7 +1387,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 			return;
 		}
 
-		$xprofile = \Hubzero\User\Profile::getInstance($this->juser->get('id'));
+		$xprofile =& Hubzero_Factory::getProfile();
 		$login = $xprofile->get('username');
 		$email = $xprofile->get('email');
 		$email_confirmed = $xprofile->get('emailConfirmed');
@@ -1504,14 +1398,13 @@ class RegisterController extends \Hubzero\Component\SiteController
 		$view->title = JText::_('COM_REGISTER_CHANGE');
 		$view->login = $login;
 		$view->email = $email;
+		$view->return = $return;
 		$view->email_confirmed = $email_confirmed;
 		$view->success = false;
 
 		// Incoming
 		$return = urldecode(JRequest::getVar('return', '/'));
 
-		$view->return = $return;
-
 		// Check if a new email was submitted
 		$pemail = JRequest::getVar('email', '', 'post');
 		$update = JRequest::getVar('update', '', 'post');
@@ -1522,7 +1415,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 			{
 				$this->setError(JText::_('COM_REGISTER_ERROR_INVALID_EMAIL'));
 			}
-			if ($pemail && RegisterHelperUtility::validemail($pemail) /*&& ($newemail != $email)*/) 
+			if ($pemail && Hubzero_Registration_Helper::validemail($pemail) /*&& ($newemail != $email)*/) 
 			{
 				// Check if the email address was actually changed
 				if ($pemail == $email) 
@@ -1533,15 +1426,15 @@ class RegisterController extends \Hubzero\Component\SiteController
 				else 
 				{
 					// New email submitted - attempt to save it
-					$xprofile = \Hubzero\User\Profile::getInstance($login);
+					$xprofile =& Hubzero_User_Profile::getInstance($login);
 					if ($xprofile) 
 					{
-						$dtmodify = JFactory::getDate()->toSql();
+						$dtmodify = date("Y-m-d H:i:s");
 						$xprofile->set('email',$pemail);
 						$xprofile->set('modifiedDate',$dtmodify);
 						if ($xprofile->update()) 
 						{
-							$juser = JUser::getInstance($login);
+							$juser =& JUser::getInstance($login);
 							$juser->set('email', $pemail);
 							$juser->save();
 						} 
@@ -1560,9 +1453,10 @@ class RegisterController extends \Hubzero\Component\SiteController
 					{
 						// No errors
 						// Attempt to send a new confirmation code
-						$confirm = RegisterHelperUtility::genemailconfirm();
+						$confirm = Hubzero_Registration_Helper::genemailconfirm();
 
-						$xprofile = new \Hubzero\User\Profile();
+						ximport('Hubzero_User_Profile');
+						$xprofile = new Hubzero_User_Profile();
 						$xprofile->load($login);
 						$xprofile->set('emailConfirmed', $confirm);
 						$xprofile->update();
@@ -1578,14 +1472,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 						$message = $eview->loadTemplate();
 						$message = str_replace("\n", "\r\n", $message);
 
-						$msg = new \Hubzero\Mail\Message();
-						$msg->setSubject($subject)
-						    ->addTo($pemail)
-						    ->addFrom($this->jconfig->getValue('config.mailfrom'), $this->jconfig->getValue('config.sitename') . ' Administrator')
-						    ->addHeader('X-Component', $this->_option)
-						    ->setBody($message);
-
-						if (!$msg->send()) 
+						if (!Hubzero_Toolbox::send_email($pemail, $subject, $message)) 
 						{
 							$this->setError(JText::sprintf('COM_REGISTER_ERROR_EMAILING_CONFIRMATION', $pemail));
 						}
@@ -1649,75 +1536,52 @@ class RegisterController extends \Hubzero\Component\SiteController
 			return;
 		}
 
-		$xprofile = \Hubzero\User\Profile::getInstance($this->juser->get('id'));
+		$xprofile =& Hubzero_Factory::getProfile();
 
 		$email_confirmed = $xprofile->get('emailConfirmed');
 
 		if (($email_confirmed == 1) || ($email_confirmed == 3)) 
 		{
-			// The current user is confirmed - check to see if the incoming code is valid at all
-			if (RegisterHelperUtility::isActiveCode($code))
-			{
-				$this->setError('login mismatch');
-
-				// Build logout/login/confirm redirect flow
-				$login_return  = base64_encode(JRoute::_('index.php?option=' . $this->option . '&task=' . $this->_task . '&confirm=' . $code));
-				$logout_return = base64_encode(JRoute::_('index.php?option=com_login&return=' . $login_return));
-
-				$redirect = JRoute::_('index.php?option=com_logout&return=' . $logout_return);
-			}
+			// All is well
 		} 
 		elseif ($email_confirmed < 0 && $email_confirmed == -$code) 
 		{
-			//var to hold return path
-			$return = '';
-			
-			// get com_register return path
-			$hconfig =  JComponentHelper::getParams('com_register');
-			$cReturn = $hconfig->get('ConfirmationReturn');
-			if ($cReturn) 
-			{
-				$return = $cReturn;
-			}
-			
-			//load user profile
-			$profile = new \Hubzero\User\Profile();
+			ximport('Hubzero_User_Profile');
+			$profile = new Hubzero_User_Profile();
 			$profile->load($xprofile->get('username'));
-			
-			//check to see if we have a return param
-			$pReturn = base64_decode(urldecode($profile->getParam('return')));
-			if ($pReturn) 
+
+			$myreturn = base64_decode($profile->getParam('return'));
+			if ($myreturn) 
 			{
-				$return = $pReturn;
 				$profile->setParam('return','');
 			}
-			
-			// make as confirmed
 			$profile->set('emailConfirmed', 1);
-			
-			// set public setting
-			$mconfig = JComponentHelper::getParams('com_members');
+
+			$mconfig =& JComponentHelper::getParams('com_members');
 			$profile->set('public', $mconfig->get('privacy', '0'));
-			
-			// upload profile
+
 			if (!$profile->update()) 
 			{
 				$this->setError(JText::_('COM_REGISTER_ERROR_CONFIRMING'));
 			}
-			
-			// Redirect
-			if (empty($return)) 
+
+			$hconfig = &JComponentHelper::getParams('com_register');
+
+			// Override any other return settings if $return is explicitly set
+			$return = $hconfig->get('ConfirmationReturn');
+			if ($return) 
 			{
-				$r = $hconfig->get('LoginReturn');
-				$return = ($r) ? $r : JRoute::_('index.php?option=com_members&task=myaccount');
-				// consume cookie (yum) if available to return to whatever action prompted registration
-				if (isset($_COOKIE['return'])) {
-					$return = $_COOKIE['return'];
-					setcookie('return', '', time() - 3600);
-				}
+				$myreturn = $return;
 			}
 
-			$app->redirect($return,'','message',true);
+			// Redirect
+			if (empty($myreturn)) 
+			{
+				$r = $hconfig->get('LoginReturn');
+				$myreturn = ($r) ? $r : JRoute::_('index.php?option=com_members&task=myaccount');
+			}
+
+			$app->redirect($myreturn,'','message',true);
 		} 
 		else 
 		{
@@ -1731,7 +1595,6 @@ class RegisterController extends \Hubzero\Component\SiteController
 		$view->login    = $xprofile->get('username');
 		$view->email    = $xprofile->get('email');
 		$view->code     = $code;
-		$view->redirect = ($redirect) ? $redirect : '';
 		$view->sitename = $this->jconfig->getValue('config.sitename');
 		if ($this->getError()) 
 		{
@@ -1747,7 +1610,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 	 */
 	protected function unconfirmed()
 	{
-		$xprofile = \Hubzero\User\Profile::getInstance($this->juser->get('id'));
+		$xprofile =& Hubzero_Factory::getProfile();
 		$email_confirmed = $xprofile->get('emailConfirmed');
 
 		// Incoming
@@ -1806,7 +1669,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 	 */
 	protected function _buildPathway()
 	{
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 
 		if (count($pathway->getPathWay()) <= 0) 
 		{
@@ -1839,7 +1702,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 		{
 			$title = JText::_('COM_REGISTER');
 		}
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($title);
 	}
 
@@ -1851,7 +1714,7 @@ class RegisterController extends \Hubzero\Component\SiteController
 	private function _cookie_check()
 	{
 		$app = JFactory::getApplication();
-		$jsession = JFactory::getSession();
+		$jsession =& JFactory::getSession();
 		$jcookie = $jsession->getName();
 
 		if (!isset($_COOKIE[$jcookie])) 
