@@ -31,6 +31,10 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+	ximport('Hubzero_User_Helper');
+	ximport('Hubzero_Environment');
+	ximport('Hubzero_Geo');
+
 	$html  = '<div id="content-header" class="full">'."\n";
 	$html .= "\t".'<h2>'.JText::_('COM_REGISTER_'.strtoupper($this->task)).'</h2>'."\n";
 	$html .= '</div><!-- / #content-header -->'."\n";
@@ -52,7 +56,7 @@ defined('_JEXEC') or die('Restricted access');
 
 		case 'edit':
 			if ($this->self) {
-				$juser = JFactory::getUser();
+				$juser =& JFactory::getUser();
 
 				$html .= '<div class="help">'."\n";
 				$html .= "\t".'<h4>How do I change my password?</h4>'."\n";
@@ -63,12 +67,12 @@ defined('_JEXEC') or die('Restricted access');
 
 		case 'proxycreate':
 			$html .= '<div class="help">'."\n";
-			$html .= "\t".'<h4>Proxy Account Creation Instructions</h4>'."\n";
+			$html .= "\t".'<h4>Proxy Account Creation Questions</h4>'."\n";
 			$html .= "\t".'<p>Simply fill out the form below and an account will be created for that person. ';
 			$html .= 'You will then be shown the basic text of an email which you <strong>MUST</strong> then copy ';
-			$html .= 'and paste and send to that person. This email will provide them with the initial password ';
-			$html .= 'set for them below as well as their email confirmation link. You may add any other information ';
-			$html .= 'that you deem appropriate, including contributed resources or the reason for their account.</p>'."\n";
+			$html .= 'and paste and send to that person. This email will provide them a random initial password ';
+			$html .= 'and their email confirmation link, and you may add any other information about contributed ';
+			$html .= 'resources or the reason for their account you deem appropriate.</p>'."\n";
 			//$html .= "\t".'<h4>What if I need to find the contents of the email to the user again?</h4>'."\n";
 			//$html .= "\t".'<p>You can retrieve the same email template and contents at any time from the user\'s ';
 			//$html .= '<a href="'.JRoute::_('index.php?option=com_members&task=whois').'">whois page</a>, under their confirmation email.</p>'."\n";
@@ -95,57 +99,14 @@ defined('_JEXEC') or die('Restricted access');
 	$html .= '<form action="'. $form_action .'" method="post" id="hubForm">'."\n";
 
 
-	$emailusers = \Hubzero\User\Profile\Helper::find_by_email($this->registration['email']);
-
-	if($this->task == 'create' && empty($this->xregistration->_invalid) && empty($this->xregistration->_missing)) {
-		// Check to see if third party auth plugins are enabled
-		$plugins        = JPluginHelper::getPlugin('authentication');
-		$authenticators = array();
-
-		foreach($plugins as $p)
-		{
-			if($p->name != 'hubzero')
-			{
-				$paramsClass = 'JParameter';
-				if (version_compare(JVERSION, '1.6', 'ge'))
-				{
-					$paramsClass = 'JRegistry';
-				}
-
-				$pparams = new $paramsClass($p->params);
-				$display = $pparams->get('display_name', ucfirst($p->name));
-				$authenticators[] = array('name' => $p->name, 'display' => $display);
-			}
-		}
-
-		// There are third party plugins, so show them on the registration form
-		if(!empty($authenticators))
-		{
-			$doc = JFactory::getDocument();
-			$com_users = (version_compare(JVERSION, '1.6', 'ge')) ? 'com_users' : 'com_user';
-			$doc->addStylesheet(DS . 'components' . DS . $com_users . DS . 'assets' . DS . 'css' . DS . 'providers.css');
-			$html .= '<div class="explaination"><p class="info">You can choose to log in via one of these services, and we\'ll help you fill in the info below!</p></div>';
-			$html .= '<fieldset>';
-			$html .= '<legend>Connect With</legend>';
-			$html .= '<div id="providers">';
-			foreach($authenticators as $a)
-			{
-				$html .= '<a class="account-group" id="'.$a['name'].'" href="'.JRoute::_('index.php?option='.$com_users.'&view=login&authenticator='.$a['name']).'">';
-				$html .= '<p>'.$a['display'].' account</p>';
-				$html .= '</a>';
-			}
-			$html .= '</div>';
-			$html .= '</fieldset>';
-			$html .= '<div class="clear"></div>';
-		}
-	}
+	$emailusers = Hubzero_User_Profile_Helper::find_by_email($this->registration['email']);
 
 	if (($this->task == 'create' || $this->task == 'proxycreate') && $emailusers) {
 		$html .= '<div class="error">'."\n";
-		$html .= "\t".'<p>The email address "' . htmlentities($this->registration['email'],ENT_COMPAT,'UTF-8') . '" is already registered. If you have lost or forgotten this ' . $this->sitename . ' login information, we can help you recover it:</p>'."\n";
-		$html .= "\t".'<p class="submit"><a href="' . JRoute::_('index.php?option=com_users&view=remind') . '" class="btn btn-danger">Email Existing Account Information</a>'."\n";
+		$html .= "\t".'<p>The email address "' . htmlentities($this->registration['email'],ENT_COMPAT,'UTF-8') . '" is already registered. If you have lost or forgotten this ' . $this->sitename . ' login information, we can resend it to you at that email address now:</p>'."\n";
+		$html .= "\t".'<p class="submit"><input type="submit" name="resend" value="Email Existing Account Information" /></p>'."\n";
 		$html .= "\t".'<p>If you are aware you already have another account registered to this email address, and are requesting another account because you need more resources, ' . $this->sitename . ' would be happy to work with you to raise your resource limits instead:</p>'."\n";
-		$html .= "\t".'<p class="submit"><a href="' . JRoute::_('index.php?option=com_support&controller=tickets&task=new') . '" class="btn btn-danger">Submit Request to Raise Existing Limits</a></p>'."\n";
+		$html .= "\t".'<p class="submit"><input type="submit" name="raiselimit" value="Raise Existing Resource Limits" /></p>'."\n";
 		$html .= '</div>'."\n";
 	}
 
@@ -171,20 +132,20 @@ defined('_JEXEC') or die('Restricted access');
 	// Login information
 	if ($this->registrationUsername != REG_HIDE || $this->registrationPassword != REG_HIDE) {
 		$html .= "\t".'<div class="explaination">'."\n";
-		$html .= "\t\t".'<p>' . JText::_('COM_REGISTER_CANNOT_CHANGE_USERNAME') . '</p>'."\n";
+		$html .= "\t\t".'<p>Usernames cannot be changed. If this poses a serious problem or raises concerns please contact our <a href="support/">support</a>.</p>'."\n";
 
 		if ($this->task == 'create' || $this->task == 'proxycreate') {
-			$html .= "\t\t".'<p>'.JText::_('COM_REGISTER_PASSWORD_CHANGE_HINT').'</p>'."\n";
+			$html .= "\t\t".'<p>'.JText::_('Password may be changed any time after account creation.').'</p>'."\n";
 		}
 
 		$html .= "\t".'</div>'."\n";
 
 		$html .= "\t".'<fieldset>'."\n";
-		$html .= "\t\t".'<legend>'.JText::_('COM_REGISTER_LOGIN_INFORMATION').'</legend>'."\n";
+		$html .= "\t\t".'<legend>'.JText::_('Login Information').'</legend>'."\n";
 
 		// Username
 		if ($this->registrationUsername == REG_READONLY) {
-			$html .= "\t\t".'<label>'.JText::_('COM_REGISTER_USER_LOGIN').': '."\n";
+			$html .= "\t\t".'<label>'.JText::_('User Login').': '."\n";
 			$html .= "\t\t\t".htmlentities($this->registration['login'],ENT_COMPAT,'UTF-8')."\n";
 			$html .= "\t\t\t".'<input name="login" id="login" type="hidden" value="'. htmlentities($this->registration['login'],ENT_COMPAT,'UTF-8') .'" />'."\n";
 			$html .= "\t\t".'</label>'."\n";
@@ -195,11 +156,11 @@ defined('_JEXEC') or die('Restricted access');
 
 			$html .= "\t\t".'<div class="group">'."\n";
 			$html .= "\t\t\t".'<label '.$fieldclass.'>'."\n";
-			$html .= "\t\t\t\t".JText::_('COM_REGISTER_USER_LOGIN').': '.$required."\n";
+			$html .= "\t\t\t\t".JText::_('User Login').': '.$required."\n";
 			$html .= "\t\t\t\t".'<input name="login" id="userlogin" type="text" maxlength="32" value="'.htmlentities($this->registration['login'],ENT_COMPAT,'UTF-8') .'" />' ."\n";
 			$html .= ($message) ? "\t\t\t\t" . $message . "\n" : '';
 			$html .= "\t\t\t".'</label>'."\n";
-			$html .= "\t\t\t".'<p class="hint" id="usernameHint">'.JText::_('COM_REGISTER_USERNAME_HINT').'</p>'."\n";
+			$html .= "\t\t\t".'<p class="hint" id="usernameHint">'.JText::_('Combination of lowercase letters and numbers. No spaces or punctuation.').'</p>'."\n";
 			$html .= "\t\t".'</div>'."\n";
 		}
 
@@ -216,7 +177,7 @@ defined('_JEXEC') or die('Restricted access');
 
 			$html .= "\t\t".'<div class="group">'."\n";
 			$html .= "\t\t\t".'<label '.$fieldclass.'>'."\n";
-			$html .= "\t\t\t\t".JText::_('COM_REGISTER_PASSWORD').': '.$required."\n";
+			$html .= "\t\t\t\t".JText::_('Password').': '.$required."\n";
 			$html .= "\t\t\t\t".'<input name="password" id="password" type="password" value="'. htmlentities($this->registration['password'],ENT_COMPAT,'UTF-8') .'" />'."\n";
 			$html .= ($message) ? "\t\t\t\t" . $message . "\n" : '';
 			$html .= "\t\t\t".'</label>'."\n";
@@ -228,7 +189,7 @@ defined('_JEXEC') or die('Restricted access');
 				$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 				$html .= "\t\t\t".'<label '.$fieldclass.'>'."\n";
-				$html .= "\t\t\t\t".JText::_('COM_REGISTER_CONFIRM_PASSWORD').': '.$required."\n";
+				$html .= "\t\t\t\t".JText::_('Confirm Password').': '.$required."\n";
 				$html .= "\t\t\t\t".'<input name="password2" id="password2" type="password" value="'. htmlentities($this->registration['confirmPassword'],ENT_COMPAT,'UTF-8') .'" />'."\n";
 				$html .= ($message) ? "\t\t\t\t" . $message . "\n" : '';
 				$html .= "\t\t\t".'</label>'."\n";
@@ -261,7 +222,7 @@ defined('_JEXEC') or die('Restricted access');
 				$html .= "\t\t"."</ul>"."\n";
 			}
 		}
-		$hconfig = JComponentHelper::getParams('com_register');
+		$hconfig =& JComponentHelper::getParams('com_register');
 		if ($hconfig->get('passwordMeter')) {
 			$html .= "\t".'<input type="hidden" id="passmeter" value="on" />'."\n";
 		}
@@ -277,13 +238,15 @@ defined('_JEXEC') or die('Restricted access');
 		$html .= "\t".'<div class="explaination">'."\n";
 
 		if ($this->task == 'create') {
-			$html .= "\t\t".'<p>'.JText::_('COM_REGISTER_ACTIVATION_EMAIL_HINT').'</p>'."\n";
+			$html .= "\t\t".'<p>Once you create an account, you will be sent an email containing an activation link.</p>'."\n";
+		} else if ($this->task == 'proxycreate') {
+			$html .= "\t\t".'<p>Once you create an account, the new account owner will be sent an email containing an activation link.</p>'."\n";
 		}
-		$html .= "\t\t".'<p>'.JText::_('COM_REGISTER_PRIVACY_HINT').'</p>'."\n";
+		$html .= "\t\t".'<p>We respect your privacy, and will never disclose your sensitive information to others.</p>'."\n";
 		$html .= "\t".'</div>'."\n";
 
 		$html .= "\t".'<fieldset>'."\n";
-		$html .= "\t\t".'<legend>'.JText::_('COM_REGISTER_CONTACT_INFORMATION').'</legend>'."\n";
+		$html .= "\t\t".'<legend>'.JText::_('Contact Information').'</legend>'."\n";
 
 		// Name
 		if ($this->registrationFullname != REG_HIDE) {
@@ -306,15 +269,15 @@ defined('_JEXEC') or die('Restricted access');
 
 			$html .= "\t\t".'<div class="threeup group">'."\n";
 			$html .= "\t\t\t".'<label'.$fieldclass.'>'."\n";
-			$html .= "\t\t\t\t".JText::_('COM_REGISTER_FIRST_NAME').': '.$required."\n";
+			$html .= "\t\t\t\t".JText::_('First Name').': '.$required."\n";
 			$html .= "\t\t\t\t".'<input type="text" name="name[first]" value="'. htmlentities(trim($givenName), ENT_COMPAT, 'UTF-8') .'" />'."\n";
 			$html .= "\t\t\t".'</label>'."\n";
 			$html .= "\t\t\t".'<label>'."\n";
-			$html .= "\t\t\t\t".JText::_('COM_REGISTER_MIDDLE_NAME').':'."\n";
+			$html .= "\t\t\t\t".JText::_('Middle Name').':'."\n";
 			$html .= "\t\t\t\t".'<input type="text" name="name[middle]" value="'. htmlentities(trim($middleName), ENT_COMPAT, 'UTF-8') .'" />'."\n";
 			$html .= "\t\t\t".'</label>'."\n";
 			$html .= "\t\t\t".'<label'.$fieldclass.'>'."\n";
-			$html .= "\t\t\t\t".JText::_('COM_REGISTER_LAST_NAME').': '."\n";
+			$html .= "\t\t\t\t".JText::_('Last Name').': '.$required."\n";
 			$html .= "\t\t\t\t".'<input type="text" name="name[last]" value="'. htmlentities(trim($surname), ENT_COMPAT, 'UTF-8') .'" />'."\n";
 			$html .= "\t\t\t".'</label>'."\n";
 			$html .= "\t\t".'</div>'."\n";
@@ -332,7 +295,7 @@ defined('_JEXEC') or die('Restricted access');
 				$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 				$html .= "\t\t\t".'<label '.$fieldclass.'>'."\n";
-				$html .= "\t\t\t\t".JText::_('COM_REGISTER_VALID_EMAIL').': '.$required."\n";
+				$html .= "\t\t\t\t".JText::_('Valid E-mail').': '.$required."\n";
 				$html .= "\t\t\t\t".'<input name="email" id="email" type="text" value="'.htmlentities($this->registration['email'],ENT_COMPAT,'UTF-8').'" />'."\n";
 				$html .= ($message) ? "\t\t\t\t" . $message . "\n" : '';
 				$html .= "\t\t\t".'</label>'."\n";
@@ -354,7 +317,7 @@ defined('_JEXEC') or die('Restricted access');
 				$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 				$html .= "\t\t\t".'<label'.$fieldclass.'>'."\n";
-				$html .= "\t\t\t\t".JText::_('COM_REGISTER_CONFIRM_EMAIL').': '.$required."\n";
+				$html .= "\t\t\t\t".JText::_('Confirm E-mail').': '.$required."\n";
 				$html .= "\t\t\t\t".'<input name="email2" id="email2" type="text" value="'.htmlentities($this->registration['confirmEmail'],ENT_COMPAT,'UTF-8').'" />'."\n";
 				$html .= ($message) ? "\t\t\t\t" . $message . "\n" : '';
 				$html .= "\t\t\t".'</label>'."\n";
@@ -363,11 +326,11 @@ defined('_JEXEC') or die('Restricted access');
 			$html .= "\t\t".'</div>'."\n";
 
 			if ($this->registrationEmail != REG_HIDE) {
-				$jconfig = JFactory::getConfig();
+				$jconfig =& JFactory::getConfig();
 				if ($this->task == 'proxycreate') {
-					$html .= "\t\t".RegistrationHelperHtml::warning('Important! The user <strong>MUST</strong> click on the email confirmation link that you will send them in order for them to start using the account you have created for them.');
+					$html .= "\t\t".RegistrationHelperHtml::warning('Important! The user <strong>must</strong> confirm receipt of confirmation e-mail from '.RegistrationHelperHtml::obfuscate($jconfig->getValue('config.mailfrom')).' in order to complete registration.');
 				} else if ($this->task == 'create') {
-					$html .= "\t\t".RegistrationHelperHtml::warning(JText::sprintf('COM_REGISTER_YOU_MUST_CONFIRM_EMAIL', RegistrationHelperHtml::obfuscate($jconfig->getValue('config.mailfrom'))));
+					$html .= "\t\t".RegistrationHelperHtml::warning('Important! You <strong>must</strong> confirm receipt of confirmation e-mail from '.RegistrationHelperHtml::obfuscate($jconfig->getValue('config.mailfrom')).' in order to complete registration.');
 				} else {
 					$html .= "\t\t".RegistrationHelperHtml::warning('Important! If you change your e-mail address you <strong>must</strong> confirm receipt of the confirmation e-mail from '.RegistrationHelperHtml::obfuscate($jconfig->getValue('config.mailfrom')).' in order to re-activate your account.');
 				}
@@ -435,11 +398,11 @@ defined('_JEXEC') or die('Restricted access');
 			$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
 
 			$html .= "\t\t\t" . '<label' . $fieldclass . '>' . "\n";
-			$html .= "\t\t\t\t" . JText::_('Employment Type') . ': ' . $required . "\n";
+			$html .= "\t\t\t\t" . JText::_('Employment Status') . ': ' . $required . "\n";
 			$html .= "\t\t\t\t" . '<select name="orgtype" id="orgtype">' . "\n";
 
 			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_register' . DS . 'tables' . DS . 'organizationtype.php');
-			$database = JFactory::getDBO();
+			$database =& JFactory::getDBO();
 			$rot = new RegisterOrganizationType($database);
 			$types = $rot->getTypes();
 
@@ -488,7 +451,7 @@ defined('_JEXEC') or die('Restricted access');
 			$org_known = 0;
 
 			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_register' . DS . 'tables' . DS . 'organization.php');
-			$database = JFactory::getDBO();
+			$database =& JFactory::getDBO();
 			$xo = new RegisterOrganization($database);
 			$orgs = $xo->getOrgs();
 
@@ -573,78 +536,58 @@ defined('_JEXEC') or die('Restricted access');
 		if ($this->registrationInterests != REG_HIDE) {
 			$required = ($this->registrationInterests == REG_REQUIRED) ? '<span class="required">'.JText::_('COM_REGISTER_FORM_REQUIRED').'</span>' : '';
 			$message = (!empty($this->xregistration->_invalid['interests'])) ? RegistrationHelperHtml::error($this->xregistration->_invalid['interests']) : '';
-			$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
+			$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 
-			// if (!is_array($this->registration['edulevel']))
-			// 	$this->registration['edulevel'] = array();
+			if (!is_array($this->registration['edulevel']))
+				$this->registration['edulevel'] = array();
 
-			// if (!is_array($this->registration['role']))
-			// 	$this->registration['role'] = array();
+			if (!is_array($this->registration['role']))
+				$this->registration['role'] = array();
 
-			// $html .= "\t\t".'<fieldset'.$fieldclass.'>'."\n";
-			// $html .= "\t\t\t".'<legend>'.JText::_('What are you interested in?').' '.$required.'</legend>'."\n";
+			$html .= "\t\t".'<fieldset'.$fieldclass.'>'."\n";
+			$html .= "\t\t\t".'<legend>'.JText::_('What are you interested in?').' '.$required.'</legend>'."\n";
 
-			// $html .= "\t\t\t".'<p class="hint">'.JText::_('Materials for ... (Check all roles and levels you are interested in.)').'</p>'."\n";
+			$html .= "\t\t\t".'<p class="hint">'.JText::_('Materials for ... (Check all roles and levels you are interested in.)').'</p>'."\n";
 
-			// $html .= "\t\t\t".'<input type="hidden" name="interests" value="unspecified" />'."\n";
+			$html .= "\t\t\t".'<input type="hidden" name="interests" value="unspecified" />'."\n";
 
-			// $html .= "\t\t\t".'<label><input type="checkbox" class="option" name="rolestudent" id="rolestudent" ';
-			// if (in_array("student", $this->registration['role']))
-			// 	$html .= 'checked="checked" value="on"';
-			// $html .= '/> '.JText::_('Students').'</label>'."\n";
+			$html .= "\t\t\t".'<label><input type="checkbox" class="option" name="rolestudent" id="rolestudent" ';
+			if (in_array("student", $this->registration['role']))
+				$html .= 'checked="checked" value="on"';
+			$html .= '/> '.JText::_('Students').'</label>'."\n";
 
-			// $html .= "\t\t\t".'<label><input type="checkbox" class="option" name="roleeducator" id="roleeducator" ';
-			// if (in_array("educator", $this->registration['role']))
-			// 	$html .= 'checked="checked" value="on"';
-			// $html .= '/> '.JText::_('Educators').'</label>'."\n";
+			$html .= "\t\t\t".'<label><input type="checkbox" class="option" name="roleeducator" id="roleeducator" ';
+			if (in_array("educator", $this->registration['role']))
+				$html .= 'checked="checked" value="on"';
+			$html .= '/> '.JText::_('Educators').'</label>'."\n";
 
-			// $html .= "\t\t\t".'<label><input type="checkbox" class="option" name="roleresearcher" id="roleresearcher" ';
-			// if (in_array("researcher", $this->registration['role']))
-			// 	$html .= 'checked="checked" value="on"';
-			// $html .= '/> '.JText::_('Researchers').'</label>'."\n";
+			$html .= "\t\t\t".'<label><input type="checkbox" class="option" name="roleresearcher" id="roleresearcher" ';
+			if (in_array("researcher", $this->registration['role']))
+				$html .= 'checked="checked" value="on"';
+			$html .= '/> '.JText::_('Researchers').'</label>'."\n";
 
-			// $html .= "\t\t\t".'<label><input type="checkbox" class="option" name="roledeveloper" id="roledeveloper" ';
-			// if (in_array("developer", $this->registration['role']))
-			// 	$html .= 'checked="checked" value="on"';
-			// $html .= '/> '.JText::_('Developers').'</label>'."\n";
+			$html .= "\t\t\t".'<label><input type="checkbox" class="option" name="roledeveloper" id="roledeveloper" ';
+			if (in_array("developer", $this->registration['role']))
+				$html .= 'checked="checked" value="on"';
+			$html .= '/> '.JText::_('Developers').'</label>'."\n";
 
-			// $html .= "\t\t\t".'<label><input type="checkbox" class="option" name="edulevelk12" id="edulevelk12" ';
-			// if (in_array("k12", $this->registration['edulevel']))
-			// 	$html .= 'checked="checked" value="on"';
-			// $html .= '/> '.JText::_('K - 12 (Pre-College)').'</label>'."\n";
+			$html .= "\t\t\t".'<label><input type="checkbox" class="option" name="edulevelk12" id="edulevelk12" ';
+			if (in_array("k12", $this->registration['edulevel']))
+				$html .= 'checked="checked" value="on"';
+			$html .= '/> '.JText::_('K - 12 (Pre-College)').'</label>'."\n";
 
-			// $html .= "\t\t\t".'<label><input type="checkbox" class="option" name="edulevelundergraduate" id="edulevelundergraduate" ';
-			// if (in_array("undergraduate", $this->registration['edulevel']))
-			// 	$html .= 'checked="checked" value="on"';
-			// $html .= '/> '.JText::_('Undergraduate').'</label>'."\n";
+			$html .= "\t\t\t".'<label><input type="checkbox" class="option" name="edulevelundergraduate" id="edulevelundergraduate" ';
+			if (in_array("undergraduate", $this->registration['edulevel']))
+				$html .= 'checked="checked" value="on"';
+			$html .= '/> '.JText::_('Undergraduate').'</label>'."\n";
 
-			// $html .= "\t\t\t".'<label><input type="checkbox" class="option" name="edulevelgraduate" id="edulevelgraduate" ';
-			// if (in_array("graduate", $this->registration['edulevel']))
-			// 	$html .= 'checked="checked" value="on"';
-			// $html .= '/> '.JText::_('Graduate / Professional').'</label>'."\n";
+			$html .= "\t\t\t".'<label><input type="checkbox" class="option" name="edulevelgraduate" id="edulevelgraduate" ';
+			if (in_array("graduate", $this->registration['edulevel']))
+				$html .= 'checked="checked" value="on"';
+			$html .= '/> '.JText::_('Graduate / Professional').'</label>'."\n";
 
-			// $html .= ($message) ? "\t\t\t" . $message . "\n" : '';
-			// $html .= "\t\t".'</fieldset>'."\n";
-			
-			// get tags string
-			$tags = $this->registration['interests'];
-
-			// instantiate tag autocompleter
-			JPluginHelper::importPlugin( 'hubzero' );
-			$dispatcher = JDispatcher::getInstance();
-			$tf = $dispatcher->trigger( 'onGetMultiEntry', array(array('tags', 'interests', 'actags','',stripslashes($tags))) );
-			
-			// output html input for interests
-			$html .= "\t\t".'<label '.$fieldclass.'>'."\n";
-			$html .= "\t\t\t".JText::_('What are you interested in?').': '.$required."\n";;
-			if (count($tf) > 0) 
-			{
-				$html .= $tf[0];
-			} else 
-			{
-				$html .= "\t\t\t".'<input type="text" name="interests" value="'. $this->escape($tags) .'" />'."\n";
-			}
-			$html .= "\t\t".'</label>'."\n";
+			$html .= ($message) ? "\t\t\t" . $message . "\n" : '';
+			$html .= "\t\t".'</fieldset>'."\n";
 		}
 		$html .= "\t".'</fieldset><div class="clear"></div>'."\n";
 	}
@@ -678,7 +621,7 @@ defined('_JEXEC') or die('Restricted access');
 			$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 
 			if (!$this->registration['countryorigin']) {
-				$userCountry = \Hubzero\Geocode\Geocode::ipcountry(JRequest::ip());
+				$userCountry = Hubzero_Geo::ipcountry(Hubzero_Environment::ipAddress());
 				$this->registration['countryorigin'] = $userCountry;
 			}
 
@@ -708,7 +651,7 @@ defined('_JEXEC') or die('Restricted access');
 				$html .= "\t\t\t\t\t".'<option value="">'.JText::_('COM_REGISTER_FORM_SELECT_FROM_LIST').'</option>'."\n";
 			}
 
-			$countries = \Hubzero\Geocode\Geocode::getcountries();
+			$countries = Hubzero_Geo::getcountries();
 			if ($countries) {
 				foreach ($countries as $country)
 				{
@@ -733,8 +676,8 @@ defined('_JEXEC') or die('Restricted access');
 			$fieldclass = ($message) ? ' class="fieldsWithErrors"' : '';
 
 			if (!$this->registration['countryresident']) {
-				if (!isset($userCountry) || !$userCountry) {
-					$userCountry = \Hubzero\Geocode\Geocode::ipcountry(JRequest::ip());
+				if (!$userCountry) {
+					$userCountry = Hubzero_Geo::ipcountry(Hubzero_Environment::ipAddress());
 				}
 				$this->registration['countryresident'] = $userCountry;
 			}
@@ -762,8 +705,8 @@ defined('_JEXEC') or die('Restricted access');
 				$html .= "\t\t\t\t\t".'<option value="">'.JText::_('COM_REGISTER_FORM_SELECT_FROM_LIST').'</option>'."\n";
 			}
 
-			if (!isset($countries) || !$countries) {
-				$countries = \Hubzero\Geocode\Geocode::getcountries();
+			if (!$countries) {
+				$countries = Hubzero_Geo::getcountries();
 			}
 			if ($countries) {
 				foreach ($countries as $country) {
@@ -1025,32 +968,15 @@ defined('_JEXEC') or die('Restricted access');
 		$required = ($this->registrationOptIn == REG_REQUIRED) ? '<span class="required">'.JText::_('COM_REGISTER_FORM_REQUIRED').'</span>' : '';
 		$message = (!empty($this->xregistration->_invalid['mailPreferenceOption'])) ? RegistrationHelperHtml::error($this->xregistration->_invalid['mailPreferenceOption']) : '';
 		$fieldclass = ($message) ? ' class="fieldWithErrors"' : '';
-		
-		//define mail preference options
-		$options = array(
-			'-1' => '- Select email option &mdash;',
-			'1'  => 'Yes, send me emails',
-			'0'  => 'No, don\'t send me emails'
-		);
-		
-		//if we dont have a mail pref option set to unanswered
-		if(!isset($this->registration['mailPreferenceOption']) || $this->registration['mailPreferenceOption'] == '')
-		{
-			$this->registration['mailPreferenceOption'] = '-1';
-		}
-		
+
 		$html .= "\t".'<fieldset>'."\n";
-		$html .= "\t\t".'<legend>'.JText::_('Receive Email Updates').'</legend>'."\n";
-		$html .= '<label for="mailPreferenceOption">';
-		$html .= 'Would you like to receive email updates (newsletters, etc.)? ' . $required;
-		$html .= '<select name="mailPreferenceOption">';
-		foreach ($options as $key => $value)
-		{
-			$sel = ($key == $this->registration['mailPreferenceOption']) ? 'selected="selected"' : '';
-			$html .= '<option '.$sel.' value="'. $key .'">' . $value . '</option>';
+		$html .= "\t\t".'<legend>'.JText::_('Updates').'</legend>'."\n";
+		$html .= "\t\t".'<input type="hidden" name="mailPreferenceOption" value="unset" />'."\n";
+		$html .= "\t\t".'<label '.$fieldclass.'><input type="checkbox" class="option" id="mailPreferenceOption" name="mailPreferenceOption" ';
+		if (!empty($this->registration['mailPreferenceOption'])) {
+			$html .= 'checked="checked" ';
 		}
-		$html .= '</select>';
-		$html .= '</label>';
+		$html .= '/> '.$required.' '.JText::_('Yes, I would like to receive newsletters and other updates by e-mail.').'</label>'."\n";
 		$html .= $message;
 		$html .= "\t".'</fieldset><div class="clear"></div>'."\n";
 	}
@@ -1061,7 +987,7 @@ defined('_JEXEC') or die('Restricted access');
 		$message = (isset($this->xregistration->_invalid['captcha']) && !empty($this->xregistration->_invalid['captcha'])) ? RegistrationHelperHtml::error($this->xregistration->_invalid['captcha']) : '';
 
 		JPluginHelper::importPlugin( 'hubzero' );
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 		$captchas = $dispatcher->trigger( 'onGetCaptcha' );
 
 		if (count($captchas) > 0) {
@@ -1084,7 +1010,7 @@ defined('_JEXEC') or die('Restricted access');
 	// Terms of use
 	if ($this->registrationTOU != REG_HIDE) {
 		$html .= "\t".'<fieldset>'."\n";
-		$html .= "\t\t".'<legend>'.JText::_('COM_REGISTER_TERMS_AND_CONDITIONS').'</legend>'."\n";
+		$html .= "\t\t".'<legend>'.JText::_('Terms &amp; Conditions').'</legend>'."\n";
 
 		if ($this->registrationTOU != REG_HIDE) {
 			$required = ($this->registrationTOU == REG_REQUIRED) ? '<span class="required">'.JText::_('COM_REGISTER_FORM_REQUIRED').'</span>' : '';
