@@ -31,6 +31,8 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 require_once( JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'resource.php');
 require_once( JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'type.php');
 require_once( JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'assoc.php');
@@ -41,23 +43,23 @@ require_once( JPATH_ROOT . DS . 'components' . DS . 'com_resources' . DS . 'help
 /**
  * Controller class for contributing a tool
  */
-class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
+class ResourcesControllerAuthors extends Hubzero_Controller
 {
 	/**
 	 * Determines task being called and attempts to execute it
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function execute()
 	{
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			JError::raiseError(403, JText::_('You must be logged in to access.'));
 			return;
 		}
 
 		// Load the com_resources component config
-		$rconfig = JComponentHelper::getParams('com_resources');
+		$rconfig =& JComponentHelper::getParams('com_resources');
 		$this->rconfig = $rconfig;
 
 		parent::execute();
@@ -65,7 +67,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 
 	/**
 	 * Save one or more authors
-	 *
+	 * 
 	 * @param      integer $show       Display author list when done?
 	 * @param      integer $id         Resource ID
 	 * @param      array   $authorsNew Authors to add
@@ -74,11 +76,11 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 	public function saveTask($show = 1, $id = 0, $authorsNew = array())
 	{
 		// Incoming resource ID
-		if (!$id)
+		if (!$id) 
 		{
 			$id = JRequest::getInt('pid', 0);
 		}
-		if (!$id)
+		if (!$id) 
 		{
 			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			if ($show)
@@ -88,6 +90,8 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 			return;
 		}
 
+		ximport('Hubzero_User_Profile');
+
 		// Incoming authors
 		$authid = JRequest::getInt('authid', 0, 'post');
 		$authorsNewstr = trim(JRequest::getVar('new_authors', '', 'post'));
@@ -105,27 +109,27 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 		$order = $rc->getLastOrder($id, 'resources');
 		$order = $order + 1; // new items are always last
 
-		if (!$authid && isset($_POST['author']))
+		if (!$authid && isset($_POST['author'])) 
 		{
 			$this->database->setQuery('SELECT id FROM #__users WHERE username = ' . $this->database->quote($_POST['author']));
 			$authid = $this->database->loadResult();
 		}
 
 		// Was there an ID? (this will come from the author <select>)
-		if ($authid)
+		if ($authid) 
 		{
 			// Check if they're already linked to this resource
 			$rc->loadAssociation($authid, $id, 'resources');
-			if ($rc->authorid)
+			if ($rc->authorid) 
 			{
-				$this->setError(JText::sprintf('COM_CONTRIBUTE_USER_IS_ALREADY_AUTHOR', $rc->name));
+				$this->setError(JText::sprintf('USER_IS_ALREADY_AUTHOR', $authid));
 			}
-			else
+			else 
 			{
 				// Perform a check to see if they have a contributors page. If not, we'll need to make one
-				$xprofile = new \Hubzero\User\Profile();
+				$xprofile = new Hubzero_User_Profile();
 				$xprofile->load($authid);
-				if ($xprofile)
+				if ($xprofile) 
 				{
 					$this->_authorCheck($authid);
 
@@ -143,7 +147,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 		}
 		$xprofile = null;
 		// Do we have new authors?
-		if (!empty($authorsNew))
+		if (!empty($authorsNew)) 
 		{
 			jimport('joomla.user.helper');
 
@@ -156,13 +160,12 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 				{
 					$uid = intval($cid);
 				}
-				else
+				else 
 				{
 					// Find the user's account info
 					$uid = JUserHelper::getUserId(strtolower($cid));
-					if (!$uid)
+					if (!$uid) 
 					{
-						$cid = addslashes(trim($cid));
 						// No account
 						// This should mean we have an author that is not a site member
 						$rcc = new ResourcesContributor($this->database);
@@ -183,8 +186,8 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 						$rcc->subid    = $id;
 						$rcc->authorid = $rcc->getUserId($cid);
 						$rcc->ordering = $order;
-						$rcc->name     = $cid;
-						$rcc->role     = addslashes($role);
+						$rcc->name     = trim($cid);
+						$rcc->role     = $role;
 						$rcc->createAssociation();
 						//$this->setError(JText::sprintf('COM_CONTRIBUTE_UNABLE_TO_FIND_USER_ACCOUNT', $cid));
 						$order++;
@@ -193,8 +196,8 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 				}
 
 				// We should only get to this part if the author is also a site member
-				$juser = JUser::getInstance($uid);
-				if (!is_object($juser))
+				$juser =& JUser::getInstance($uid);
+				if (!is_object($juser)) 
 				{
 					$this->setError( JText::sprintf('COM_CONTRIBUTE_UNABLE_TO_FIND_USER_ACCOUNT', $cid));
 					continue;
@@ -202,7 +205,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 
 				$uid = $juser->get('id');
 
-				if (!$uid)
+				if (!$uid) 
 				{
 					$this->setError(JText::sprintf('COM_CONTRIBUTE_UNABLE_TO_FIND_USER_ACCOUNT', $cid));
 					continue;
@@ -211,15 +214,15 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 				// Check if they're already linked to this resource
 				$rcc = new ResourcesContributor($this->database);
 				$rcc->loadAssociation($uid, $id, 'resources');
-				if ($rcc->authorid)
+				if ($rcc->authorid) 
 				{
-					$this->setError(JText::sprintf('COM_CONTRIBUTE_USER_IS_ALREADY_AUTHOR', $rcc->name));
+					$this->setError(JText::sprintf('USER_IS_ALREADY_AUTHOR', $cid));
 					continue;
 				}
 
 				$this->_authorCheck($uid);
 
-				$xprofile = \Hubzero\User\Profile::getInstance($juser->get('id'));
+				$xprofile = Hubzero_User_Profile::getInstance($juser->get('id'));
 				$rcc->subtable     = 'resources';
 				$rcc->subid        = $id;
 				$rcc->authorid     = $uid;
@@ -227,7 +230,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 				$rcc->name         = $xprofile->get('name');
 				$rcc->role         = $role;
 				$rcc->organization = $xprofile->get('organization');
-				if (!$rcc->createAssociation())
+				if (!$rcc->createAssociation()) 
 				{
 					$this->setError($rcc->getError());
 				}
@@ -236,7 +239,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 			}
 		}
 
-		if ($show)
+		if ($show) 
 		{
 			// Push through to the authors view
 			$this->displayTask($id);
@@ -245,24 +248,24 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 
 	/**
 	 * Split a user's name into its parts if not already done
-	 *
+	 * 
 	 * @param      integer $id User ID
 	 * @return     void
 	 */
 	private function _authorCheck($id)
 	{
-		$xprofile = \Hubzero\User\Profile::getInstance($id);
-		if ($xprofile->get('givenName') == ''
-		 && $xprofile->get('middleName') == ''
-		 && $xprofile->get('surname') == '')
+		$xprofile = Hubzero_User_Profile::getInstance($id);
+		if ($xprofile->get('givenName') == '' 
+		 && $xprofile->get('middleName') == '' 
+		 && $xprofile->get('surname') == '') 
 		{
 			$bits = explode(' ', $xprofile->get('name'));
 			$xprofile->set('surname', array_pop($bits));
-			if (count($bits) >= 1)
+			if (count($bits) >= 1) 
 			{
 				$xprofile->set('givenName', array_shift($bits));
 			}
-			if (count($bits) >= 1)
+			if (count($bits) >= 1) 
 			{
 				$xprofile->set('middleName', implode(' ', $bits));
 			}
@@ -271,7 +274,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 
 	/**
 	 * Remove an author from an item
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function removeTask()
@@ -281,7 +284,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 		$pid = JRequest::getInt('pid', 0);
 
 		// Ensure we have a resource ID ($pid) to work with
-		if (!$pid)
+		if (!$pid) 
 		{
 			$this->setError(JText::_('CONTRIBUTE_NO_ID'));
 			$this->displayTask();
@@ -289,10 +292,10 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 		}
 
 		// Ensure we have the contributor's ID ($id)
-		if ($id)
+		if ($id) 
 		{
 			$rc = new ResourcesContributor($this->database);
-			if (!$rc->deleteAssociation($id, $pid, 'resources'))
+			if (!$rc->deleteAssociation($id, $pid, 'resources')) 
 			{
 				$this->setError($rc->getError());
 			}
@@ -304,7 +307,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 
 	/**
 	 * Update information for a resource author
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function updateTask()
@@ -314,7 +317,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 		$pid = JRequest::getInt('pid', 0);
 
 		// Ensure we have a resource ID ($pid) to work with
-		if (!$pid)
+		if (!$pid) 
 		{
 			$this->setError(JText::_('COM_CONTRIBUTE_NO_ID'));
 			$this->displayTask();
@@ -322,7 +325,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 		}
 
 		// Ensure we have the contributor's ID ($id)
-		if ($ids)
+		if ($ids) 
 		{
 			foreach ($ids as $id => $data)
 			{
@@ -340,7 +343,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 
 	/**
 	 * Reorder the list of authors
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function reorderTask()
@@ -351,7 +354,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 		$move = 'order' . JRequest::getVar('move', 'down');
 
 		// Ensure we have an ID to work with
-		if (!$id)
+		if (!$id) 
 		{
 			$this->setError(JText::_('COM_CONTRIBUTE_NO_CHILD_ID'));
 			$this->displayTask($pid);
@@ -359,7 +362,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 		}
 
 		// Ensure we have a parent ID to work with
-		if (!$pid)
+		if (!$pid) 
 		{
 			$this->setError(JText::_('COM_CONTRIBUTE_NO_ID'));
 			$this->displayTask($pid);
@@ -405,7 +408,7 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 
 	/**
 	 * Display a list of authors
-	 *
+	 * 
 	 * @param      integer $id Resource ID
 	 * @return     void
 	 */
@@ -414,13 +417,13 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 		$this->view->setLayout('display');
 
 		// Incoming
-		if (!$id)
+		if (!$id) 
 		{
 			$id = JRequest::getInt('id', 0);
 		}
 
 		// Ensure we have an ID to work with
-		if (!$id)
+		if (!$id) 
 		{
 			JError::raiseError(500, JText::_('CONTRIBUTE_NO_ID'));
 			return;
@@ -448,7 +451,9 @@ class ResourcesControllerAuthors extends \Hubzero\Component\SiteController
 
 		$this->view->roles = $rt->getRolesForType($resource->type);
 
-		if ($this->getError())
+		$this->_getStyles($this->_option, 'create.css');
+
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
