@@ -58,63 +58,9 @@ HUB.Support = {
 				}
 			});
 		}
-
-		var attach = $("#ajax-uploader");
-		if (attach.length) {
-			$('#ajax-uploader-list')
-				.on('click', 'a.delete', function (e){
-					e.preventDefault();
-					if ($(this).attr('data-id')) {
-						$.get($(this).attr('href'), {}, function(data) {});
-					}
-					$(this).parent().parent().remove();
-				});
-
-			var uploader = new qq.FileUploader({
-				element: attach[0],
-				action: attach.attr("data-action"),
-				multiple: true,
-				debug: true,
-				template: '<div class="qq-uploader">' +
-							'<div class="qq-upload-button"><span>Click or drop file</span></div>' + 
-							'<div class="qq-upload-drop-area"><span>Click or drop file</span></div>' +
-							'<ul class="qq-upload-list"></ul>' + 
-						'</div>',
-				onSubmit: function(id, file) {
-					//$("#ajax-upload-left").append("<div id=\"ajax-upload-uploading\" />");
-				},
-				onComplete: function(id, file, response) {
-					$('ul.qq-upload-list').empty();
-					// HTML entities had to be encoded for the JSON or IE 8 went nuts. So, now we have to decode it.
-					response.html = response.html.replace(/&gt;/g, '>');
-					response.html = response.html.replace(/&lt;/g, '<');
-					$('#ajax-uploader-list').append(response.html);
-				}
-			});
-		}
-
-		// Add customized tooltip (with delay so it doesn't popup when moving mouse down the screen)
-		/*$('.ticket-content').tooltip({
-			position: 'top center',
-			effect: 'fade',
-			delay: 250,
-			predelay: 750,
-			offset: [-4, 0],
-			onBeforeShow: function(event, position) {
-				var tip = this.getTip(),
-					tipText = tip[0].innerHTML;
-					
-				if (tipText.indexOf('::') != -1) {
-					var parts = tipText.split('::');
-					tip[0].innerHTML = '<span class="tooltip-title">' + parts[0] + '</span><span class="tooltip-text">' + parts[1] + '</span>';
-				}
-			}
-		});*/
 	},
 
 	addEditQueryEvent: function() {
-		var $ = HUB.Support.jQuery;
-
 		$('a.modal').fancybox({
 			type: 'ajax',
 			width: 600,
@@ -154,22 +100,12 @@ HUB.Support = {
 						$.post($(this).attr('action'), $(this).serialize(), function(data) {
 							$('#custom-views').html(data);
 							HUB.Support.addEditQueryEvent();
-							$.fancybox.close();
+							$.fancybox().close();
 						});
 					});
 				}
 			}
 		});
-
-		/*$('a.delete').each(function(i, el) {
-			$(el).on('click', function(e) {
-				var res = confirm('Are you sure you wish to delete this item?');
-				if (!res) {
-					e.preventDefault();
-				}
-				return res;
-			});
-		});*/
 	},
 
 	addDeleteQueryEvent: function() {
