@@ -31,192 +31,254 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Controller class for tags
  */
-class TagsControllerTags extends \Hubzero\Component\SiteController
+class TagsControllerTags extends Hubzero_Controller
 {
 	/**
 	 * Execute a task
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function execute()
 	{
 		$this->_authorize();
 
-		$this->registerTask('feed.rss', 'feed');
-		$this->registerTask('feedrss', 'feed');
-
-		if (($tagstring = urldecode(trim(JRequest::getVar('tag', '', 'request', 'none', 2)))))
-		{
-			if (!JRequest::getVar('task', ''))
-			{
-				JRequest::setVar('task', 'view');
-			}
-		}
+		$this->registerTask('feed', 'feed.rss');
 
 		parent::execute();
 	}
 
 	/**
 	 * Display the main page for this component
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function displayTask()
 	{
+		// Instantiate a new view
+		$this->view->showsizes = 0;
+		$this->view->config = $this->config;
+
+		// Set some variables
+		$this->view->min_font_size = 1;
+		$this->view->max_font_size = 1.8;
+
+		// Find all tags
+		$t = new TagsTag($this->database);
+
+		$this->view->tags = $t->getTopTags(100);
+
+		$this->view->newtags = $t->getRecentTags(25);
+
+		// Trigger the functions that return the areas we'll be using
+		$this->view->categories = array();
+		$this->view->tagpile = array();
+
+		if ($this->view->tags) 
+		{
+			$retarr = array();
+			foreach ($this->view->tags as $tag)
+			{
+				$retarr[$tag->raw_tag] = $tag->tcount;
+			}
+			ksort($retarr);
+
+			$this->view->max_qty = max(array_values($retarr));  // Get the max qty of tagged objects in the set
+			$this->view->min_qty = min(array_values($retarr));  // Get the min qty of tagged objects in the set
+		} 
+		else 
+		{
+			$this->view->max_qty = 0;
+			$this->view->min_qty = 0;
+		}
+
+		// For ever additional tagged object from min to max, we add $step to the font size.
+		$spread = $this->view->max_qty - $this->view->min_qty;
+		if (0 == $spread) 
+		{
+			// Divide by zero
+			$spread = 1;
+		}
+		$this->view->step = ($this->view->max_font_size - $this->view->min_font_size)/($spread);
+
 		// Set the page title
 		$this->_buildTitle(null);
 
 		// Set the pathway
 		$this->_buildPathway(null);
 
-		$this->view
-			->set('cloud', new TagsModelCloud())
-			->set('config', $this->config)
-			->display();
+		// Push some styles to the template
+		$this->_getStyles('', 'introduction.css', true); // component, stylesheet name, look in media system dir
+		$this->_getStyles();
+
+		// Output HTML
+		if ($this->getError()) 
+		{
+			foreach ($this->getErrors() as $error)
+			{
+				$this->view->setError($error);
+			}
+		}
+		$this->view->display();
 	}
 
 	/**
 	 * View items tagged with this tag
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function viewTask()
 	{
 		// Incoming
-		$tagstring = urldecode(htmlspecialchars_decode(trim(JRequest::getVar('tag', '', 'request', 'none', 2))));
+		$tagstring = urldecode(trim(JRequest::getVar('tag', '', 'request', 'none', 2)));
 
 		$addtag = trim(JRequest::getVar('addtag', ''));
 
 		// Ensure we were passed a tag
-		if (!$tagstring && !$addtag)
+		if (!$tagstring && !$addtag) 
 		{
-			if (JRequest::getWord('task', '', 'get'))
-			{
-				$this->setRedirect(
-					JRoute::_('index.php?option=' . $this->_option)
-				);
-				return;
-			}
 			JError::raiseError(404, JText::_('COM_TAGS_NO_TAG'));
 			return;
 		}
 
-		if ($tagstring)
+		if ($tagstring) 
 		{
 			// Break the string into individual tags
-			$tgs = explode(',', $tagstring);
+			$tgs = explode(' ', $tagstring);
 			$tgs = array_map('trim', $tgs);
-		}
-		else
+		} 
+		else 
 		{
 			$tgs = array();
 		}
 
 		// See if we're adding any tags to the search list
-		if ($addtag && !in_array($addtag, $tgs))
+		if ($addtag && !in_array($addtag, $tgs)) 
 		{
 			$tgs[] = $addtag;
 		}
 
 		// Sanitize the tag
+		$t = new TagsHandler($this->database);
+
 		$tags  = array();
 		$added = array();
 		$rt    = array();
 		foreach ($tgs as $tag)
 		{
-			// Load the tag
-			$tagobj = TagsModelTag::getInstance($tag);
+			$tag = $t->normalize_tag($tag);
 
-			if (in_array($tagobj->get('tag'), $added))
+			if (in_array($tag, $added)) 
 			{
 				continue;
 			}
 
-			$added[] = $tagobj->get('tag');
+			$added[] = $tag;
+
+			// Load the tag
+			$tagobj = new TagsTag($this->database);
+			$tagobj->loadTag($this->database->getEscaped($tag));
 
 			// Ensure we loaded the tag's info from the database
-			if ($tagobj->exists())
+			if ($tagobj->id) 
 			{
 				$tags[] = $tagobj;
-				$rt[]   = $tagobj->get('raw_tag');
+				$rt[]   = $tagobj->raw_tag;
 			}
 		}
 
 		// Ensure we loaded the tag's info from the database
-		if (empty($tags))
+		if (empty($tags)) 
 		{
-			JError::raiseError(404, JText::_('COM_TAGS_TAG_NOT_FOUND'));
+			JError::raiseError(404, JText::_('COM_TAGS_NOT_FOUND'));
 			return;
 		}
 
+		// Set the page title
+		//$title .= ': ';
+		$tagname = array();
+		$tagstring = array();
+		for ($i=0, $n=count($tags); $i < $n; $i++)
+		{
+			if ($i > 0) 
+			{
+				$title .= '+ ';
+			}
+			$tagname[] = $tags[$i]->raw_tag;
+			$tagstring[] = $tags[$i]->tag;
+			//$title .= $tags[$i]->raw_tag . ' ';
+		}
+
 		// Load plugins
 		JPluginHelper::importPlugin('tags');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		// Get configuration
 		$config = JFactory::getConfig();
 
 		// Incoming paging vars
-		$this->view->filters = array(
-			'limit' => JRequest::getInt('limit', $config->getValue('config.list_limit')),
-			'start' => JRequest::getInt('limitstart', 0),
-			'sort'  => JRequest::getVar('sort', 'date')
-		);
-		if (!in_array($this->view->filters['sort'], array('date', 'title')))
+		$this->view->filters = array();
+		$this->view->filters['limit'] = JRequest::getInt('limit', $config->getValue('config.list_limit'));
+		$this->view->filters['start'] = JRequest::getInt('limitstart', 0);
+		$this->view->filters['sort']  = JRequest::getVar('sort', 'date');
+
+		// Trigger the functions that return the areas we'll be using
+		$areas = array();
+		$searchareas = $dispatcher->trigger('onTagAreas');
+		foreach ($searchareas as $area)
 		{
-			throw new Exception(JText::sprintf('Invalid sort value of "%s".', $this->view->filters), 404);
+			$areas = array_merge($areas, $area);
 		}
 
 		// Get the active category
-		$area = JRequest::getString('area', '');
+		$area = JRequest::getVar('area', '');
+		if ($area) 
+		{
+			$activeareas = array($area);
+		} 
+		else 
+		{
+			//$limit = 5;
+			$activeareas = $areas;
+		}
 
-		$this->view->categories = $dispatcher->trigger('onTagView', array(
-			$tags,
-			$this->view->filters['limit'],
-			$this->view->filters['start'],
-			$this->view->filters['sort'],
-			$area
-		));
+		// Get the search result totals
+		$totals = $dispatcher->trigger('onTagView', array(
+				$tags,
+				0,
+				0,
+				$this->view->filters['sort'],
+				$activeareas
+			)
+		);
 
-		$this->view->total   = 0;
-		$this->view->results = null;
+		$this->view->filters['limit'] = ($this->view->filters['limit'] == 0) ? 'all' : $this->view->filters['limit'];
 
-		if (!$area)
+		// Get the search results
+		$this->view->results = $dispatcher->trigger('onTagView', array(
+				$tags,
+				$this->view->filters['limit'],
+				$this->view->filters['start'],
+				$this->view->filters['sort'],
+				$activeareas
+			)
+		);
+
+		if (count($activeareas) > 1) 
 		{
 			$query = '';
-			if ($this->view->categories)
+			if ($this->view->results) 
 			{
 				$s = array();
-				foreach ($this->view->categories as $response)
+				foreach ($this->view->results as $sql)
 				{
-					$this->view->total += $response['total'];
-
-					if (is_array($response['sql']))
+					if (trim($sql) != '') 
 					{
-						continue;
-					}
-					if (trim($response['sql']) != '')
-					{
-						$s[] = $response['sql'];
-					}
-					if (isset($response['children']))
-					{
-						foreach ($response['children'] as $sresponse)
-						{
-							//$this->view->total += $sresponse['total'];
-
-							if (is_array($sresponse['sql']))
-							{
-								continue;
-							}
-							if (trim($sresponse['sql']) != '')
-							{
-								$s[] = $sresponse['sql'];
-							}
-						}
+						$s[] = $sql;
 					}
 				}
 				$query .= "(";
@@ -229,61 +291,83 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 					case 'date':
 					default:      $query .= 'publish_up DESC, title'; break;
 				}
-				if ($this->view->filters['limit'] != 'all'
+				if ($this->view->filters['limit'] != 'all' 
 				 && $this->view->filters['limit'] > 0)
 				{
 					$query .= " LIMIT " . $this->view->filters['start'] . "," . $this->view->filters['limit'];
 				}
 			}
 			$this->database->setQuery($query);
-			$this->view->results = $this->database->loadObjectList();
+			$this->view->results = array($this->database->loadObjectList());
 		}
-		else
+
+		// Get the total results found (sum of all categories)
+		$i = 0;
+		$this->view->total = 0;
+
+		foreach ($areas as $c => $t)
 		{
-			if ($this->view->categories)
+			$cats[$i]['category'] = $c;
+
+			// Do sub-categories exist?
+			if (is_array($t) && !empty($t)) 
 			{
-				foreach ($this->view->categories as $response)
+				// They do - do some processing
+				$cats[$i]['title'] = ucfirst($c);
+				$cats[$i]['total'] = 0;
+				$cats[$i]['_sub']  = array();
+				$z = 0;
+				// Loop through each sub-category
+				foreach ($t as $s=>$st)
 				{
-					$this->view->total += $response['total'];
-				}
-				foreach ($this->view->categories as $response)
-				{
-					//$this->view->total += $response['total'];
-
-					if (is_array($response['results']))
+					// Ensure a matching array of totals exist
+					if (is_array($totals[$i]) && !empty($totals[$i]) && isset($totals[$i][$z])) 
 					{
-						$this->view->results = $response['results'];
-						break;
-					}
-
-					if (isset($response['children']))
-					{
-						foreach ($response['children'] as $sresponse)
-						{
-							//$this->view->total += $sresponse['total'];
-
-							if (is_array($sresponse['results']))
-							{
-								$this->view->results = $sresponse['results'];
-								break 2;
-							}
-						}
+						// Add to the parent category's total
+						$cats[$i]['total'] = $cats[$i]['total'] + $totals[$i][$z];
+						// Get some info for each sub-category
+						$cats[$i]['_sub'][$z]['category'] = $s;
+						$cats[$i]['_sub'][$z]['title']    = $st;
+						$cats[$i]['_sub'][$z]['total']    = $totals[$i][$z];
 					}
+					$z++;
 				}
+			} 
+			else 
+			{
+				// No sub-categories - this should be easy
+				$cats[$i]['title'] = $t;
+				$cats[$i]['total'] = (!is_array($totals[$i])) ? $totals[$i] : 0;
 			}
+
+			// Add to the overall total
+			$this->view->total = $this->view->total + intval($cats[$i]['total']);
+			$i++;
+		}
+		$this->view->totals = $totals;
+		$this->view->cats   = $cats;
+
+		// Do we have an active area?
+		if (count($activeareas) == 1 && isset($activeareas[0])) 
+		{
+			$active = $activeareas[0];
+		} 
+		else 
+		{
+			$active = '';
 		}
 
 		$related = null;
-		if (count($tags) == 1)
+		if (count($tags) == 1) 
 		{
-			$this->view->tagstring = $tags[0]->get('tag');
-		}
-		else
+			$this->view->tagstring = $tags[0]->tag;
+		} 
+		else 
 		{
 			$tagstring = array();
 			foreach ($tags as $tag)
 			{
-				$tagstring[] = $tag->get('tag');
+				$tagstring[] = $tag->tag;
 			}
 			$this->view->tagstring = implode('+', $tagstring);
 		}
@@ -294,19 +378,25 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 		// Set the page title
 		$this->_buildTitle($tags);
 
+		// Push some styles to the template
+		$this->_getStyles();
+
 		// Output HTML
-		if (JRequest::getVar('format', '') == 'xml')
+		if (JRequest::getVar('format', '') == 'xml') 
 		{
 			$this->view->setLayout('view_xml');
 		}
 
 		$this->view->tags   = $tags;
-		$this->view->active = $area;
+		$this->view->active = $active;
 		$this->view->search = implode(', ', $rt);
 
-		foreach ($this->getErrors() as $error)
+		if ($this->getError()) 
 		{
-			$this->view->setError($error);
+			foreach ($this->getErrors() as $error)
+			{
+				$this->view->setError($error);
+			}
 		}
 
 		$this->view->display();
@@ -315,47 +405,35 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 	/**
 	 * Returns results (JSON format) for a search string
 	 * Used for autocompletion scripts called via AJAX
-	 *
-	 * @return  string  JSON
+	 * 
+	 * @return     string JSON
 	 */
 	public function autocompleteTask()
 	{
-		$filters = array(
-			'limit'  => 20,
-			'start'  => 0,
-			'admin'  => 0,
-			'search' => trim(JRequest::getString('value', ''))
-		);
+		$filters = array();
+		$filters['limit']  = 20;
+		$filters['start']  = 0;
+		$filters['search'] = trim(JRequest::getString('value', ''));
 
 		// Create a Tag object
-		$cloud = new TagsModelCloud();
+		$obj = new TagsTag($this->database);
 
 		// Fetch results
-		$rows = $cloud->tags('list', $filters);
+		$rows = $obj->getAutocomplete($filters);
 
 		// Output search results in JSON format
 		$json = array();
-		if (count($rows) > 0)
+		if (count($rows) > 0) 
 		{
 			foreach ($rows as $row)
 			{
-				$name = str_replace("\n", '', stripslashes(trim($row->get('raw_tag'))));
+				$name = str_replace("\n", '', stripslashes(trim($row->raw_tag)));
 				$name = str_replace("\r", '', $name);
-
-				$item = array(
-					'id'   => $row->get('tag'),
+	
+				$json[] = array(
+					'id'   => $row->tag,
 					'name' => $name
 				);
-
-				// Push exact matches to the front
-				if ($row->get('tag') == $filters['search'])
-				{
-					array_unshift($json, $item);
-				}
-				else
-				{
-					$json[] = $item;
-				}
 			}
 		}
 
@@ -364,41 +442,51 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 
 	/**
 	 * Generate an RSS feed
-	 *
-	 * @return  string  RSS
+	 * 
+	 * @return     string RSS
 	 */
 	public function feedTask()
 	{
+		include_once(JPATH_ROOT . DS . 'libraries' . DS . 'joomla' . DS . 'document' . DS . 'feed' . DS . 'feed.php');
+
+		$app = JFactory::getApplication();
+
+		// Set the mime encoding for the document
+		$jdoc =& JFactory::getDocument();
+		$jdoc->setMimeEncoding('application/rss+xml');
+
+		// Start a new feed object
+		$doc = new JDocumentFeed;
+		$params =& $app->getParams();
+		$doc->link = JRoute::_('index.php?option=' . $this->_option);
+
 		// Incoming
 		$tagstring = trim(JRequest::getVar('tag', '', 'request', 'none', 2));
 
 		// Ensure we were passed a tag
-		if (!$tagstring)
+		if (!$tagstring) 
 		{
 			JError::raiseError(404, JText::_('COM_TAGS_NO_TAG'));
 			return;
 		}
 
 		// Break the string into individual tags
-		$tgs = explode(',', $tagstring);
+		$tgs = explode(' ', $tagstring);
 
 		// Sanitize the tag
-		$tags  = array();
-		$added = array();
+		$t = new TagsHandler($this->database);
+
+		$tags = array();
 		foreach ($tgs as $tag)
 		{
+			$tag = $t->normalize_tag($tag);
+
 			// Load the tag
-			$tagobj = TagsModelTag::getInstance($tag);
-
-			if (in_array($tagobj->get('tag'), $added))
-			{
-				continue;
-			}
-
-			$added[] = $tagobj->get('tag');
+			$tagobj = new TagsTag($this->database);
+			$tagobj->loadTag($tag);
 
 			// Ensure we loaded the tag's info from the database
-			if ($tagobj->exists())
+			if ($tagobj->id) 
 			{
 				$tags[] = $tagobj;
 			}
@@ -413,7 +501,7 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 
 		// Load plugins
 		JPluginHelper::importPlugin('tags');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		$areas = array();
 		$searchareas = $dispatcher->trigger('onTagAreas');
@@ -426,19 +514,19 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 		$area = JRequest::getVar('area', '');
 		$sort = JRequest::getVar('sort', '');
 
-		if ($area)
+		if ($area) 
 		{
 			$activeareas = array($area);
-		}
-		else
+		} 
+		else 
 		{
 			$activeareas = $areas;
 		}
 
 		// Get the search results
-		if (count($activeareas) > 1)
+		if (count($activeareas) > 1) 
 		{
-			$sqls = $dispatcher->trigger('onTagView',
+			$sqls = $dispatcher->trigger('onTagView', 
 				array(
 					$tags,
 					$limit,
@@ -447,16 +535,12 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 					$activeareas
 				)
 			);
-			if ($sqls)
+			if ($sqls) 
 			{
 				$s = array();
 				foreach ($sqls as $sql)
 				{
-					if (!is_string($sql))
-					{
-						continue;
-					}
-					if (trim($sql) != '')
+					if (trim($sql) != '') 
 					{
 						$s[] = $sql;
 					}
@@ -475,10 +559,10 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 			}
 			$this->database->setQuery($query);
 			$results = array($this->database->loadObjectList());
-		}
-		else
+		} 
+		else 
 		{
-			$results = $dispatcher->trigger('onTagView',
+			$results = $dispatcher->trigger('onTagView', 
 				array(
 					$tags,
 					$limit,
@@ -489,15 +573,15 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 			);
 		}
 
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 
 		// Run through the array of arrays returned from plugins and find the one that returned results
 		$rows = array();
-		if ($results)
+		if ($results) 
 		{
 			foreach ($results as $result)
 			{
-				if (is_array($result) && !empty($result))
+				if (is_array($result) && !empty($result)) 
 				{
 					$rows = $result;
 					break;
@@ -509,31 +593,22 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 		$title = JText::_(strtoupper($this->_option)) . ': ';
 		for ($i=0, $n=count($tags); $i < $n; $i++)
 		{
-			if ($i > 0)
+			if ($i > 0) 
 			{
 				$title .= '+ ';
 			}
-			$title .= $tags[$i]->get('raw_tag') . ' ';
+			$title .= $tags[$i]->raw_tag . ' ';
 		}
 		$title = trim($title);
 		$title .= ': ' . $area;
 
-		include_once(JPATH_ROOT . DS . 'libraries' . DS . 'joomla' . DS . 'document' . DS . 'feed' . DS . 'feed.php');
-
-		// Set the mime encoding for the document
-		$jdoc = JFactory::getDocument();
-		$jdoc->setMimeEncoding('application/rss+xml');
-
-		// Start a new feed object
-		$doc = new JDocumentFeed;
-		$doc->link        = JRoute::_('index.php?option=' . $this->_option);
 		$doc->title       = $jconfig->getValue('config.sitename') . ' - ' . $title;
 		$doc->description = JText::sprintf('COM_TAGS_RSS_DESCRIPTION', $jconfig->getValue('config.sitename'), $title);
 		$doc->copyright   = JText::sprintf('COM_TAGS_RSS_COPYRIGHT', date("Y"), $jconfig->getValue('config.sitename'));
 		$doc->category    = JText::_('COM_TAGS_RSS_CATEGORY');
 
 		// Start outputing results if any found
-		if (count($rows) > 0)
+		if (count($rows) > 0) 
 		{
 			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_resources' . DS . 'helpers' . DS . 'helper.php');
 
@@ -543,14 +618,17 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 				$title = strip_tags($row->title);
 				$title = html_entity_decode($title);
 
+				// URL link to article
+				//$link = JRoute::_($row->href);
+
 				// Strip html from feed item description text
-				$description = html_entity_decode(\Hubzero\Utility\String::truncate(\Hubzero\Utility\Sanitize::stripAll(stripslashes($row->ftext)),300));
+				$description = html_entity_decode(Hubzero_View_Helper_Html::shortenText(Hubzero_View_Helper_Html::purifyText(stripslashes($row->ftext)),300,0));
 				$author = '';
 				@$date = ($row->publish_up ? date('r', strtotime($row->publish_up)) : '');
 
-				if (isset($row->data3) || isset($row->rcount))
+				if (isset($row->data3) || isset($row->rcount)) 
 				{
-					$resourceEx = new ResourcesHelper($row->id, $this->database);
+					$resourceEx = new ResourceExtended($row->id, $this->database);
 					$resourceEx->getCitationsCount();
 					$resourceEx->getLastCitationDate();
 					$resourceEx->getContributors();
@@ -578,25 +656,25 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 
 	/**
 	 * Browse the list of tags
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function browseTask()
 	{
 		// Instantiate a new view
-		if (JRequest::getVar('format', '') == 'xml')
+		if (JRequest::getVar('format', '') == 'xml') 
 		{
 			$this->view->setLayout('browse_xml');
 		}
 
 		// Get configuration
 		$jconfig = JFactory::getConfig();
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 
 		// Incoming
-		$this->view->filters = array(
-			'admin' => 0
-		);
+		$this->view->filters = array();
+		//$this->view->filters['start']  = JRequest::getInt('limitstart', 0);
+		//$this->view->filters['search'] = urldecode(JRequest::getString('search'));
 		$this->view->filters['start'] = $app->getUserStateFromRequest(
 			$this->_option . '.' . $this->_controller . '.limitstart',
 			'limitstart',
@@ -604,42 +682,29 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 			'int'
 		);
 		$this->view->filters['search']       = urldecode($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.search',
-			'search',
+			$this->_option . '.' . $this->_controller . '.search', 
+			'search', 
 			''
 		));
-
-		// Fallback support for deprecated sorting option
-		if ($sortby = JRequest::getVar('sortby'))
+		$this->view->filters['sortby'] = $app->getUserStateFromRequest(
+			$this->_option . '.' . $this->_controller . '.sortby',
+			'show',
+			''
+		);
+		//$this->view->filters['sortby'] = JRequest::getVar('sortby', '');
+		if (!in_array($this->view->filters['sortby'], array('raw_tag', 'total')))
 		{
-			JRequest::setVar('sort', $sortby);
-		}
-		$this->view->filters['sort'] = urldecode($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.sort',
-			'sort',
-			'raw_tag'
-		));
-		$this->view->filters['sort_Dir'] = strtolower($app->getUserStateFromRequest(
-			$this->_option . '.' . $this->_controller . '.sort_Dir',
-			'sortdir',
-			'asc'
-		));
-		if (!in_array($this->view->filters['sort'], array('raw_tag', 'total')))
-		{
-			$this->view->filters['sort'] = 'raw_tag';
-		}
-		if (!in_array($this->view->filters['sort_Dir'], array('asc', 'desc')))
-		{
-			$this->view->filters['sort_Dir'] = 'asc';
+			$this->view->filters['sortby'] = '';
 		}
 
 		$this->view->total = 0;
 
-		$t = new TagsModelCloud();
+		$t = new TagsTag($this->database);
 
 		$order = JRequest::getVar('order', '');
-		if ($order == 'usage')
+		if ($order == 'usage') 
 		{
+			//$limit = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
 			$limit = $app->getUserStateFromRequest(
 				$this->_option . '.' . $this->_controller . '.limit',
 				'limit',
@@ -647,18 +712,12 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 				'int'
 			);
 
-			$this->view->rows = $t->tags('list', array(
-				'limit'    => $limit,
-				'admin'    => 0,
-				'sort'     => 'total',
-				'sort_Dir' => 'DESC',
-				'by'       => 'user'
-			));
-		}
-		else
+			$this->view->rows = $t->getTopTags($limit);
+		} 
+		else 
 		{
 			// Record count
-			$this->view->total = $t->tags('count', $this->view->filters);
+			$this->view->total = $t->getCount($this->view->filters);
 
 			$this->view->filters['limit'] = $app->getUserStateFromRequest(
 				$this->_option . '.' . $this->_controller . '.limit',
@@ -666,15 +725,16 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 				$jconfig->getValue('config.list_limit'),
 				'int'
 			);
+			//$this->view->filters['limit'] = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
 
 			// Get records
-			$this->view->rows = $t->tags('list', $this->view->filters);
+			$this->view->rows = $t->getRecords($this->view->filters);
 
 			// Initiate paging
 			jimport('joomla.html.pagination');
 			$this->view->pageNav = new JPagination(
-				$this->view->total,
-				$this->view->filters['start'],
+				$this->view->total, 
+				$this->view->filters['start'], 
 				$this->view->filters['limit']
 			);
 		}
@@ -685,21 +745,29 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 		// Set the page title
 		$this->_buildTitle();
 
+		// Push some styles to the document
+		$this->_getStyles();
+
+		// Push scripts to the document
+		$this->_getScripts('assets/css/tags');
+
 		$this->view->config = $this->config;
 
 		// Output HTML
-		foreach ($this->getErrors() as $error)
+		if ($this->getError()) 
 		{
-			$this->view->setError($error);
+			foreach ($this->getErrors() as $error)
+			{
+				$this->view->setError($error);
+			}
 		}
-
 		$this->view->display();
 	}
 
 	/**
 	 * Create a new tag
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function createTask()
 	{
@@ -707,38 +775,41 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 	}
 
 	/**
-	 * Show a form for editing a tag
-	 *
-	 * @param   object  $tag  TagsTableTag
-	 * @return  void
+	 * Show a form for editing a task
+	 * 
+	 * @param      object $tag TagsTag
+	 * @return     void
 	 */
 	public function editTask($tag=NULL)
 	{
+		$this->view->setLayout('edit');
+
 		// Check that the user is authorized
-		if (!$this->config->get('access-edit-tag'))
+		if (!$this->config->get('access-edit-tag')) 
 		{
 			JError::raiseWarning(403, JText::_('ALERTNOTAUTH'));
 			return;
 		}
 
 		// Load a tag object if one doesn't already exist
-		if (is_object($tag))
+		if (is_object($tag)) 
 		{
 			$this->view->tag = $tag;
 		}
-		else
+		else 
 		{
 			// Incoming
-			$this->view->tag = new TagsModelTag(intval(JRequest::getInt('id', 0, 'request')));
+			$id = JRequest::getInt('id', 0, 'request');
+
+			$this->view->tag = new TagsTag($this->database);
+			$this->view->tag->load($id);
 		}
 
-		$this->view->filters = array(
-			'limit'    => JRequest::getInt('limit', 0),
-			'start'    => JRequest::getInt('limitstart', 0),
-			'sort'     => JRequest::getVar('sort', ''),
-			'sort_Dir' => JRequest::getVar('sortdir', ''),
-			'search'   => urldecode(JRequest::getString('search', ''))
-		);
+		$this->view->filters = array();
+		$this->view->filters['limit']  = JRequest::getInt('limit', 0);
+		$this->view->filters['start']  = JRequest::getInt('limitstart', 0);
+		$this->view->filters['sortby'] = JRequest::getInt('sortby', '');
+		$this->view->filters['search'] = urldecode(JRequest::getString('search', ''));
 
 		// Set the pathway
 		$this->_buildPathway();
@@ -746,21 +817,28 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 		// Set the page title
 		$this->_buildTitle();
 
+		// Push some styles to the template
+		$this->_getStyles();
+
+		// Push scripts to the document
+		$this->_getScripts('assets/css/tags');
+
 		// Pass error messages to the view
-		foreach ($this->getErrors() as $error)
+		if ($this->getError()) 
 		{
-			$this->view->setError($error);
+			foreach ($this->getErrors() as $error)
+			{
+				$this->view->setError($error);
+			}
 		}
 
-		$this->view
-			->setLayout('edit')
-			->display();
+		$this->view->display();
 	}
 
 	/**
 	 * Cancel a task and redirect to the main listing
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function cancelTask()
 	{
@@ -773,16 +851,13 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 
 	/**
 	 * Save a tag
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function saveTask()
 	{
-		// Check for request forgeries
-		JRequest::checkToken() or jexit('Invalid Token');
-
 		// Check that the user is authorized
-		if (!$this->config->get('access-edit-tag'))
+		if (!$this->config->get('access-edit-tag')) 
 		{
 			JError::raiseWarning(403, JText::_('ALERTNOTAUTH'));
 			return;
@@ -790,23 +865,44 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 
 		$tag = JRequest::getVar('fields', array(), 'post');
 
-		// Bind incoming data
-		$row = new TagsModelTag(intval($tag['id']));
-		if (!$row->bind($tag))
+		$row = new TagsTag($this->database);
+		if (!$row->bind($tag)) 
 		{
 			$this->setError($row->getError());
 			$this->editTask($row);
 			return;
 		}
 
-		// Store new content
-		if (!$row->store(true))
+		// Check content
+		if (!$row->check()) 
 		{
 			$this->setError($row->getError());
 			$this->editTask($row);
 			return;
 		}
 
+		// Make sure the tag doesn't already exist
+		if (!$row->id) 
+		{
+			if ($row->checkExistence()) 
+			{
+				$this->setError(JText::_('COM_TAGS_TAG_EXIST'));
+				$this->editTask($row);
+				return;
+			}
+		}
+
+		// Store new content
+		if (!$row->store()) 
+		{
+			$this->setError($row->getError());
+			$this->editTask($row);
+			return;
+		}
+
+		// Save substitutions
+		$row->saveSubstitutions($tag['substitutions']);
+
 		$limit  = JRequest::getInt('limit', 0);
 		$start  = JRequest::getInt('limitstart', 0);
 		$sortby = JRequest::getInt('sortby', '');
@@ -820,13 +916,13 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 
 	/**
 	 * Delete one or more tags
-	 *
-	 * @return  void
+	 * 
+	 * @return     void
 	 */
 	public function deleteTask()
 	{
 		// Check that the user is authorized
-		if (!$this->config->get('access-delete-tag'))
+		if (!$this->config->get('access-delete-tag')) 
 		{
 			JError::raiseWarning(403, JText::_('ALERTNOTAUTH'));
 			return;
@@ -834,13 +930,13 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 
 		// Incoming
 		$ids = JRequest::getVar('id', array());
-		if (!is_array($ids))
+		if (!is_array($ids)) 
 		{
 			$ids = array();
 		}
 
 		// Make sure we have an ID
-		if (empty($ids))
+		if (empty($ids)) 
 		{
 			$this->setRedirect(
 				JRoute::_('index.php?option=' . $this->_option . '&task=browse')
@@ -850,95 +946,63 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 
 		// Get Tags plugins
 		JPluginHelper::importPlugin('tags');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 
 		foreach ($ids as $id)
 		{
-			$id = intval($id);
-
 			// Remove references to the tag
 			$dispatcher->trigger('onTagDelete', array($id));
 
 			// Remove the tag
-			$tag = new TagsModelTag($id);
-			$tag->delete();
+			$tag = new TagsTag($this->database);
+			$tag->delete($id);
 		}
 
-		$this->cleancacheTask(false);
-
-		// Get the browse filters so we can go back to previous view
+		//get the browse filters so we can go back to previous view
 		$search = JRequest::getVar('search', '');
 		$sortby = JRequest::getVar('sortby', '');
 		$limit  = JRequest::getInt('limit', 25);
 		$start  = JRequest::getInt('limitstart', 0);
 		$count  = JRequest::getInt('count', 1);
 
-		// Redirect back to browse mode
+		//redirect back to browse mode
 		$this->setRedirect(
 			JRoute::_('index.php?option=' . $this->_option . '&task=browse&search=' . $search . '&sortby=' . $sortby . '&limit=' . $limit . '&limitstart=' . $start . '#count' . $count)
 		);
 	}
 
-	/**
-	 * Clean cached tags data
-	 *
-	 * @param   boolean  $redirect  Redirect after?
-	 * @return  void
-	 */
-	public function cleancacheTask($redirect=true)
-	{
-		$conf = JFactory::getConfig();
-
-		$cache = JCache::getInstance('', array(
-			'defaultgroup' => '',
-			'storage'      => $conf->get('cache_handler', ''),
-			'caching'      => true,
-			'cachebase'    => $conf->get('cache_path', JPATH_SITE . '/cache')
-		));
-		$cache->clean('tags');
-
-		if (!$redirect)
-		{
-			return true;
-		}
-
-		$this->setRedirect(
-			JRoute::_('index.php?option=' . $this->_option . '&task=browse')
-		);
-	}
-
 	/**
 	 * Method to set the document path
-	 *
-	 * @param   array  $tags  Tags currently viewing
-	 * @return  void
+	 * 
+	 * @param      array $tags Tags currently viewing
+	 * @return     void
 	 */
 	protected function _buildPathway($tags=null)
 	{
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 
-		if (count($pathway->getPathWay()) <= 0)
+		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
 				JText::_(strtoupper($this->_option)),
 				'index.php?option=' . $this->_option
 			);
 		}
-		if ($this->_task && $this->_task != 'view' && $this->_task != 'display')
+		if ($this->_task && $this->_task != 'view' && $this->_task != 'display') 
 		{
 			$pathway->addItem(
 				JText::_(strtoupper($this->_option) . '_' . strtoupper($this->_task)),
 				'index.php?option=' . $this->_option . '&task=' . $this->_task
 			);
 		}
-		if (is_array($tags) && count($tags) > 0)
+		if (is_array($tags) && count($tags) > 0) 
 		{
 			$t = array();
 			$l = array();
 			foreach ($tags as $tag)
 			{
-				$t[] = stripslashes($tag->get('raw_tag'));
-				$l[] = $tag->get('tag');
+				$t[] = stripslashes($tag->raw_tag);
+				$l[] = $tag->tag;
 			}
 
 			$pathway->addItem(
@@ -950,63 +1014,77 @@ class TagsControllerTags extends \Hubzero\Component\SiteController
 
 	/**
 	 * Method to build and set the document title
-	 *
-	 * @param   array  $tags  Tags currently viewing
-	 * @return  void
+	 * 
+	 * @param      array $tags Tags currently viewing
+	 * @return     void
 	 */
 	protected function _buildTitle($tags=null)
 	{
 		$this->view->title = JText::_(strtoupper($this->_option));
-		if ($this->_task && $this->_task != 'view' && $this->_task != 'display')
+		if ($this->_task && $this->_task != 'view' && $this->_task != 'display') 
 		{
 			$this->view->title .= ': ' . JText::_(strtoupper($this->_option) . '_' . strtoupper($this->_task));
 		}
-		if (is_array($tags) && count($tags) > 0)
+		if (is_array($tags) && count($tags) > 0) 
 		{
 			$t = array();
 			foreach ($tags as $tag)
 			{
-				$t[] = stripslashes($tag->get('raw_tag'));
+				$t[] = stripslashes($tag->raw_tag);
 			}
 			$this->view->title .= ': ' . implode(' + ', $t);
 		}
-
-		JFactory::getDocument()->setTitle($this->view->title);
+		$document =& JFactory::getDocument();
+		$document->setTitle($this->view->title);
 	}
 
 	/**
 	 * Method to check admin access permission
 	 *
-	 * @return  boolean  True on success
+	 * @return	boolean	True on success
 	 */
 	protected function _authorize($assetType='tag', $assetId=null)
 	{
 		$this->config->set('access-view-' . $assetType, true);
 
-		if (!$this->juser->get('guest'))
+		if (!$this->juser->get('guest')) 
 		{
-			$asset  = $this->_option;
-			if ($assetId)
+			if (version_compare(JVERSION, '1.6', 'ge'))
 			{
-				$asset .= ($assetType != 'component') ? '.' . $assetType : '';
-				$asset .= ($assetId) ? '.' . $assetId : '';
-			}
+				$asset  = $this->_option;
+				if ($assetId)
+				{
+					$asset .= ($assetType != 'component') ? '.' . $assetType : '';
+					$asset .= ($assetId) ? '.' . $assetId : '';
+				}
 
-			$at = '';
-			if ($assetType != 'component')
+				$at = '';
+				if ($assetType != 'component')
+				{
+					$at .= '.' . $assetType;
+				}
+
+				// Admin
+				$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
+				$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
+				// Permissions
+				$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
+				$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
+				$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
+				$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
+				$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
+			}
+			else 
 			{
-				$at .= '.' . $assetType;
+				if ($this->juser->authorize($this->_option, 'manage'))
+				{
+					$this->config->set('access-manage-' . $assetType, true);
+					$this->config->set('access-admin-' . $assetType, true);
+					$this->config->set('access-create-' . $assetType, true);
+					$this->config->set('access-delete-' . $assetType, true);
+					$this->config->set('access-edit-' . $assetType, true);
+				}
 			}
-
-			// Admin
-			$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
-			$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
-			// Permissions
-			$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
-			$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
-			$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
-			$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
-			$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
 		}
 	}
 }
