@@ -31,14 +31,16 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Controller class for tools (default)
  */
-class ToolsControllerTools extends \Hubzero\Component\SiteController
+class ToolsControllerTools extends Hubzero_Controller
 {
 	/**
 	 * Execute a task
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function execute()
@@ -51,8 +53,7 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 		// Check if middleware is enabled
 		if ($task != 'image'
 		 && $task != 'css'
-		 && $task != 'assets'
-		 && (!$this->config->get('mw_on') || ($this->config->get('mw_on') > 1 && !$this->config->get('access-admin-component'))))
+		 && (!$this->config->get('mw_on') || ($this->config->get('mw_on') > 1 && !$this->config->get('access-admin-component')))) 
 		{
 			// Redirect to home page
 			$this->setRedirect(
@@ -60,7 +61,7 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 			);
 			return;
 		}
-
+		
 		parent::execute();
 	}
 
@@ -72,11 +73,11 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 	protected function _buildTitle($title=null)
 	{
 		$this->_title = ($title) ? $title : JText::_(strtoupper($this->_option));
-		if ($this->_task && $this->_task != 'display')
+		if ($this->_task && $this->_task != 'display') 
 		{
 			$this->_title .= ': ' . JText::_(strtoupper($this->_option) . '_' . strtoupper($this->_task));
 		}
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle($this->_title);
 	}
 
@@ -87,16 +88,16 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 	 */
 	protected function _buildPathway()
 	{
-		$pathway = JFactory::getApplication()->getPathway();
+		$pathway =& JFactory::getApplication()->getPathway();
 
-		if (count($pathway->getPathWay()) <= 0)
+		if (count($pathway->getPathWay()) <= 0) 
 		{
 			$pathway->addItem(
-				(isset($this->_title) ? $this->_title : JText::_(strtoupper($this->_option))),
+				$this->_title,
 				'index.php?option=' . $this->_option
 			);
 		}
-		if ($this->_task && $this->_task != 'display')
+		if ($this->_task && $this->_task != 'display') 
 		{
 			$pathway->addItem(
 				JText::_(strtoupper($this->_option) . '_' . strtoupper($this->_task)),
@@ -107,7 +108,7 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 
 	/**
 	 * Display the landing page
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function displayTask()
@@ -119,12 +120,13 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 		$this->view->apps = $model->getApplicationTools();
 
 		// Get the forge image
-		$this->view->image = \Hubzero\Document\Assets::getComponentImage($this->_option, 'forge.png', 1);
+		ximport('Hubzero_Document');
+		$this->view->image = Hubzero_Document::getComponentImage($this->_option, 'forge.png', 1);
 
 		// Get some vars to fill in text
 		$this->view->title = $this->_title;
 
-		$jconfig = JFactory::getConfig();
+		$jconfig =& JFactory::getConfig();
 
 		$live_site = rtrim(JURI::base(),'/');
 		$slive_site = preg_replace('/^http:\/\//', 'https://', $live_site, 1);
@@ -137,7 +139,11 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 		// Set the pathway
 		$this->_buildPathway();
 
-		if ($this->getError())
+		// Push some styles to the template
+		$this->_getStyles('', 'introduction.css', true); // component, stylesheet name, look in media system dir
+		$this->_getStyles($this->_option, 'tools.css');
+
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -147,57 +153,17 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 		$this->view->display();
 	}
 
-	/**
-	 * Tool asset delivery function.
- 	 * Original purpose was to deliver a template overrideable css file for the filexfer package
-	 *
-	 * @return    exit
-	 */
-	public function assetsTask()
-	{
-		$type = JRequest::getVar('type', 'css');
-		$file = JRequest::getVar('file', '');
-
-		if (($type != 'css') || empty($file))
-		{
-			ob_clean();
-			header("HTTP/1.1 404 Not Found");
-			ob_end_flush();
-			exit;
-		}
-
-		if ($type == 'css')
-		{
-			$file = JPATH_SITE . \Hubzero\Document\Assets::getComponentStylesheet($this->_option, $file);
-
-			if (is_readable($file))
-			{
-				ob_clean();
-				header("Content-Type: text/css");
-				readfile($file);
-				ob_end_flush();
-				exit;
-			}
-			else
-			{
-				ob_clean();
-				header("HTTP/1.1 404 Not Found");
-				ob_end_flush();
-				exit;
-			}
-		}
-	}
-
 	/**
 	 * Display the FORGE logo
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function imageTask()
 	{
-		$image = JPATH_SITE . \Hubzero\Document\Assets::getComponentImage($this->_option, 'forge.png', 1);
+		ximport('Hubzero_Document');
+		$image = JPATH_SITE . Hubzero_Document::getComponentImage($this->_option, 'forge.png', 1);
 
-		if (is_readable($image))
+		if (is_readable($image)) 
 		{
 			ob_clean();
 			header("Content-Type: image/png");
@@ -209,14 +175,15 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 
 	/**
 	 * Display CSS
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function cssTask()
 	{
-		$file = JPATH_SITE . \Hubzero\Document\Assets::getComponentStylesheet($this->_option, 'site_css.css');
+		ximport('Hubzero_Document');
+		$file = JPATH_SITE . Hubzero_Document::getComponentStylesheet($this->_option, 'site_css.css');
 
-		if (is_readable($file))
+		if (is_readable($file)) 
 		{
 			ob_clean();
 			header("Content-Type: text/css");
@@ -228,7 +195,7 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 
 	/**
 	 * Authorization checks
-	 *
+	 * 
 	 * @param      string $assetType Asset type
 	 * @param      string $assetId   Asset id to check against
 	 * @return     void
@@ -236,30 +203,44 @@ class ToolsControllerTools extends \Hubzero\Component\SiteController
 	public function _authorize($assetType='component', $assetId=null)
 	{
 		$this->config->set('access-view-' . $assetType, true);
-		if (!$this->juser->get('guest'))
+		if (!$this->juser->get('guest')) 
 		{
-			$asset  = $this->_option;
-			if ($assetId)
+			if (version_compare(JVERSION, '1.6', 'ge'))
 			{
-				$asset .= ($assetType != 'component') ? '.' . $assetType : '';
-				$asset .= ($assetId) ? '.' . $assetId : '';
-			}
+				$asset  = $this->_option;
+				if ($assetId)
+				{
+					$asset .= ($assetType != 'component') ? '.' . $assetType : '';
+					$asset .= ($assetId) ? '.' . $assetId : '';
+				}
 
-			$at = '';
-			if ($assetType != 'component')
+				$at = '';
+				if ($assetType != 'component')
+				{
+					$at .= '.' . $assetType;
+				}
+
+				// Admin
+				$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
+				$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
+				// Permissions
+				$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
+				$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
+				$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
+				$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
+				$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
+			}
+			else 
 			{
-				$at .= '.' . $assetType;
+				if ($this->juser->authorize($this->_option, 'manage'))
+				{
+					$this->config->set('access-manage-' . $assetType, true);
+					$this->config->set('access-admin-' . $assetType, true);
+					$this->config->set('access-create-' . $assetType, true);
+					$this->config->set('access-delete-' . $assetType, true);
+					$this->config->set('access-edit-' . $assetType, true);
+				}
 			}
-
-			// Admin
-			$this->config->set('access-admin-' . $assetType, $this->juser->authorise('core.admin', $asset));
-			$this->config->set('access-manage-' . $assetType, $this->juser->authorise('core.manage', $asset));
-			// Permissions
-			$this->config->set('access-create-' . $assetType, $this->juser->authorise('core.create' . $at, $asset));
-			$this->config->set('access-delete-' . $assetType, $this->juser->authorise('core.delete' . $at, $asset));
-			$this->config->set('access-edit-' . $assetType, $this->juser->authorise('core.edit' . $at, $asset));
-			$this->config->set('access-edit-state-' . $assetType, $this->juser->authorise('core.edit.state' . $at, $asset));
-			$this->config->set('access-edit-own-' . $assetType, $this->juser->authorise('core.edit.own' . $at, $asset));
 		}
 	}
 }
