@@ -31,122 +31,178 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Controller');
+
 /**
  * Wiki controller class for media
  */
-class WikiControllerMedia extends \Hubzero\Component\SiteController
+class WikiControllerMedia extends Hubzero_Controller
 {
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      array $config Optional configurations
 	 * @return     void
 	 */
 	public function __construct($config=array())
 	{
 		$this->_base_path = JPATH_ROOT . DS . 'components' . DS . 'com_wiki';
-		if (isset($config['base_path']))
-		{
-			$this->_base_path = $config['base_path'];
-		}
 
 		$this->_sub = false;
-		if (isset($config['sub']))
+		if (isset($config['sub'])) 
 		{
 			$this->_sub = $config['sub'];
 		}
 
 		$this->_group = false;
-		if (isset($config['group']))
+		if (isset($config['group'])) 
 		{
 			$this->_group = $config['group'];
 		}
 
-		$this->book = new WikiModelBook(($this->_group ? $this->_group : '__site__'));
+		/*$this->_access = false;
+		if (isset($config['access'])) 
+		{
+			$this->_access = $config['access'];
+		}*/
 
 		parent::__construct($config);
 	}
 
 	/**
 	 * Execute a task
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function execute()
 	{
-		$this->page = $this->book->page();
+		if ($this->_sub || $this->_option != 'com_wiki')
+		{
+			$this->config = JComponentHelper::getParams('com_wiki');
+		}
+		
+		define('WIKI_SUBPAGE_SEPARATOR', $this->config->get('subpage_separator', '/'));
+		define('WIKI_MAX_PAGENAME_LENGTH', $this->config->get('max_pagename_length', 100));
+
+		$this->page   = WikiHelperPage::getPage($this->config);
+		$this->config = WikiHelperPage::authorize($this->config, $this->page);
 
 		parent::execute();
 	}
 
 	/**
 	 * Download a wiki file
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function downloadTask()
 	{
-		$this->page->set('pagename', trim(JRequest::getVar('pagename', '', 'default', 'none', 2)));
+		// Get some needed libraries
+		ximport('Hubzero_Content_Server');
 
 		// Instantiate an attachment object
-		$attachment = new WikiTableAttachment($this->database);
-		if ($this->page->get('namespace') == 'image' || $this->page->get('namespace') == 'file')
+		$attachment = new WikiPageAttachment($this->database);
+		if (substr(strtolower($this->page->pagename), 0, strlen('image:')) == 'image:') 
 		{
-			$attachment->filename = $this->page->denamespaced();
+			$attachment->filename .= substr($this->page->pagename, strlen('image:'));
+		} 
+		else if (substr(strtolower($this->page->pagename), 0, strlen('file:')) == 'file:') 
+		{
+			$attachment->filename .= substr($this->page->pagename, strlen('file:'));
 		}
 		$attachment->filename = urldecode($attachment->filename);
 
 		// Get the scope of the parent page the file is attached to
-		if (!$this->scope)
+		if (!$this->scope) 
 		{
 			$this->scope = trim(JRequest::getVar('scope', ''));
 		}
-		$segments = explode('/', $this->scope);
+		$segments = explode(DS, $this->scope);
 		$pagename = array_pop($segments);
-		$scope = implode('/', $segments);
+		$scope = implode(DS, $segments);
 
 		// Get the parent page the file is attached to
-		$this->page = new WikiModelPage($pagename, $scope);
+		$this->page = new WikiPage($this->database);
+		$this->page->load($pagename, $scope);
 
 		// Load the page
-		if ($this->page->exists())
-		{
-			// Check if the page is group restricted and the user is authorized
-			if ($this->page->get('group_cn') != '' && $this->page->get('access') != 0 && !$this->page->access('view'))
-			{
-				JError::raiseWarning(403, JText::_('COM_WIKI_WARNING_NOT_AUTH'));
-				return;
-			}
-		}
-		else if ($this->page->get('namespace') == 'tmp')
-		{
-			$this->page->set('id', $this->page->denamespaced());
-		}
-		else
+		if (!$this->page->id) 
 		{
 			JError::raiseError(404, JText::_('COM_WIKI_PAGE_NOT_FOUND'));
 			return;
 		}
 
+		// Check authorization
+		$paramClass = 'JParameter';
+		if (version_compare(JVERSION, '1.6', 'ge'))
+		{
+			$paramClass = 'JRegistry';
+		}
+		$this->page->params = new $paramClass($this->page->params);
+		
+		$this->config = WikiHelperPage::authorize($this->config, $this->page);
+
+		// Check if the page is group restricted and the user is authorized
+		if ($this->page->group != '' && $this->page->access != 0 && !$this->config->get('access-view')) 
+		{
+			if ($this->_sub) 
+			{
+				echo WikiHtml::warning(JText::_('WIKI_WARNING_NOT_AUTH'));
+			} 
+			else 
+			{
+				JError::raiseWarning(403, JText::_('WIKI_WARNING_NOT_AUTH'));
+			}
+			return;
+		}
+
 		// Ensure we have a path
-		if (empty($attachment->filename))
+		if (empty($attachment->filename)) 
 		{
 			JError::raiseError(404, JText::_('COM_WIKI_FILE_NOT_FOUND'));
 			return;
 		}
+		if (preg_match("/^\s*http[s]{0,1}:/i", $attachment->filename)) 
+		{
+			JError::raiseError(404, JText::_('COM_WIKI_BAD_FILE_PATH'));
+			return;
+		}
+		if (preg_match("/^\s*[\/]{0,1}index.php\?/i", $attachment->filename)) 
+		{
+			JError::raiseError(404, JText::_('COM_WIKI_BAD_FILE_PATH'));
+			return;
+		}
+		// Disallow windows drive letter
+		if (preg_match("/^\s*[.]:/", $attachment->filename)) 
+		{
+			JError::raiseError(404, JText::_('COM_WIKI_BAD_FILE_PATH'));
+			return;
+		}
+		// Disallow \
+		if (strpos('\\', $attachment->filename)) 
+		{
+			JError::raiseError(404, JText::_('COM_WIKI_BAD_FILE_PATH'));
+			return;
+		}
+		// Disallow ..
+		if (strpos('..', $attachment->filename)) 
+		{
+			JError::raiseError(404, JText::_('COM_WIKI_BAD_FILE_PATH'));
+			return;
+		}
 
 		// Get the configured upload path
-		$base_path = DS . trim($this->book->config('filepath', '/site/wiki'), DS) . DS . $this->page->get('id');
+		$base_path = DS . trim($this->config->get('filepath', '/site/wiki'), DS) . DS . $this->page->id;
 
 		// Does the path start with a slash?
 		$attachment->filename = DS . ltrim($attachment->filename, DS);
 
 		// Does the beginning of the $attachment->path match the config path?
-		if (substr($attachment->filename, 0, strlen($base_path)) == $base_path)
+		if (substr($attachment->filename, 0, strlen($base_path)) == $base_path) 
 		{
 			// Yes - this means the full path got saved at some point
-		}
-		else
+		} 
+		else 
 		{
 			// No - append it
 			$attachment->filename = $base_path . $attachment->filename;
@@ -156,24 +212,24 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 		$filename = JPATH_ROOT . $attachment->filename;
 
 		// Ensure the file exist
-		if (!file_exists($filename))
+		if (!file_exists($filename)) 
 		{
-			JError::raiseError(404, JText::_('COM_WIKI_FILE_NOT_FOUND') . ' ' . $filename);
+			JError::raiseError(404, JText::_('COM_WIKI_FILE_NOT_FOUND').' '.$filename);
 			return;
 		}
 
 		// Initiate a new content server and serve up the file
-		$xserver = new \Hubzero\Content\Server();
+		$xserver = new Hubzero_Content_Server();
 		$xserver->filename($filename);
 		$xserver->disposition('inline');
 		$xserver->acceptranges(false); // @TODO fix byte range support
 
-		if (!$xserver->serve())
+		if (!$xserver->serve()) 
 		{
 			// Should only get here on error
 			JError::raiseError(404, JText::_('COM_WIKI_SERVER_ERROR'));
-		}
-		else
+		} 
+		else 
 		{
 			exit;
 		}
@@ -182,31 +238,31 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Upload a file to the wiki via AJAX
-	 *
+	 * 
 	 * @return     string
 	 */
 	public function ajaxUploadTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
-			echo json_encode(array('error' => JText::_('COM_WIKI_WARNING_LOGIN')));
+			echo json_encode(array('error' => JText::_('Must be logged in.')));
 			return;
 		}
 
 		// Ensure we have an ID to work with
 		$listdir = JRequest::getInt('listdir', 0);
-		if (!$listdir)
+		if (!$listdir) 
 		{
-			echo json_encode(array('error' => JText::_('COM_WIKI_NO_ID')));
+			echo json_encode(array('error' => JText::_('WIKI_NO_ID')));
 			return;
 		}
-
+		
 		//allowed extensions for uplaod
 		//$allowedExtensions = array("png","jpeg","jpg","gif");
-
+		
 		//max upload size
-		$sizeLimit = $this->book->config('maxAllowed', 40000000);
+		$sizeLimit = $this->config->get('maxAllowed', 40000000);
 
 		// get the file
 		if (isset($_GET['qqfile']))
@@ -218,60 +274,60 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 		elseif (isset($_FILES['qqfile']))
 		{
 			//$files = JRequest::getVar('qqfile', '', 'files', 'array');
-
+			
 			$stream = false;
 			$file = $_FILES['qqfile']['name'];
 			$size = (int) $_FILES['qqfile']['size'];
 		}
 		else
 		{
-			echo json_encode(array('error' => JText::_('COM_WIKI_ERROR_NO_FILE')));
+			echo json_encode(array('error' => JText::_('File not found')));
 			return;
 		}
 
 		//define upload directory and make sure its writable
-		$path = JPATH_ROOT . DS . trim($this->book->config('filepath', '/site/wiki'), DS) . DS . $listdir;
-		if (!is_dir($path))
+		$path = JPATH_ROOT . DS . trim($this->config->get('filepath', '/site/wiki'), DS) . DS . $listdir;
+		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path))
+			if (!JFolder::create($path, 0777)) 
 			{
-				echo json_encode(array('error' => JText::_('COM_WIKI_ERROR_UNABLE_TO_CREATE_DIRECTORY')));
+				echo json_encode(array('error' => JText::_('Error uploading. Unable to create path.')));
 				return;
 			}
 		}
 
 		if (!is_writable($path))
 		{
-			echo json_encode(array('error' => JText::_('COM_WIKI_ERROR_DIRECTORY_NOT_WRITABLE')));
+			echo json_encode(array('error' => JText::_('Server error. Upload directory isn\'t writable.')));
 			return;
 		}
 
 		//check to make sure we have a file and its not too big
-		if ($size == 0)
+		if ($size == 0) 
 		{
-			echo json_encode(array('error' => JText::_('COM_WIKI_ERROR_NO_FILE')));
+			echo json_encode(array('error' => JText::_('File is empty')));
 			return;
 		}
-		if ($size > $sizeLimit)
+		if ($size > $sizeLimit) 
 		{
-			$max = preg_replace('/<abbr \w+=\\"\w+\\">(\w{1,3})<\\/abbr>/', '$1', \Hubzero\Utility\Number::formatBytes($sizeLimit));
-			echo json_encode(array('error' => JText::sprintf('COM_WIKI_ERROR_FILE_TOO_LARGE', $max)));
+			$max = preg_replace('/<abbr \w+=\\"\w+\\">(\w{1,3})<\\/abbr>/', '$1', Hubzero_View_Helper_Html::formatSize($sizeLimit));
+			echo json_encode(array('error' => JText::sprintf('File is too large. Max file upload size is %s', $max)));
 			return;
 		}
 
 		// don't overwrite previous files that were uploaded
 		$pathinfo = pathinfo($file);
 		$filename = $pathinfo['filename'];
-
+		
 		// Make the filename safe
 		jimport('joomla.filesystem.file');
 		$filename = urldecode($filename);
 		$filename = JFile::makeSafe($filename);
 		$filename = str_replace(' ', '_', $filename);
-
+		
 		$ext = $pathinfo['extension'];
-		while (file_exists($path . DS . $filename . '.' . $ext))
+		while (file_exists($path . DS . $filename . '.' . $ext)) 
 		{
 			$filename .= rand(10, 99);
 		}
@@ -285,7 +341,7 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 			$temp = tmpfile();
 			$realSize = stream_copy_to_stream($input, $temp);
 			fclose($input);
-
+		
 			//move from temp location to target location which is user folder
 			$target = fopen($file , "w");
 			fseek($temp, 0, SEEK_SET);
@@ -298,25 +354,25 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 		}
 
 		// Create database entry
-		$attachment = new WikiTableAttachment($this->database);
+		$attachment = new WikiPageAttachment($this->database);
 		$attachment->pageid      = $listdir;
 		$attachment->filename    = $filename . '.' . $ext;
 		$attachment->description = trim(JRequest::getVar('description', '', 'post'));
-		$attachment->created     = JFactory::getDate()->toSql();
+		$attachment->created     = date('Y-m-d H:i:s', time());
 		$attachment->created_by  = $this->juser->get('id');
 
-		if (!$attachment->check())
+		if (!$attachment->check()) 
 		{
 			$this->setError($attachment->getError());
 		}
-		if (!$attachment->store())
+		if (!$attachment->store()) 
 		{
 			$this->setError($attachment->getError());
 		}
 
 		//echo result
 		echo json_encode(array(
-			'success'   => true,
+			'success'   => true, 
 			'file'      => $filename . '.' . $ext,
 			'directory' => str_replace(JPATH_ROOT, '', $path)
 		));
@@ -324,13 +380,13 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Upload a file to the wiki
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function uploadTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			$this->displayTask();
 			return;
@@ -343,31 +399,31 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 
 		// Ensure we have an ID to work with
 		$listdir = JRequest::getInt('listdir', 0, 'post');
-		if (!$listdir)
+		if (!$listdir) 
 		{
-			$this->setError(JText::_('COM_WIKI_NO_ID'));
+			$this->setError(JText::_('WIKI_NO_ID'));
 			$this->displayTask();
 			return;
 		}
 
 		// Incoming file
 		$file = JRequest::getVar('upload', '', 'files', 'array');
-		if (!$file['name'])
+		if (!$file['name']) 
 		{
-			$this->setError(JText::_('COM_WIKI_NO_FILE'));
+			$this->setError(JText::_('WIKI_NO_FILE'));
 			$this->displayTask();
 			return;
 		}
 
 		// Build the upload path if it doesn't exist
-		$path = JPATH_ROOT . DS . trim($this->book->config('filepath', '/site/wiki'), DS) . DS . $listdir;
+		$path = JPATH_ROOT . DS . trim($this->config->get('filepath', '/site/wiki'), DS) . DS . $listdir;
 
-		if (!is_dir($path))
+		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path))
+			if (!JFolder::create($path, 0777)) 
 			{
-				$this->setError(JText::_('COM_WIKI_ERROR_UNABLE_TO_CREATE_DIRECTORY'));
+				$this->setError(JText::_('Error uploading. Unable to create path.'));
 				$this->displayTask();
 				return;
 			}
@@ -380,26 +436,26 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 		$file['name'] = str_replace(' ', '_', $file['name']);
 
 		// Upload new files
-		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name']))
+		if (!JFile::upload($file['tmp_name'], $path . DS . $file['name'])) 
 		{
-			$this->setError(JText::_('COM_WIKI_ERROR_UPLOADING'));
+			$this->setError(JText::_('ERROR_UPLOADING'));
 		}
-		// File was uploaded
-		else
+		// File was uploaded 
+		else 
 		{
 			// Create database entry
-			$attachment = new WikiTableAttachment($this->database);
+			$attachment = new WikiPageAttachment($this->database);
 			$attachment->pageid      = $listdir;
 			$attachment->filename    = $file['name'];
 			$attachment->description = trim(JRequest::getVar('description', '', 'post'));
-			$attachment->created     = JFactory::getDate()->toSql();
+			$attachment->created     = date('Y-m-d H:i:s', time());
 			$attachment->created_by  = $this->juser->get('id');
 
-			if (!$attachment->check())
+			if (!$attachment->check()) 
 			{
 				$this->setError($attachment->getError());
 			}
-			if (!$attachment->store())
+			if (!$attachment->store()) 
 			{
 				$this->setError($attachment->getError());
 			}
@@ -411,13 +467,13 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Delete a folder in the wiki
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function deletefolderTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			$this->displayTask();
 			return;
@@ -425,44 +481,38 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 
 		// Incoming group ID
 		$listdir = JRequest::getInt('listdir', 0, 'get');
-		if (!$listdir)
+		if (!$listdir) 
 		{
-			$this->setError(JText::_('COM_WIKI_NO_ID'));
+			$this->setError(JText::_('WIKI_NO_ID'));
 			$this->displayTask();
 			return;
 		}
 
 		// Incoming folder
 		$folder = trim(JRequest::getVar('folder', '', 'get'));
-		if (!$folder)
+		if (!$folder) 
 		{
-			$this->setError(JText::_('COM_WIKI_NO_DIRECTORY'));
+			$this->setError(JText::_('WIKI_NO_DIRECTORY'));
 			$this->displayTask();
 			return;
 		}
 
 		// Build the file path
-		$path = JPATH_ROOT . DS . trim($this->book->config('filepath', '/site/wiki'), DS) . DS . $listdir . DS . $folder;
+		$path = JPATH_ROOT . DS . trim($this->config->get('filepath', '/site/wiki'), DS) . DS . $listdir . DS . $folder;
 
 		// Delete the folder
-		if (is_dir($path))
+		if (is_dir($path)) 
 		{
 			// Attempt to delete the file
 			jimport('joomla.filesystem.file');
-			if (!JFolder::delete($path))
+			if (!JFolder::delete($path)) 
 			{
-				$this->setError(JText::_('COM_WIKI_ERROR_UNABLE_TO_DELETE_DIRECTORY'));
+				$this->setError(JText::_('UNABLE_TO_DELETE_DIRECTORY'));
 			}
-		}
-		else
+		} 
+		else 
 		{
-			$this->setError(JText::_('COM_WIKI_NO_DIRECTORY'));
-		}
-
-		// Push through to the media view
-		if (JRequest::getVar('no_html', 0))
-		{
-			return $this->listTask();
+			$this->setError(JText::_('WIKI_NO_DIRECTORY'));
 		}
 
 		// Push through to the media view
@@ -471,13 +521,13 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Delete a file in the wiki
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function deletefileTask()
 	{
 		// Check if they're logged in
-		if ($this->juser->get('guest'))
+		if ($this->juser->get('guest')) 
 		{
 			$this->displayTask();
 			return;
@@ -485,59 +535,54 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 
 		// Incoming
 		$listdir = JRequest::getInt('listdir', 0, 'get');
-		if (!$listdir)
+		if (!$listdir) 
 		{
-			$this->setError(JText::_('COM_WIKI_NO_ID'));
+			$this->setError(JText::_('WIKI_NO_ID'));
 			$this->displayTask();
 			return;
 		}
 
 		// Incoming file
 		$file = trim(JRequest::getVar('file', '', 'get'));
-		if (!$file)
+		if (!$file) 
 		{
-			$this->setError(JText::_('COM_WIKI_NO_FILE'));
+			$this->setError(JText::_('WIKI_NO_FILE'));
 			$this->displayTask();
 			return;
 		}
 
 		// Build the file path
-		$path = JPATH_ROOT . DS . trim($this->book->config('filepath', '/site/wiki'), DS) . DS . $listdir;
+		$path = JPATH_ROOT . DS . trim($this->config->get('filepath', '/site/wiki'), DS) . DS . $listdir;
 
 		// Delete the file
-		if (!file_exists($path . DS . $file) or !$file)
+		if (!file_exists($path . DS . $file) or !$file) 
 		{
-			$this->setError(JText::_('COM_WIKI_ERROR_NO_FILE'));
+			$this->setError(JText::_('FILE_NOT_FOUND'));
 			$this->displayTask();
-		}
-		else
+		} 
+		else 
 		{
 			// Attempt to delete the file
 			jimport('joomla.filesystem.file');
-			if (!JFile::delete($path . DS . $file))
+			if (!JFile::delete($path . DS . $file)) 
 			{
-				$this->setError(JText::sprintf('COM_WIKI_ERROR_UNABLE_TO_DELETE_FILE', $file));
-			}
-			else
+				$this->setError(JText::_('UNABLE_TO_DELETE_FILE'));
+			} 
+			else 
 			{
 				// Delete the database entry for the file
-				$attachment = new WikiTableAttachment($this->database);
+				$attachment = new WikiPageAttachment($this->database);
 				$attachment->deleteFile($file, $listdir);
 			}
 		}
 
 		// Push through to the media view
-		if (JRequest::getVar('no_html', 0))
-		{
-			return $this->listTask();
-		}
-
 		$this->displayTask();
 	}
 
 	/**
 	 * Display a form for uploading files
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function displayTask()
@@ -550,7 +595,7 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 		// Output HTML
 		$this->view->config = $this->config;
 
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -563,22 +608,20 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 
 	/**
 	 * Display a list of files
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function listTask()
 	{
-		$this->view->setLayout('list');
-
 		// Incoming
 		$listdir = JRequest::getInt('listdir', 0, 'get');
 
-		if (!$listdir)
+		if (!$listdir) 
 		{
-			$this->setError(JText::_('COM_WIKI_NO_ID'));
+			$this->setError(JText::_('WIKI_NO_ID'));
 		}
 
-		$path = JPATH_ROOT . DS . trim($this->book->config('filepath', '/site/wiki'), DS) . DS . $listdir;
+		$path = JPATH_ROOT . DS . trim($this->config->get('filepath', '/site/wiki'), DS) . DS . $listdir;
 
 		$folders = array();
 		$docs    = array();
@@ -618,15 +661,17 @@ class WikiControllerMedia extends \Hubzero\Component\SiteController
 			ksort($docs);
 		}
 
-		$this->view->docs    = $docs;
+		$this->view->docs = $docs;
 		$this->view->folders = $folders;
 
-		$this->view->config  = $this->config;
+		$this->view->config = $this->config;
 		$this->view->listdir = $listdir;
-		$this->view->name    = $this->_name;
-		$this->view->sub     = $this->_sub;
+		$this->view->name = $this->_name;
+		$this->view->sub = $this->_sub;
 
-		if ($this->getError())
+		$this->_getStyles();
+
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
