@@ -41,31 +41,8 @@ class WikiHelperPage
 	 */
 	public static function getPage($config)
 	{
-		$db = JFactory::getDBO();
-
-		$tbl = new WikiPage($db);
 		$pagename = trim(JRequest::getVar('pagename', '', 'default', 'none', 2));
-		if (substr(strtolower($pagename), 0, strlen('image:')) != 'image:' 
-		 && substr(strtolower($pagename), 0, strlen('file:')) != 'file:')
-		{
-			$pagename = $tbl->normalize($pagename);
-		} 
-		JRequest::setVar('pagename', $pagename);
-
 		$scope = trim(JRequest::getVar('scope', ''));
-		if ($scope)
-		{
-			// Clean the scope. Since scope is built of a chain of pagenames or groups/groupname/wiki
-			// the wiki normalize() should strip any nasty stuff out
-			$bits = explode('/', $scope);
-			foreach ($bits as $i => $bit)
-			{
-				$bits[$i] = preg_replace("/[^\:a-zA-Z0-9_\-]/", '', $bit);
-			}
-			$scope = implode('/', $bits);
-			JRequest::setVar('scope', $scope);
-		}
-
 		$task = trim(JRequest::getWord('task', ''));
 
 		// No page name given! Default to the home page
@@ -75,17 +52,15 @@ class WikiHelperPage
 		}
 
 		// Load the page
-		//$page = WikiPage::getInstance($pagename, $scope);
-		$page = new WikiPage($db);
-		$page->load($pagename, $scope);
+		$database =& JFactory::getDBO();
 
-		/*if (in_array(strtolower($page->getNamespace()), array('special'))) 
-		{
-			$page->load(JRequest::getVar('page', ''), $scope);
-		}*/
+		$page = new WikiPage($database);
+		$page->load($pagename, $scope);
+		$page->scope = $scope;
+		$page->pagename = $pagename;
 
 		if (!$page->exist() 
-		 && (strtolower($page->getNamespace()) == 'help')) 
+		 && (substr(strtolower($pagename), 0, strlen('help:')) == 'help:')) 
 		{
 			$page->load($pagename, '');
 			$page->scope = $scope;
@@ -121,7 +96,7 @@ class WikiHelperPage
 		$config->set('access-comment-delete', false);
 		$config->set('access-comment-edit', false);
 
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 
 		// Check if they are logged in
 		if ($juser->get('guest')) 
@@ -132,6 +107,24 @@ class WikiHelperPage
 
 		$option = JRequest::getCmd('option', 'com_wiki');
 
+		// Check if they're a site admin (from Joomla)
+		if ($juser->authorize($option, 'manage')) 
+		{
+			$config->set('access-admin', true);
+			$config->set('access-manage', true);
+			$config->set('access-create', true);
+			$config->set('access-delete', true);
+			$config->set('access-edit', true);
+			$config->set('access-modify', true);
+
+			$config->set('access-comment-view', true);
+			$config->set('access-comment-create', true);
+			$config->set('access-comment-delete', true);
+			$config->set('access-comment-edit', true);
+
+			return $config;
+		}
+
 		// Is a group set?
 		if (trim($page->group_cn)) 
 		{
@@ -201,23 +194,6 @@ class WikiHelperPage
 				}
 			}
 		}
-		// Check if they're a site admin (from Joomla)
-		else if ($juser->authorize($option, 'manage')) 
-		{
-			$config->set('access-admin', true);
-			$config->set('access-manage', true);
-			$config->set('access-create', true);
-			$config->set('access-delete', true);
-			$config->set('access-edit', true);
-			$config->set('access-modify', true);
-
-			$config->set('access-comment-view', true);
-			$config->set('access-comment-create', true);
-			$config->set('access-comment-delete', true);
-			$config->set('access-comment-edit', true);
-
-			return $config;
-		}
 		// No group = Site wiki
 		else 
 		{
