@@ -30,44 +30,54 @@
 
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
-
-if (!$this->sub)
-{
-	$this->css();
-}
-$this->js();
 ?>
-<header id="<?php echo ($this->sub) ? 'sub-content-header' : 'content-header'; ?>">
+<div id="<?php echo ($this->page->group_cn) ? 'sub-content-header' : 'content-header'; ?>" class="full">
 	<h2><?php echo $this->escape($this->title); ?></h2>
-</header><!-- /#content-header -->
+</div><!-- /#content-header -->
 
 <?php
-	$this->view('submenu', 'page')
-	     ->setBasePath($this->base_path)
-	     ->set('option', $this->option)
-	     ->set('controller', $this->controller)
-	     ->set('page', $this->page)
-	     ->set('task', $this->task)
-	     ->set('sub', $this->sub)
-	     ->display();
+	$view = new JView(array(
+		'base_path' => $this->base_path, 
+		'name'      => 'page',
+		'layout'    => 'submenu'
+	));
+	$view->option = $this->option;
+	$view->controller = $this->controller;
+	$view->page   = $this->page;
+	$view->task   = $this->task;
+	$view->config = $this->config;
+	$view->sub    = $this->sub;
+	$view->display();
 ?>
 
-<section class="main section">
+<div class="main section">
 	<p class="warning">
-		<?php echo JText::sprintf('COM_WIKI_WARNING_PAGE_DOES_NOT_EXIST_CREATE_IT', JRoute::_($this->page->link('new'))); ?>
+		This page does not exist. Would you like to <a href="<?php echo JRoute::_('index.php?option='.$this->option.'&scope='.$this->page->scope.'&pagename='.$this->page->pagename.'&task=new'); ?>">create it?</a>
 	</p>
-<?php if (count($this->book->templates('list', array(), 'true'))) { ?>
 	<p>
-		<?php echo JText::_('COM_WIKI_CHOOSE_TEMPLATE'); ?>
+		<?php echo JText::_('Or choose a page template to create an already-formatted page:'); ?>
 	</p>
 	<ul>
-	<?php foreach ($this->book->templates() as $template) { ?>
+<?php 
+if ($templates = $this->page->getTemplates()) {
+	foreach ($templates as $template)
+	{
+?>
 		<li>
-			<a href="<?php echo JRoute::_($this->page->link('new') . '&tplate=' . stripslashes($template->get('pagename'))); ?>">
-				<?php echo $this->escape(stripslashes($template->get('title'))); ?>
+			<a href="<?php echo JRoute::_('index.php?option='.$this->option.'&scope='.$this->page->scope.'&pagename='.$this->page->pagename.'&task=new&tplate='.stripslashes($template->pagename)); ?>">
+				<?php echo stripslashes($template->pagename); ?>
 			</a>
 		</li>
-	<?php } ?>
+<?php
+	}
+} else {
+?>
+		<li>
+			<?php echo JText::_('No templates available.'); ?>
+		</li>
+<?php
+}
+?>
 	</ul>
-<?php } ?>
-</section><!-- / .main section -->
+	<div class="clear"></div>
+</div><!-- / .main section -->
