@@ -70,13 +70,6 @@ class Hubzero_Group
 	 */
 	private $published = null;
 	
-	/**
-	 * Description for 'approved'
-	 *
-	 * @var unknown
-	 */
-	private $approved = null;
-	
 	/**
 	 * Description for 'type'
 	 *
@@ -84,6 +77,13 @@ class Hubzero_Group
 	 */
 	private $type = null;
 	
+	/**
+	 * Description for 'access'
+	 *
+	 * @var unknown
+	 */
+	private $access = null;
+	
 	/**
 	 * Description for 'public_desc'
 	 *
@@ -113,11 +113,11 @@ class Hubzero_Group
 	private $join_policy = null;
 	
 	/**
-	 * Description for 'discoverability'
+	 * Description for 'privacy'
 	 *
 	 * @var unknown
 	 */
-	private $discoverability = null;
+	private $privacy = null;
 	
 	/**
 	 * Description for 'discussion_email_autosubscribe'
@@ -262,54 +262,22 @@ class Hubzero_Group
 	}
 
 	/**
-	 * Returns a reference to a group object
+	 * Short description for 'getInstance'
+	 * Long description (if any) ...
 	 *
-	 * @param     mixed $group A string (cn) or integer (ID)
-	 * @return    mixed Object if instance found, false if not
+	 * @param unknown $group Parameter description (if any) ...
+	 * @return mixed Return description (if any) ...
 	 */
 	static public function getInstance($group)
 	{
-		static $instances;
+		$hzg = new Hubzero_Group();
 
-		// Set instances array
-		if (!isset($instances)) 
+		if ($hzg->read($group) === false)
 		{
-			$instances = array();
+			return false;
 		}
 
-		// Do we have a matching instance?
-		if (!isset($instances[$group])) 
-		{
-			// If an ID is passed, check for a match in existing instances
-			if (is_numeric($group))
-			{
-				foreach ($instances as $instance)
-				{
-					if ($instance && $instance->get('gidNumber') == $group)
-					{
-						// Match found
-						return $instance;
-						break;
-					}
-				}
-			}
-
-			// No matches
-			// Create group object
-			$hzg = new Hubzero_Group();
-
-			if ($hzg->read($group) === false)
-			{
-				$instances[$group] = false;
-			}
-			else
-			{
-				$instances[$group] = $hzg;
-			}
-		}
-
-		// Return instance
-		return $instances[$group];
+		return $hzg;
 	}
 
 	/**
@@ -1103,7 +1071,7 @@ class Hubzero_Group
 
 		if ($check_system)
 		{
-			if (is_numeric($group) && posix_getgrgid($group))
+			if (is_numeric($group) && posix_getgrid($group))
 			{
 				return true;
 			}
@@ -1173,14 +1141,16 @@ class Hubzero_Group
 		else
 		{
 			$t = implode(",", $types);
-			
-			//replace group type names with group type id
-			$t = str_replace('hub', 1, $t);
-			$t = str_replace('project', 2, $t);
-			$t = str_replace('partner', 3, $t);
-			$t = str_replace('course', 4, $t);
-			$t = str_replace('system', 0, $t);
-			
+			if ($t == 'hub')
+				$t = 1;
+			if ($t == 'project')
+				$t = 2;
+			if ($t == 'partner')
+				$t = 3;
+			if ($t == 'course')
+				$t = 4;
+			if ($t == 'system')
+				$t = 0;
 			$where_clause = 'WHERE type IN (' . $t . ')';
 		}
 
@@ -1195,7 +1165,7 @@ class Hubzero_Group
 				$where_clause = "WHERE";
 			}
 			
-			$where_clause .= " (LOWER(description) LIKE '%" . $db->getEscaped(strtolower($filters['search'])) . "%' OR LOWER(cn) LIKE '%" . $db->getEscaped(strtolower($filters['search'])) . "%')";
+			$where_clause .= " (LOWER(description) LIKE '%" . $filters['search'] . "%' OR LOWER(cn) LIKE '%" . $filters['search'] . "%')";
 		}
 
 		if (isset($filters['index']) && $filters['index'] != '')
@@ -1209,12 +1179,12 @@ class Hubzero_Group
 				$where_clause = "WHERE";
 			}
 			
-			$where_clause .= " (LOWER(description) LIKE '" . $db->getEscaped(strtolower($filters['index'])) . "%') ";
+			$where_clause .= " (LOWER(description) LIKE '" . $filters['index'] . "%') ";
 		}
 
 		if (isset($filters['authorized']) && $filters['authorized'] === 'admin')
 		{
-			if (isset($filters['discoverability']) && $filters['discoverability'] != '')
+			if (isset($filters['privacy']) && $filters['privacy'])
 			{
 				if ($where_clause != '')
 				{
@@ -1225,13 +1195,16 @@ class Hubzero_Group
 					$where_clause .= "WHERE";
 				}
 
-				switch ($filters['discoverability'])
+				switch ($filters['privacy'])
 				{
-					case 0:
-						$where_clause .= " discoverability=0";
+					case 'private':
+						$where_clause .= " privacy=4";
 						break;
-					case 1:
-						$where_clause .= " discoverability=1";
+					case 'protected':
+						$where_clause .= " privacy=1";
+						break;
+					case 'public':
+						$where_clause .= " privacy=0";
 						break;
 				}
 			}
@@ -1251,7 +1224,7 @@ class Hubzero_Group
 				$where_clause .= "WHERE";
 			}
 
-			$where_clause .= " discoverability=0";
+			$where_clause .= " privacy=0";
 		}
 
 		if (isset($filters['policy']) && $filters['policy'])
@@ -1282,40 +1255,7 @@ class Hubzero_Group
 					break;
 			}
 		}
-		
-		if (isset($filters['approved']) && $filters['approved'] != '')
-		{
-			if ($where_clause != '')
-			{
-				$where_clause .= " AND";
-			}
-			else
-			{
-				$where_clause .= "WHERE";
-			}
-			
-			$where_clause .= " approved=".$filters['approved'];
-		}
-		
-		if (isset($filters['created']) && $filters['created'] != '')
-		{
-			if ($where_clause != '')
-			{
-				$where_clause .= " AND";
-			}
-			else
-			{
-				$where_clause .= "WHERE";
-			}
-			
-			if($filters['created'] == 'pastday')
-			{
-				$pastDay = date("Y-m-d H:i:s", strtotime('-1 DAY'));
-				$where_clause .= " created >= '" . $pastDay . "'";
-			}
-		}
-		
-		
+
 		if (empty($filters['fields']))
 		{
 			$filters['fields'][] = 'cn';
@@ -1491,22 +1431,15 @@ class Hubzero_Group
 		{
 			return false;
 		}
-		
-		if($q == '')
-		{
-			return false;
-		}
 
 		$table = '#__xgroups_' . $tbl;
-		$user_table = '#__users';
 
 		$db = & JFactory::getDBO();
 
-		$query = "SELECT u.id FROM {$table} AS t, {$user_table} AS u 
-					WHERE t.gidNumber={$db->Quote($this->gidNumber)} 
-					AND u.id=t.uidNumber 
-					AND LOWER(u.name) LIKE '%" . strtolower($q) . "%';";
+		$query = 'SELECT u.id FROM #__xgroups_ ' . $tbl . ' AS t,#__users AS u WHERE t.gidNumber=' . $db->Quote($this->gidNumber) . " AND u.id=t.uidNumber AND LOWER(u.name) LIKE '%" . strtolower($q) . "%';";
+
 		$db->setQuery($query);
+
 		return $db->loadResultArray();
 	}
 }
\ No newline at end of file
