@@ -28,78 +28,78 @@
  * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  */
 
-namespace Hubzero\User;
-
-use Hubzero\User\Password\History;
+// Check to ensure this file is included in Joomla!
+defined('_JEXEC') or die('Restricted access');
 
 /**
- * Password handling class for users
+ * Short description for 'Hubzero_User_Password' Long description (if any) . ..
  */
-class Password
+class Hubzero_User_Password
 {
+	
 	/**
 	 * Description for 'user_id'
 	 *
 	 * @var mixed
 	 */
 	private $user_id = null;
-
+	
 	/**
 	 * Description for 'passhash'
 	 *
 	 * @var unknown
 	 */
 	private $passhash = null;
-
+	
 	/**
 	 * Description for 'shadowLastChange'
 	 *
 	 * @var unknown
 	 */
 	private $shadowLastChange = null;
-
+	
 	/**
 	 * Description for 'shadowMin'
 	 *
 	 * @var array
 	 */
 	private $shadowMin = array();
-
+	
 	/**
 	 * Description for 'shadowMax'
 	 *
 	 * @var unknown
 	 */
 	private $shadowMax = null;
-
+	
 	/**
 	 * Description for 'shadowWarning'
 	 *
 	 * @var unknown
 	 */
 	private $shadowWarning = null;
-
+	
 	/**
 	 * Description for 'shadowInactive'
 	 *
 	 * @var unknown
 	 */
 	private $shadowInactive = null;
-
+	
 	/**
 	 * Description for 'shadowExpire'
 	 *
 	 * @var unknown
 	 */
 	private $shadowExpire = null;
-
+	
 	/**
 	 * Description for 'shadowFlag'
 	 *
 	 * @var unknown
 	 */
 	private $shadowFlag = null;
-
+	
 	/**
 	 * Description for '_updatedkeys'
 	 *
@@ -124,19 +124,19 @@ class Password
 	public function clear()
 	{
 		$cvars = get_class_vars(__CLASS__);
-
+		
 		$this->_updatedkeys = array();
-
+		
 		foreach ($cvars as $key=>$value)
 		{
 			if ($key{0} != '_')
 			{
 				unset($this->$key);
-
+				
 				$this->$key = null;
 			}
 		}
-
+		
 		$this->_updatedkeys = array();
 	}
 
@@ -147,15 +147,15 @@ class Password
 	 * @param unknown $storage Parameter description (if any) ...
 	 * @return mixed Return description (if any) ...
 	 */
-	public static function getInstance($instance, $storage = null)
+	public function getInstance($instance, $storage = null)
 	{
-		$hzup = new self();
-
+		$hzup = new Hubzero_User_Password();
+		
 		if ($hzup->read($instance) === false)
 		{
 			return false;
 		}
-
+		
 		return $hzup;
 	}
 
@@ -166,32 +166,32 @@ class Password
 	 */
 	public function create()
 	{
-		$db =  \JFactory::getDBO();
-
+		$db = &JFactory::getDBO();
+		
 		if (empty($db))
 		{
 			return false;
 		}
-
-		// @FIXME: this should fail if id doesn't exist in #__users
-
+		
+		// @FIXME: this should fail if id doesn't exist in jos_users
+		
 
 		if ($this->user_id > 0)
 		{
 			$query = "INSERT INTO #__users_password (user_id) VALUES ( " . $db->Quote($this->user_id) . ");";
-
+			
 			$db->setQuery($query);
-
+			
 			$result = $db->query();
-
+			
 			if ($result !== false || $db->getErrorNum() == 1062)
 			{
 				return true;
 			}
-
+			
 			$this->update();
 		}
-
+		
 		return false;
 	}
 
@@ -208,54 +208,54 @@ class Password
 		{
 			$instance = $this->user_id;
 		}
-
+		
 		if (empty($instance))
 		{
 			return false;
 		}
-
+		
 		$this->clear();
-
-		$db = \JFactory::getDBO();
-
+		
+		$db = JFactory::getDBO();
+		
 		if (empty($db))
 		{
 			return false;
 		}
-
+		
 		$result = true;
-
+		
 		if (is_numeric($instance))
 		{
 			if ($instance <= 0)
 			{
 				return false;
 			}
-
+			
 			$query = "SELECT user_id,passhash,shadowLastChange,shadowMin," . "shadowMax,shadowWarning,shadowInactive,shadowExpire," . "shadowFlag FROM #__users_password WHERE user_id=" . $db->Quote($instance) . ";";
 		}
 		else
 		{
 			$query = "SELECT user_id,passhash,shadowLastChange,shadowMin," . "shadowMax,shadowWarning,shadowInactive,shadowExpire," . "shadowFlag FROM #__users_password,#__users WHERE user_id=id" . " AND username=" . $db->Quote($instance) . ";";
 		}
-
+		
 		$db->setQuery($query);
-
+		
 		$result = $db->loadAssoc();
-
+		
 		if (!empty($result))
 		{
 			foreach ($result as $key=>$value)
 			{
 				$this->__set($key, $value);
 			}
-
+			
 			$this->_updatedkeys = array();
 		}
 		else
 		{
-			$hzp = Profile::getInstance($instance);
-
+			$hzp = Hubzero_User_Profile::getInstance($instance);
+			
 			if (is_object($hzp))
 			{
 				$this->__set('user_id', $hzp->get('uidNumber'));
@@ -267,7 +267,7 @@ class Password
 				return false;
 			}
 		}
-
+		
 		return true;
 	}
 
@@ -277,33 +277,28 @@ class Password
 	 * @param boolean $all Parameter description (if any) ...
 	 * @return boolean Return description (if any) ...
 	 */
-	public function update()
+	function update()
 	{
-		$db = \JFactory::getDBO();
-
-		if (!$this->__get('user_id'))
-		{
-			return false;
-		}
-
+		$db = &JFactory::getDBO();
+		
 		$query = "UPDATE #__users_password SET ";
-
+		
 		$classvars = get_class_vars(__CLASS__);
-
+		
 		$first = true;
-
+		
 		foreach ($classvars as $property=>$value)
 		{
 			if (($property{0} == '_'))
 			{
 				continue;
 			}
-
+			
 			if (!in_array($property, $this->_updatedkeys))
 			{
 				continue;
 			}
-
+			
 			if (!$first)
 			{
 				$query .= ',';
@@ -312,9 +307,9 @@ class Password
 			{
 				$first = false;
 			}
-
+			
 			$value = $this->__get($property);
-
+			
 			if ($value === null)
 			{
 				$query .= "`$property`=NULL";
@@ -324,33 +319,34 @@ class Password
 				$query .= "`$property`=" . $db->Quote($value);
 			}
 		}
-
-		$query .= " WHERE `user_id`=" . $db->Quote($this->__get('user_id'));
-
+		
+		$query .= " WHERE `user_id`=" . $db->Quote($this->__get('user_id')) . " LIMIT 1;";
+		
 		if ($first == true)
 		{
 			$query = '';
 		}
-
+		
 		$affected = 0;
+		
 		if (!empty($query))
 		{
 			$db->setQuery($query);
-
+			
 			$result = $db->query();
-
+			
 			if ($result)
 			{
 				$affected = $db->getAffectedRows();
 			}
 		}
-
+		
 		if ($affected > 0)
 		{
-			\JPluginHelper::importPlugin('user');
-			\JDispatcher::getInstance()->trigger('onAfterStorePassword', array($this));
+			JPluginHelper::importPlugin('user');
+			JDispatcher::getInstance()->trigger('onAfterStorePassword', array($this));
 		}
-
+		
 		return true;
 	}
 
@@ -365,41 +361,41 @@ class Password
 		{
 			return false;
 		}
-
-		$db = \JFactory::getDBO();
-
+		
+		$db = JFactory::getDBO();
+		
 		if (empty($db))
 		{
 			return false;
 		}
-
+		
 		if (!isset($this->user_id))
 		{
 			$db->setQuery("SELECT user_id FROM #__users_password WHERE user_id" . $db->Quote($this->user_id) . ";");
-
+			
 			$this->__set('user_id', $db->loadResult());
 		}
-
+		
 		if (empty($this->user_id))
 		{
 			return false;
 		}
-
+		
 		$db->setQuery("DELETE FROM #__users_password WHERE user_id= " . $db->Quote($this->user_id) . ";");
-
+		
 		$affected = 0;
-
+		
 		if ($db->query())
 		{
 			$affected = $db->getAffectedRows();
 		}
-
+		
 		if ($affected > 0)
 		{
-			\JPluginHelper::importPlugin('user');
-			\JDispatcher::getInstance()->trigger('onAfterDeletePassword', array($this));
+			JPluginHelper::importPlugin('user');
+			JDispatcher::getInstance()->trigger('onAfterDeletePassword', array($this));
 		}
-
+		
 		return true;
 	}
 
@@ -417,23 +413,23 @@ class Password
 			{
 				$property = '(null)';
 			}
-
+			
 			$this->_error("Cannot access property " . __CLASS__ . "::$" . $property, E_USER_ERROR);
 			die();
 		}
-
+		
 		if (isset($this->$property))
 		{
 			return $this->$property;
 		}
-
+		
 		if (array_key_exists($property, get_object_vars($this)))
 		{
 			return null;
 		}
-
+		
 		$this->_error("Undefined property " . __CLASS__ . "::$" . $property, E_USER_NOTICE);
-
+		
 		return null;
 	}
 
@@ -452,13 +448,13 @@ class Password
 			{
 				$property = '(null)';
 			}
-
+			
 			$this->_error("Cannot access property " . __CLASS__ . "::$" . $property, E_USER_ERROR);
 			die();
 		}
-
+		
 		$this->$property = $value;
-
+		
 		if (!in_array($property, $this->_updatedkeys))
 		{
 			$this->_updatedkeys[] = $property;
@@ -479,11 +475,11 @@ class Password
 			{
 				$property = '(null)';
 			}
-
+			
 			$this->_error("Cannot access property " . __CLASS__ . "::$" . $property, E_USER_ERROR);
 			die();
 		}
-
+		
 		return isset($this->$property);
 	}
 
@@ -501,13 +497,13 @@ class Password
 			{
 				$property = '(null)';
 			}
-
+			
 			$this->_error("Cannot access property " . __CLASS__ . "::$" . $property, E_USER_ERROR);
 			die();
 		}
-
+		
 		$this->_updatedkeys = array_diff($this->_updatedkeys, array($property));
-
+		
 		unset($this->$property);
 	}
 
@@ -521,7 +517,7 @@ class Password
 	private function _error($message, $level = E_USER_NOTICE)
 	{
 		$caller = next(debug_backtrace());
-
+		
 		switch ($level)
 		{
 			case E_USER_NOTICE:
@@ -534,7 +530,7 @@ class Password
 				echo "Unknown error: ";
 				break;
 		}
-
+		
 		echo $message . ' in ' . $caller['file'] . ' on line ' . $caller['line'] . "\n";
 	}
 
@@ -561,85 +557,64 @@ class Password
 		return $this->__set($key, $value);
 	}
 
-	public static function isPasswordExpired($user = null)
+	public function isPasswordExpired($user = null)
 	{
 		$hzup = self::getInstance($user);
-
+		
 		if (!is_object($hzup))
 		{
 			return false;
 		}
-
+		
 		if (empty($hzup->shadowLastChange))
 		{
 			return false;
 		}
-
+		
 		if ($hzup->shadowMax === '0')
 		{
 			return true;
 		}
-
+		
 		if (empty($hzup->shadowMax))
 		{
 			return false;
 		}
-
+		
 		$chgtime = time();
 		$chgtime = intval($chgtime / 86400);
-
+		
 		if (($hzup->shadowLastChange + $hzup->shadowMax) >= $chgtime)
 		{
 			return false;
 		}
-
+		
 		return true;
 	}
 
-	public static function getPasshash($password)
+	public function changePassword($user = null, $password)
 	{
-		// Get the password encryption/hashing mechanism
-		$config = \JComponentHelper::getParams('com_members');
-		$type   = $config->get('passhash_mechanism', 'CRYPT_SHA512');
-
-		switch ($type)
-		{
-			case 'MD5':
-				$passhash = "{MD5}" . base64_encode(pack('H*', md5($password)));
-				break;
-
-			case 'CRYPT_SHA512':
-			default:
-				$encrypted = crypt($password, '$6$' . \JUserHelper::genRandomPassword(8) . '$');
-				$passhash = "{CRYPT}" . $encrypted;
-				break;
-		}
-
-		return $passhash;
-	}
-
-	public static function changePassword($user = null, $password)
-	{
-		$passhash = self::getPasshash($password);
-
+		$passhash = "{MD5}" . base64_encode(pack('H*', md5($password)));
+		
 		return self::changePasshash($user, $passhash);
 	}
 
-	public static function changePasshash($user = null, $passhash)
+	public function changePasshash($user = null, $passhash)
 	{
+		ximport('Hubzero_User_Password_History');
+		
 		// Get config values for min, max, and warning
-		$config        = \JComponentHelper::getParams('com_members');
-		$shadowMin     = $config->get('shadowMin', '0');
-		$shadowMax     = $config->get('shadowMax', null);
+		$config = & JComponentHelper::getParams('com_members');
+		$shadowMin = $config->get('shadowMin', '0');
+		$shadowMax = $config->get('shadowMax', null);
 		$shadowWarning = $config->get('shadowWarning', '7');
-
-		// Translate empty shadowMax to mean NULL
+		
 		$shadowMax = ($shadowMax == '') ? null : $shadowMax;
-
+		
 		$hzup = self::getInstance($user);
-
+		
 		$oldhash = $hzup->__get('passhash');
-
+		
 		$hzup->__set('passhash', $passhash);
 		$hzup->__set('shadowFlag', null);
 		$hzup->__set('shadowLastChange', intval(time() / 86400));
@@ -649,73 +624,60 @@ class Password
 		$hzup->__set('shadowInactive', '0');
 		$hzup->__set('shadowExpire', null);
 		$hzup->update();
-
-		$db = \JFactory::getDBO();
-
-		$db->setQuery("UPDATE `#__xprofiles` SET userPassword=" . $db->Quote($passhash) . " WHERE uidNumber=" . $db->Quote($hzup->get('user_id')));
+		
+		$db = JFactory::getDBO();
+		
+		$db->setQuery("UPDATE #__xprofiles SET userPassword=" . $db->Quote($passhash) . ";");
 		$db->query();
-
-		$db->setQuery("UPDATE `#__users` SET password=" . $db->Quote($passhash) . " WHERE id=" . $db->Quote($hzup->get('user_id')));
+		
+		$db->setQuery("UPDATE #__users SET password=" . $db->Quote($passhash) . ";");
 		$db->query();
-
+		
 		if (!empty($oldhash))
 		{
-			History::addPassword($oldhash, $user);
+			Hubzero_User_Password_History::addPassword($oldhash, $user);
 		}
-
+		
 		return true;
 	}
 
-	public static function comparePasswords($passhash, $password)
+	public function comparePasswords($passhash, $password)
 	{
 		if (empty($passhash) || empty($password))
 		{
 			return false;
 		}
-
+		
 		preg_match("/^\s*(\{(.*)\}\s*|)((.*?)\s*:\s*|)(.*?)\s*$/", $passhash, $matches);
-
+		
 		$encryption = strtolower($matches[2]);
-
+		
 		if (empty($encryption))
 		{ // Joomla
 			$encryption = "md5-hex";
-
+			
 			if (!empty($matches[4]))
 			{ // Joomla 1.5
 				$crypt = $matches[4];
-				$salt  = $matches[5];
+				$salt = $matches[5];
 			}
 			else
 			{ // Joomla 1.0
 				$crypt = $matches[5];
-				$salt  = '';
+				$salt = '';
 			}
 		}
 		else
 		{
-			$salt  = $matches[4];
+			$salt = $matches[4];
 			$crypt = $matches[5];
 		}
-
+		
 		if ($encryption == 'md5')
 		{
 			$encryption = "md5-base64";
 		}
-		else if ($encryption == 'crypt')
-		{
-			preg_match('/\$([[:alnum:]]{1,2})\$[[:alnum:]]{8}\$/', $passhash, $parts);
-			$salt = $parts[0];
-
-			switch ($parts[1])
-			{
-				case '6':
-				default:
-					$encryption = 'crypt-sha512';
-					break;
-			}
-		}
-
+		
 		if (empty($salt) && ($encryption == 'ssha'))
 		{
 			$salt = substr(base64_decode(substr($crypt, -32)), -4);
@@ -724,62 +686,51 @@ class Password
 		else
 		{
 			jimport('joomla.user.helper');
-			$hashed = \JUserHelper::getCryptedPassword($password, $salt, $encryption);
+			$hashed = JUserHelper::getCryptedPassword($password, $salt, $encryption);
 		}
-
+		
 		return ($crypt == $hashed);
 	}
 
-	public static function passwordMatches($user = null, $password, $alltables = false)
+	public function passwordMatches($user = null, $password, $alltables = false)
 	{
 		$passhash = null;
-
+		
 		$hzup = self::getInstance($user);
-
+		
 		if (is_object($hzup) && !empty($hzup->passhash))
 		{
 			$passhash = $hzup->passhash;
 		}
 		else if ($alltables)
 		{
-			$profile = Profile::getInstance($user);
-
+			$profile = Hubzero_User_Profile::getInstance($user);
+			
 			if (is_object($profile) && ($profile->get('userPassword') != ''))
 			{
 				$passhash = $profile->get('userPassword');
 			}
 			else
 			{
-				$user = \JUser::getInstance($user);
-
+				$user = JUser::getInstance($user);
+				
 				if (is_object($user) && !empty($user->password))
 				{
 					$passhash = $user->password;
 				}
 			}
 		}
-
+		
 		return self::comparePasswords($passhash, $password);
 	}
 
-	public static function invalidatePassword($user = null)
+	public function invalidatePassword($user = null)
 	{
 		$hzup = self::getInstance($user);
-
+		
 		$hzup->__set('shadowFlag', '-1');
 		$hzup->update();
-
+		
 		return true;
 	}
-
-	public static function expirePassword($user = null)
-	{
-		$hzup = self::getInstance($user);
-
-		$hzup->__set('shadowLastChange', '1');
-		$hzup->__set('shadowMax', '0');
-		$hzup->update();
-
-		return true;
-	}
-}
+}
\ No newline at end of file
