@@ -34,4 +34,5 @@ defined('_JEXEC') or die('Restricted access');
 // Include the syndicate functions only once
 require_once (dirname(__FILE__).DS.'helper.php');
 
-$modlogin = modLoginHelper::display($params, $module);
\ No newline at end of file
+$modlogin = new modLoginHelper($params, $module);
+$modlogin->display();
\ No newline at end of file
