@@ -25,21 +25,32 @@
 // No direct access
 defined('_JEXEC') or die('Restricted access');
 
+jimport('joomla.plugin.plugin');
+
 /**
  * Groups Plugin class for usage
  */
-class plgGroupsUsage extends \Hubzero\Plugin\Plugin
+class plgGroupsUsage extends JPlugin
 {
 	/**
-	 * Affects constructor behavior. If true, language files will be loaded automatically.
-	 *
-	 * @var    boolean
+	 * Short description for 'plgGroupsUsage'
+	 * 
+	 * Long description (if any) ...
+	 * 
+	 * @param      unknown &$subject Parameter description (if any) ...
+	 * @param      unknown $config Parameter description (if any) ...
+	 * @return     void
 	 */
-	protected $_autoloadLanguage = true;
+	public function __construct(&$subject, $config)
+	{
+		parent::__construct($subject, $config);
+
+		$this->loadLanguage();
+	}
 
 	/**
 	 * Return the alias and name for this category of content
-	 *
+	 * 
 	 * @return     array
 	 */
 	public function &onGroupAreas()
@@ -48,15 +59,14 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 			'name' => 'usage',
 			'title' => JText::_('USAGE'),
 			'default_access' => $this->params->get('plugin_access', 'members'),
-			'display_menu_tab' => $this->params->get('display_tab', 1),
-			'icon' => 'f080'
+			'display_menu_tab' => true
 		);
 		return $area;
 	}
 
 	/**
 	 * Return data on a group view (this will be some form of HTML)
-	 *
+	 * 
 	 * @param      object  $group      Current group
 	 * @param      string  $option     Name of the component
 	 * @param      string  $authorized User's authorization level
@@ -81,66 +91,65 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 		$this_area = $this->onGroupAreas();
 
 		// Check if our area is in the array of areas we want to return results for
-		if (is_array($areas) && $limit)
+		if (is_array($areas) && $limit) 
 		{
-			if (!in_array($this_area['name'], $areas))
+			if (!in_array($this_area['name'], $areas)) 
 			{
 				$return = '';
 			}
 		}
 
-		if ($return == 'html')
+		if ($return == 'html') 
 		{
 			//set group members plugin access level
 			$group_plugin_acl = $access[$active];
 
 			//Create user object
-			$juser = JFactory::getUser();
+			$juser =& JFactory::getUser();
 
 			//get the group members
 			$members = $group->get('members');
 
 			//if set to nobody make sure cant access
-			if ($group_plugin_acl == 'nobody')
+			if ($group_plugin_acl == 'nobody') 
 			{
 				$arr['html'] = '<p class="info">' . JText::sprintf('GROUPS_PLUGIN_OFF', ucfirst($active)) . '</p>';
 				return $arr;
 			}
 
 			//check if guest and force login if plugin access is registered or members
-			if ($juser->get('guest')
-			 && ($group_plugin_acl == 'registered' || $group_plugin_acl == 'members'))
+			if ($juser->get('guest') 
+			 && ($group_plugin_acl == 'registered' || $group_plugin_acl == 'members')) 
 			{
-				$url = JRoute::_('index.php?option=com_groups&cn='.$group->get('cn').'&active='.$active, false, true);
-
-				$this->redirect(
-					JRoute::_('index.php?option=com_users&view=login&return=' . base64_encode($url)),
-					JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active)),
-					'warning'
-				);
-				return;
+				ximport('Hubzero_Module_Helper');
+				$arr['html']  = '<p class="info">' . JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active)) . '</p>';
+				$arr['html'] .= Hubzero_Module_Helper::renderModules('force_mod');
+				return $arr;
 			}
 
 			//check to see if user is member and plugin access requires members
-			if (!in_array($juser->get('id'), $members)
-			 && $group_plugin_acl == 'members'
-			 && $authorized != 'admin')
+			if (!in_array($juser->get('id'), $members) 
+			 && $group_plugin_acl == 'members' 
+			 && $authorized != 'admin') 
 			{
 				$arr['html'] = '<p class="info">' . JText::sprintf('GROUPS_PLUGIN_REQUIRES_MEMBER', ucfirst($active)) . '</p>';
 				return $arr;
 			}
 
 			//instantiate the db
-			$database = JFactory::getDBO();
+			$database =& JFactory::getDBO();
 
 			//reference group for other functions
 			$this->group = $group;
 
+			//import the hubzero document library
+			ximport('Hubzero_Document');
+
 			//get the joomla document
-			$doc = JFactory::getDocument();
+			$doc =& JFactory::getDocument();
 
 			//add usage stylesheet to view
-			\Hubzero\Document\Assets::addPluginStylesheet('groups', 'usage');
+			Hubzero_Document::addPluginStylesheet('groups', 'usage');
 
 			//add datepicker stylesheet to view
 			$doc->addStyleSheet('plugins' . DS . 'groups' . DS . 'usage' . DS . 'datepicker.css');
@@ -165,13 +174,13 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 			$end = JRequest::getVar('end', date("Y-m-d 23:59:59"));
 
 			//make sure start date is a full php datetime
-			if (strlen($start) != 19)
+			if (strlen($start) != 19) 
 			{
 				$start .= " 00:00:00";
 			}
 
 			//make sure end date is a full php datetime
-			if (strlen($end) != 19)
+			if (strlen($end) != 19) 
 			{
 				$end .= " 23:59:59";
 			}
@@ -181,7 +190,8 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 			$doc->addScriptDeclaration($script);
 
 			//import and create view
-			$view = new \Hubzero\Plugin\View(
+			ximport('Hubzero_Plugin_View');
+			$view = new Hubzero_Plugin_View(
 				array(
 					'folder'  => 'groups',
 					'element' => 'usage',
@@ -190,7 +200,7 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 			);
 
 			//get the group pages
-			$query = "SELECT id, title FROM `#__xgroups_pages` WHERE state=1 AND gidNumber=" . $database->quote($group->get('gidNumber'));
+			$query = "SELECT id, title FROM #__xgroups_pages WHERE gid=" . $group->get('gidNumber');
 			$database->setQuery($query);
 			$view->pages = $database->loadAssocList();
 
@@ -203,7 +213,7 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 			$view->start = $start;
 			$view->end = $end;
 
-			if ($this->getError())
+			if ($this->getError()) 
 			{
 				foreach ($this->getErrors() as $error)
 				{
@@ -219,63 +229,63 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Get a count of all resources
-	 *
+	 * 
 	 * @param      integer $gid        Group ID
 	 * @param      string  $authorized Authorization level
 	 * @return     integer
 	 */
-	public static function getResourcesCount($gid=NULL, $authorized)
+	public function getResourcesCount($gid=NULL, $authorized)
 	{
-		if (!$gid)
+		if (!$gid) 
 		{
 			return 0;
 		}
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		include_once(JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_resources' . DS . 'tables' . DS . 'resource.php');
 		$rr = new ResourcesResource($database);
 
-		$database->setQuery("SELECT COUNT(*) FROM " . $rr->getTableName() . " AS r WHERE r.group_owner=" . $database->quote($gid));
+		$database->setQuery("SELECT COUNT(*) FROM " . $rr->getTableName() . " AS r WHERE r.group_owner='" . $gid . "'");
 		return $database->loadResult();
 	}
 
 	/**
 	 * Get a count of all wiki pages
-	 *
+	 * 
 	 * @param      integer $gid        Group ID
 	 * @param      string  $authorized Authorization level
 	 * @return     integer
 	 */
-	public static function getWikipageCount($gid=NULL, $authorized)
+	public function getWikipageCount($gid=NULL, $authorized)
 	{
-		if (!$gid)
+		if (!$gid) 
 		{
 			return 0;
 		}
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
-		$database->setQuery("SELECT COUNT(*) FROM `#__wiki_page` AS p WHERE p.scope=" . $database->quote($gid . DS . 'wiki') . " AND p.group_cn=" . $database->quote($gid));
+		$database->setQuery("SELECT COUNT(*) FROM #__wiki_page AS p WHERE p.scope='" . $gid . DS . 'wiki' . "' AND p.group_cn='" . $gid . "'");
 		return $database->loadResult();
 	}
 
 	/**
 	 * Get a count of all wiki attachments
-	 *
+	 * 
 	 * @param      integer $gid        Group ID
 	 * @param      string  $authorized Authorization level
 	 * @return     integer
 	 */
-	public static function getWikifileCount($gid=NULL, $authorized)
+	public function getWikifileCount($gid=NULL, $authorized)
 	{
-		if (!$gid)
+		if (!$gid) 
 		{
 			return 0;
 		}
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
-		$database->setQuery("SELECT id FROM `#__wiki_page` AS p WHERE p.scope=" . $database->quote($gid . DS . 'wiki') . " AND p.group_cn=" . $database->quote($gid));
+		$database->setQuery("SELECT id FROM #__wiki_page AS p WHERE p.scope='" . $gid . DS . 'wiki' . "' AND p.group_cn='" . $gid . "'");
 		$pageids = $database->loadObjectList();
-		if ($pageids)
+		if ($pageids) 
 		{
 			$ids = array();
 			foreach ($pageids as $pageid)
@@ -283,10 +293,10 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 				$ids[] = $pageid->id;
 			}
 
-			$database->setQuery("SELECT COUNT(*) FROM `#__wiki_attachments` WHERE pageid IN (" . implode(',', $ids) . ")");
+			$database->setQuery("SELECT COUNT(*) FROM #__wiki_attachments WHERE pageid IN (" . implode(',', $ids) . ")");
 			return $database->loadResult();
-		}
-		else
+		} 
+		else 
 		{
 			return 0;
 		}
@@ -294,19 +304,19 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Get a count of all forum posts
-	 *
+	 * 
 	 * @param      integer $gid        Group ID
 	 * @param      string  $authorized Authorization level
 	 * @param      string  $state      State of threads
 	 * @return     integer
 	 */
-	public static function getForumCount($gid=NULL, $authorized, $state='')
+	public function getForumCount($gid=NULL, $authorized, $state='')
 	{
-		if (!$gid)
+		if (!$gid) 
 		{
 			return 0;
 		}
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_forum' . DS . 'tables' . DS . 'post.php');
 
@@ -328,36 +338,37 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 		$filters['start'] = 0;
 		$filters['group'] = $gid;
 
-		$forum = new ForumTablePost($database);
+		$forum = new ForumPost($database);
 		return $forum->getCount($filters);
 	}
 
 	/**
 	 * Get a count of all the group pages
-	 *
+	 * 
 	 * @param      string $gid Group alias
 	 * @return     integer
 	 */
-	public static function getGroupPagesCount($gid)
+	public function getGroupPagesCount($gid)
 	{
-		if (!$gid)
+		if (!$gid) 
 		{
 			return 0;
 		}
 
-		// get group pages if any
-		$pageArchive = GroupsModelPageArchive::getInstance();
-		$pages = $pageArchive->pages('list', array(
-			'gidNumber' => $gid,
-			'state'     => array(0,1),
-		));
+		$database =& JFactory::getDBO();
+
+		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_groups' . DS . 'tables' . DS . 'pages.php');
+
+		$gp = new GroupPages($database);
+
+		$pages = $gp->getPages($gid);
 
 		return count($pages);
 	}
 
 	/**
 	 * Get a list of all page views over a time period
-	 *
+	 * 
 	 * @param      string $gid    Group ID
 	 * @param      string $pageid Page ID
 	 * @param      string $start  Start date
@@ -366,22 +377,18 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 	 */
 	public function getGroupPageViews($gid, $pageid = null, $start, $end)
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
-		if ($pageid != '')
+		if ($pageid != '') 
 		{
-			$query = "SELECT * FROM `#__xgroups_pages_hits` WHERE `gidNumber`=" . $database->quote($gid) . " AND `date` > " . $database->quote($start) . " AND `date` < " . $database->quote($end) . " AND `pageid`=" . $database->quote($pageid) . " GROUP BY ip ORDER BY `date` ASC";
-		}
-		else
+			$query = "SELECT * FROM #__xgroups_pages_hits WHERE gid=" . $gid . " AND datetime > '{$start}' AND datetime < '{$end}' AND pid={$pageid} ORDER BY datetime ASC";
+		} 
+		else 
 		{
-			$query = "SELECT * FROM `#__xgroups_pages_hits` WHERE `gidNumber`=" . $database->quote($gid) . " AND `date` > " . $database->quote($start) . " AND `date` < " . $database->quote($end) . " GROUP BY ip ORDER BY `date` ASC";
+			$query = "SELECT * FROM #__xgroups_pages_hits WHERE gid=" . $gid . " AND datetime > '{$start}' AND datetime < '{$end}' ORDER BY datetime ASC";
 		}
 		$database->setQuery($query);
 		$views = $database->loadAssocList();
-		if (!$views)
-		{
-			$views = array();
-		}
 
 		$s = strtotime($start);
 		$e = strtotime($end);
@@ -389,7 +396,7 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 
 		$page_views = array();
 
-		for ($i=0; $i < $diff; $i++)
+		for ($i=0; $i < $diff; $i++) 
 		{
 			$count = 0;
 			$date = date("M d, Y", strtotime("-{$i} DAYS", strtotime($end)));
@@ -397,11 +404,11 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 			$day_s = date("Y-m-d 00:00:00", strtotime("-{$i} DAYS", strtotime($end)));
 			$day_e = date("Y-m-d 23:59:59", strtotime("-{$i} DAYS", strtotime($end)));
 
-			foreach ($views as $view)
+			foreach ($views as $view) 
 			{
-				$t = $view['date'];
+				$t = $view['datetime'];
 
-				if ($t >= $day_s && $t <= $day_e)
+				if ($t >= $day_s && $t <= $day_e) 
 				{
 					$count++;
 				}
@@ -415,15 +422,15 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Draw a chart of page views over time for a specific page
-	 *
+	 * 
 	 * @param      integer $pid   Page ID
 	 * @param      string  $start Start date
 	 * @param      string  $end   End date
-	 * @return     string
+	 * @return     string 
 	 */
 	public function drawChart($pid, $start, $end)
 	{
-		//vars used
+		//vars used 
 		$jsObj = '';
 		$script = '';
 
@@ -431,11 +438,11 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 		$page_views = $this->getGroupPageViews($this->group->get('gidNumber'), $pid, $start, $end);
 		$total = count($page_views);
 		$count = 0;
-		foreach ($page_views as $d => $c)
+		foreach ($page_views as $d => $c) 
 		{
 			$count++;
 			$jsObj .= "[\"{$d}\", {$c}]";
-			if ($count < $total)
+			if ($count < $total) 
 			{
 				$jsObj .= ", \n \t\t\t\t";
 			}
@@ -488,48 +495,48 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Get a count of all blog entries
-	 *
+	 * 
 	 * @param      string $gid Group alias
 	 * @return     integer
 	 */
-	public static function getGroupBlogCount($gid)
+	public function getGroupBlogCount($gid)
 	{
-		if (!$gid)
+		if (!$gid) 
 		{
 			return 0;
 		}
 
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
-		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'tables' . DS . 'entry.php');
+		include_once(JPATH_ROOT . DS . 'components' . DS . 'com_blog' . DS . 'tables' . DS . 'blog.entry.php');
 
 		$filters = array();
 		$filters['scope'] = 'group';
-		$filters['scope_id'] = $gid;
+		$filters['group_id'] = $gid;
 
-		$gb = new BlogTableEntry($database);
+		$gb = new BlogEntry($database);
 
-		$total = $gb->find('count', $filters);
+		$total = $gb->getCount($filters);
 
 		return $total;
 	}
 
 	/**
 	 * Get a count of all blog comments
-	 *
+	 * 
 	 * @param      string $gid Group alias
 	 * @return     integer
 	 */
-	public static function getGroupBlogCommentCount($gid)
+	public function getGroupBlogCommentCount($gid)
 	{
-		if (!$gid)
+		if (!$gid) 
 		{
 			return 0;
 		}
 
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
-		$query = "SELECT count(*) FROM `#__blog_entries` as be, `#__blog_comments` as bc WHERE be.scope='group' AND be.scope_id=" . $database->quote($gid) . " AND be.id=bc.entry_id";
+		$query = "SELECT count(*) FROM jos_blog_entries as be, jos_blog_comments as bc WHERE be.scope='group' AND be.group_id=" . $gid . " AND be.id=bc.entry_id";
 		$database->setQuery($query);
 
 		$count = $database->loadResult();
@@ -538,15 +545,15 @@ class plgGroupsUsage extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Get a count of all the group calendar events
-	 *
+	 * 
 	 * @param      string $gid Group alias
 	 * @return     integer
 	 */
-	public static function getGroupCalendarCount($gid)
+	public function getGroupCalendarCount($gid)
 	{
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
-		$query = "SELECT COUNT(*) FROM `#__events` WHERE scope=".$database->quote('group')." AND scope_id=" . $database->quote($gid) . " AND state=1";
+		$query = "SELECT COUNT(*) FROM jos_xgroups_events WHERE gidNumber=" . $gid;
 		$database->setQuery($query);
 		return $database->loadResult();
 	}
