@@ -111,13 +111,13 @@ class FileMacro extends WikiMacro
 
 		// Get single attributes
 		// EX: [[Image(myimage.png, nolink, right)]]
-		$argues = preg_replace_callback('/[, ](left|right|top|center|bottom|[0-9]+(px|%|em)?)(?:[, ]|$)/i', array(&$this, 'parseSingleAttribute'), $content);
+		$argues = preg_replace_callback('/[, ](left|right|top|bottom)(?:[, ]|$)/i', array(&$this, 'parseSingleAttribute'), $content);
 		// Get quoted attribute/value pairs
 		// EX: [[Image(myimage.png, desc="My description, contains, commas")]]
-		$argues = preg_replace_callback('/[, ](alt|altimage|althref|desc|title|width|height|align|border|longdesc|class|id|usemap|link|rel)=(?:["\'])([^"\']*)(?:["\'])/i', array(&$this, 'parseAttributeValuePair'), $content);
+		$argues = preg_replace_callback('/[, ](alt|altimage|desc|title|width|height|align|border|longdesc|class|id|usemap)=(?:["\'])([^"]*)(?:["\'])/i', array(&$this, 'parseAttributeValuePair'), $content);
 		// Get non-quoted attribute/value pairs
 		// EX: [[Image(myimage.png, width=100)]]
-		$argues = preg_replace_callback('/[, ](alt|altimage|althref|desc|title|width|height|align|border|longdesc|class|id|usemap|link|rel)=([^"\',]*)(?:[, ]|$)/i', array(&$this, 'parseAttributeValuePair'), $content);
+		$argues = preg_replace_callback('/[, ](alt|altimage|desc|title|width|height|align|border|longdesc|class|id|usemap)=([^"\',]*)(?:[, ]|$)/i', array(&$this, 'parseAttributeValuePair'), $content);
 
 		$attr = $this->attr;
 
@@ -128,8 +128,8 @@ class FileMacro extends WikiMacro
 			$this->config->set('filepath', $this->filepath);
 		}
 		$imgs = explode(',', $this->config->get('img_ext', 'jpg, jpeg, jpe, gif, png'));
-		$imgs = array_map('trim', $imgs);
-		$imgs = array_map('strtolower', $imgs);
+		array_map('trim', $imgs);
+		array_map('strtolower', $imgs);
 		$this->imgs = $imgs;
 
 		$ret = false;
@@ -148,7 +148,7 @@ class FileMacro extends WikiMacro
 				$attr['desc'] = (isset($attr['desc'])) ? $attr['desc'] : '';
 				if (!$attr['desc'])
 				{
-					$attr['desc'] = ($attach->description) ? stripslashes($attach->description) : ''; //$attach->filename;
+					$attr['desc'] = ($attach->description) ? stripslashes($attach->description) : $attach->filename;
 				}
 				$attr['created'] = $attach->created;
 				$attr['created_by'] = $attach->created_by;
@@ -203,27 +203,26 @@ class FileMacro extends WikiMacro
 		$key = strtolower(trim($matches[1]));
 		$val = trim($matches[2]);
 
-		$size   = '/^[0-9]+(%|px|em)+$/';
-		$attrs  = '/(alt|altimage|althref|desc|title|width|height|align|border|longdesc|class|id|usemap|rel)=(.+)/';
+		$size   = '/[0-9+](%|px|em)?$/';
+		$attrs  = '/(alt|altimage|desc|title|width|height|align|border|longdesc|class|id|usemap)=(.+)/';
 		$quoted = "/(?:[\"'])(.*)(?:[\"'])$/";
 
 		// Set width if just a pixel size is given 
 		// e.g., [[File(myfile.jpg, width=120px)]]
-		if (preg_match($size, $val, $matches) && $key != 'border') 
+		if (preg_match($size, $val, $matches)) 
 		{
-			if ($matches[0] && in_array($key, array('width', 'height')))
+			if ($matches[0])
 			{
-				$this->attr['style'][$key] = $val;
-				//$this->attr[$key] = $val;
+				$this->attr['style']['width'] = $val;
+				$this->attr['width'] = $val;
 				return;
 			}
 		}
 
-		if (is_numeric($val) && in_array($key, array('width', 'height')))
+		if (is_numeric($val))
 		{
-
-			$this->attr['style'][$key] = $val . 'px';
-			$this->attr[$key] = $val;
+			$this->attr['style']['width'] = $val . 'px';
+			$this->attr['width'] = $val;
 		}
 		// Specific call to NOT link an image
 		// Links images by default
@@ -251,25 +250,16 @@ class FileMacro extends WikiMacro
 		}
 		// Check for alignment, no key given
 		// e.g., [[File(myfile.jpg, left)]]
-		if (in_array($key, array('left', 'right', 'top', 'bottom', 'center'))) 
+		if (in_array($key, array('left', 'right', 'top', 'bottom'))) 
 		{
-			if ($key == 'center')
+			$this->attr['style']['float'] = $key;
+			if ($key == 'left')
 			{
-				$this->attr['style']['display'] = 'block';
-				$this->attr['style']['margin-right'] = 'auto';
-				$this->attr['style']['margin-left'] = 'auto';
+				$this->attr['style']['margin-right'] = '1em';
 			}
-			else 
+			else if ($key == 'right')
 			{
-				$this->attr['style']['float'] = $key;
-				if ($key == 'left')
-				{
-					$this->attr['style']['margin-right'] = '1em';
-				}
-				else if ($key == 'right')
-				{
-					$this->attr['style']['margin-left'] = '1em';
-				}
+				$this->attr['style']['margin-left'] = '1em';
 			}
 			return;
 		}
@@ -286,14 +276,6 @@ class FileMacro extends WikiMacro
 			else 
 			{
 				$this->attr['style']['float'] = $val;
-				if ($val == 'left')
-				{
-					$this->attr['style']['margin-right'] = '1em';
-				}
-				else if ($val == 'right')
-				{
-					$this->attr['style']['margin-left'] = '1em';
-				}
 			}
 		} 
 		else if ($key == 'border') 
@@ -318,29 +300,23 @@ class FileMacro extends WikiMacro
 	{
 		$key = strtolower(trim($matches[1]));
 
-		$ky = 'width';
-		if (isset($this->attr['width']))
-		{
-			$ky = 'height';
-		}
-
 		// Set width if just a pixel size is given 
 		// e.g., [[File(myfile.jpg, 120px)]]
-		$size   = '/[0-9+](%|px|em)+$/';
+		$size   = '/[0-9+](%|px|em)?$/';
 		if (preg_match($size, $key, $matches)) 
 		{
 			if ($matches[0])
 			{
-				$this->attr['style'][$ky] = $key;
-				//$this->attr[$ky] = $key;
+				$this->attr['style']['width'] = $key;
+				$this->attr['width'] = $key;
 				return;
 			}
 		}
 
 		if (is_numeric($key))
 		{
-			$this->attr['style'][$ky] = $key . 'px';
-			$this->attr[$ky] = $key;
+			$this->attr['style']['width'] = $key . 'px';
+			$this->attr['width'] = $key;
 		}
 
 		// Specific call to NOT link an image
@@ -355,24 +331,15 @@ class FileMacro extends WikiMacro
 		// e.g., [[File(myfile.jpg, left)]]
 		if (in_array($key, array('left', 'right', 'top', 'bottom'))) 
 		{
-			if ($key == 'center')
+			$this->attr['style']['display'] = 'block';
+			$this->attr['style']['float'] = $key;
+			if ($key == 'left')
 			{
-				$this->attr['style']['display'] = 'block';
-				$this->attr['style']['margin-right'] = 'auto';
-				$this->attr['style']['margin-left'] = 'auto';
+				$this->attr['style']['margin-right'] = '1em';
 			}
-			else 
+			else if ($key == 'right')
 			{
-				$this->attr['style']['display'] = 'block';
-				$this->attr['style']['float'] = $key;
-				if ($key == 'left')
-				{
-					$this->attr['style']['margin-right'] = '1em';
-				}
-				else if ($key == 'right')
-				{
-					$this->attr['style']['margin-left'] = '1em';
-				}
+				$this->attr['style']['margin-left'] = '1em';
 			}
 			return;
 		}
@@ -449,10 +416,6 @@ class FileMacro extends WikiMacro
 		$type = 'File';
 		if (in_array(strtolower(JFile::getExt($file)), $this->imgs)) 
 		{
-			if (JRequest::getVar('format') == 'pdf')
-			{
-				return $this->_path($file);
-			}
 			$type = 'Image';
 		}
 		$link .= $this->pagename . DS . $type . ':' . $file;
@@ -473,120 +436,45 @@ class FileMacro extends WikiMacro
 
 		switch ($ext)
 		{
-			case 'unity3d':
-				$attr['width']  = (isset($attr['width']) && $attr['width'])  ? $attr['width']  : 400;
-				$attr['height'] = (isset($attr['height']) && $attr['height']) ? $attr['height'] : 400;
-				if (isset($attr['style']['width']))
-				{
-					$attr['width'] = intval($attr['style']['width']);
-				}
-				if (isset($attr['style']['height']))
-				{
-					$attr['height'] = intval($attr['style']['height']);
-				}
-				$attr['href']   = (isset($attr['href']) && $attr['href'] && $attr['href'] != 'none')   ? $attr['href']   : $this->_link($file);
-
-				/*if (!array_key_exists('alt', $attr) 
-				 && array_key_exists('altimage', $attr) 
-				 && $attr['altimage'] != ''
-				 && file_exists($this->_path($attr['altimage']))) 
-				{
-					//$attr['href'] = (array_key_exists('althref', $attr) && $attr['althref'] != '') ? $attr['althref'] : $attr['href'];
-					$althref = (array_key_exists('althref', $attr) && $attr['althref'] != '') ? $attr['althref'] : $attr['href'];
-					$attr['alt']  = '<a class="attachment" rel="internal" href="' . $althref . '" title="' . htmlentities($attr['desc'], ENT_COMPAT, 'UTF-8') . '">';
-					$attr['alt'] .= '<img src="' . $this->_link($attr['altimage']) . '" alt="' . htmlentities($attr['desc'], ENT_COMPAT, 'UTF-8') . '" />';
-					$attr['alt'] .= '</a>';
-				} 
-				else 
-				{
-					$althref = (array_key_exists('althref', $attr) && $attr['althref'] != '') ? $attr['althref'] : $attr['href'];
-					$attr['alt']  = (isset($attr['alt'])) ? $attr['alt'] : '';
-					$attr['alt'] .= '<a class="attachment" rel="internal" href="' . $althref . '" title="' . htmlentities($attr['desc'], ENT_COMPAT, 'UTF-8') . '">' . $attr['desc'] . '</a>';
-				}*/
-
-				$juri = JURI::getInstance();
-				$rand = rand(0, 100000);
-
-				$html  = '<script type="text/javascript" src="' . ($juri->getScheme() == 'https' ? 'https://ssl-' : 'http://') . 'webplayer.unity3d.com/download_webplayer-3.x/3.0/uo/UnityObject.js"></script>' . "\n";
-				$html .= '<script type="text/javascript">' . "\n";
-				$html .= '<!--
-							function GetUnity() {
-								if (typeof unityObject!= "undefined") {
-									return unityObject.getObjectById("unityPlayer' . $rand . '");
-								}
-								return null;
-							}
-							if (typeof unityObject!= "undefined") {
-								unityObject.embedUnity("unityPlayer' . $rand . '", "' . $attr['href'] . '", ' . intval($attr['width']) . ', ' . intval($attr['height']) . ');
-							}
-							-->' . "\n";
-				$html .= '</script>' . "\n";
-				$html .= '<div class="embedded-plugin" style="width: ' . intval($attr['width']) . 'px; height: ' . intval($attr['height']) . 'px;"><div id="unityPlayer' . $rand . '">
-							<div class="missing-plugin">
-								<a href="http://unity3d.com/webplayer/" title="Unity Web Player. Install now!">
-									<img alt="Unity Web Player. Install now!" src="' . ($juri->getScheme() == 'https' ? 'https://ssl-' : 'http://') . 'webplayer.unity3d.com/installation/getunity.png" width="193" height="63" />
-								</a>
-							</div>
-						</div></div>' . "\n";
-			break;
-
 			case 'cdf':
-				$attr['width']  = (isset($attr['width']) && $attr['width'])  ? $attr['width']  : 400;
-				$attr['height'] = (isset($attr['height']) && $attr['height']) ? $attr['height'] : 400;
-				if (isset($attr['style']['width']))
-				{
-					$attr['width'] = intval($attr['style']['width']);
-				}
-				if (isset($attr['style']['height']))
-				{
-					$attr['height'] = intval($attr['style']['height']);
-				}
+				$attr['width']  = (isset($attr['width']) && $attr['width'])  ? $attr['width']  : 500;
+				$attr['height'] = (isset($attr['height']) && $attr['height']) ? $attr['height'] : 700;
 				$attr['href']   = (isset($attr['href']) && $attr['href'] && $attr['href'] != 'none')   ? $attr['href']   : $this->_link($file);
 
-				$juri = JURI::getInstance();
-
-				$rand = rand(0, 100000);
-
 				if (!array_key_exists('alt', $attr) 
 				 && array_key_exists('altimage', $attr) 
 				 && $attr['altimage'] != ''
 				 && file_exists($this->_path($attr['altimage']))) 
 				{
-					//$attr['href'] = (array_key_exists('althref', $attr) && $attr['althref'] != '') ? $attr['althref'] : $attr['href'];
-					$althref = (array_key_exists('althref', $attr) && $attr['althref'] != '') ? $attr['althref'] : $attr['href'];
-					$attr['alt']  = '<a href="http://www.wolfram.com/cdf-player/" title="CDF Web Player. Install now!">';
+					$attr['alt']  = '<a class="attachment" rel="internal" href="' . $attr['href'] . '" title="' . htmlentities($attr['desc'], ENT_COMPAT, 'UTF-8') . '">';
 					$attr['alt'] .= '<img src="' . $this->_link($attr['altimage']) . '" alt="' . htmlentities($attr['desc'], ENT_COMPAT, 'UTF-8') . '" />';
 					$attr['alt'] .= '</a>';
 				} 
 				else 
 				{
-					$attr['alt'] = '<div class="embedded-plugin" style="width: ' . intval($attr['width']) . 'px; height: ' . intval($attr['height']) . 'px;"><a class="missing-plugin" href="http://www.wolfram.com/cdf-player/" title="CDF Web Player. Install now!"><img alt="CDF Web Player. Install now!" src="' . $juri->getScheme() . '://www.wolfram.com/cdf/images/cdf-player-black.png" width="187" height="41" /></a></div>';
+					$attr['alt']  = (isset($attr['alt'])) ? $attr['alt'] : '';
+					$attr['alt'] .= '<a class="attachment" rel="internal" href="' . $attr['href'] . '" title="' . htmlentities($attr['desc'], ENT_COMPAT, 'UTF-8') . '">' . $attr['desc'] . '</a>';
 				}
 
-				$html  = '<script type="text/javascript" src="' . $juri->getScheme() . '://www.wolfram.com/cdf-player/plugin/v2.1/cdfplugin.js"></script>';
-				$html .= '<script type="text/javascript">';
-				//$html .= '<!--';
-				$html .= '	var cdf = new cdfplugin();';
-				$html .= "var defaultContent = '" . $attr['alt'] . "';";
-				$html .= '	if (defaultContent!= "") {';
-				$html .= '		cdf.setDefaultContent(defaultContent);';
-				$html .= '	}';
-				$html .= '	cdf.embed(\'' . $attr['href'] . '\', ' . intval($attr['width']) . ', ' . intval($attr['height']) . ');';
-				//$html .= ' -->';
+				$juri = JURI::getInstance();
+
+				$html  = '<script type="text/javascript" src="' . $juri->getScheme() . '://www.wolfram.com/cdf-player/plugin/v2.1/cdfplugin.js"></script>' . "\n";
+				$html .= '<script type="text/javascript">' . "\n";
+				$html .= "\t" . 'var cdf = new cdfplugin();' . "\n";
+				$html .= "\t" . 'var defaultContent = "' . addslashes($attr['alt']) . '"' . "\n";
+				$html .= "\t" . 'if (defaultContent != "") {' . "\n";
+				$html .= "\t\t" . 'cdf.setDefaultContent(defaultContent);' . "\n";
+				$html .= "\t" . '}' . "\n";
+				$html .= "\t" . 'cdf.embed(\'' . $attr['href'] . '\', ' . intval($attr['width']) . ', ' . intval($attr['height']) . ');' . "\n";
 				$html .= '</script>' . "\n";
-				$html .= '<noscript>';
-				$html .= '<div class="embedded-plugin" style="width: ' . intval($attr['width']) . 'px; height: ' . intval($attr['height']) . ';">';
+				$html .= '<noscript>' . "\n";
+				//$html .= "\t" . '<a class="attachment" href="' . $attr['href'] . '">' . $attr['alt'] . '</a>' . "\n";
 				$html .= $attr['alt'];
-				$html .= '</div>';
 				$html .= '</noscript>' . "\n";
 			break;
 
 			default:
 				$attr['alt'] = (isset($attr['alt'])) ? htmlentities($attr['alt'], ENT_COMPAT, 'UTF-8') : $attr['desc'];
-				if (!$attr['alt'])
-				{
-					$attr['alt'] = $file;
-				}
 
 				if (in_array($ext, $this->imgs)) 
 				{
@@ -600,19 +488,22 @@ class FileMacro extends WikiMacro
 						}
 						$styles = implode('; ', $s);
 					}
-					$attr['style'] = '';
-
+					else 
+					{
+						$attr['style'] = '';
+					}
+					
 					$attribs = array();
 					foreach ($attr as $k => $v)
 					{
 						$k = strtolower($k);
 						if ($k != 'href' && $k != 'rel' && $k != 'desc' && $v)
 						{
-							$attribs[] = $k . '="' . trim($v, '"') . '"';
+							$attribs[] = $k . '="' . $v . '"';
 						}
 					}
 					$html  = '<span class="figure"' . ($styles ? ' style="' . $styles . '"' : '') . '>';
-					$img = '<img src="' . $this->_link($file) . '" ' . implode(' ', $attribs) . ' />';
+					$img = '<img src="' . $this->_link($file) . '" ' . implode(' ', $attribs) . '" />';
 					if ($attr['href'] == 'none') 
 					{
 						$html .= $img;
@@ -657,7 +548,7 @@ class FileMacro extends WikiMacro
 						}
 						if (isset($attr['created']))
 						{
-							$html .= ' ' . Hubzero_View_Helper_Html::timeAgo(Hubzero_View_Helper_Html::mkt(JHTML::_('date', $attr['created'], JFactory::getDBO()->getDateFormat())));
+							$html .= ' ' . Hubzero_View_Helper_Html::timeAgo($attr['created']);
 						}
 						$html .= '</span>)';
 					}
