@@ -163,13 +163,13 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 
 		// Get single attributes
 		// EX: [[Image(myimage.png, nolink, right)]]
-		$argues = preg_replace_callback('/[, ](left|right|top|center|bottom|[0-9]+(px|%|em)?)(?:[, ]|$)/i', array(&$this, 'parseSingleAttribute'), $content);
+		$argues = preg_replace_callback('/[, ](left|right|top|bottom)(?:[, ]|$)/i', array(&$this, 'parseSingleAttribute'), $content);
 		// Get quoted attribute/value pairs
 		// EX: [[Image(myimage.png, desc="My description, contains, commas")]]
-		$argues = preg_replace_callback('/[, ](alt|altimage|desc|title|width|height|align|border|longdesc|class|id|usemap|link)=(?:["\'])([^"]*)(?:["\'])/i', array(&$this, 'parseAttributeValuePair'), $content);
+		$argues = preg_replace_callback('/[, ](alt|altimage|desc|title|width|height|align|border|longdesc|class|id|usemap)=(?:["\'])([^"]*)(?:["\'])/i', array(&$this, 'parseAttributeValuePair'), $content);
 		// Get non-quoted attribute/value pairs
 		// EX: [[Image(myimage.png, width=100)]]
-		$argues = preg_replace_callback('/[, ](alt|altimage|desc|title|width|height|align|border|longdesc|class|id|usemap|link)=([^"\',]*)(?:[, ]|$)/i', array(&$this, 'parseAttributeValuePair'), $content);
+		$argues = preg_replace_callback('/[, ](alt|altimage|desc|title|width|height|align|border|longdesc|class|id|usemap)=([^"\',]*)(?:[, ]|$)/i', array(&$this, 'parseAttributeValuePair'), $content);
 
 		$attr = $this->attr;
 
@@ -180,8 +180,8 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 			$this->config->set('filepath', $this->filepath);
 		}
 		$imgs = explode(',', $this->config->get('img_ext', 'jpg, jpeg, jpe, gif, png'));
-		$imgs = array_map('trim', $imgs);
-		$imgs = array_map('strtolower', $imgs);
+		array_map('trim', $imgs);
+		array_map('strtolower', $imgs);
 		$this->imgs = $imgs;
 
 		$ret = false;
@@ -200,7 +200,7 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 				$attr['desc'] = (isset($attr['desc'])) ? $attr['desc'] : '';
 				if (!$attr['desc'])
 				{
-					$attr['desc'] = ($attach->description) ? stripslashes($attach->description) : ''; //$attach->filename;
+					$attr['desc'] = ($attach->description) ? stripslashes($attach->description) : $attach->filename;
 				}
 
 				$ret = true;
@@ -209,7 +209,7 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 		// Check for file existence
 		else if (file_exists($this->_path($file)) || file_exists($this->_path($file, true))) 
 		{
-			$attr['desc'] = (isset($attr['desc'])) ? $attr['desc'] : ''; //$file;
+			$attr['desc'] = (isset($attr['desc'])) ? $attr['desc'] : $file;
 
 			$ret = true;
 		} 
@@ -230,7 +230,7 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 		else 
 		{
 			// Return error message
-			return '(Image(' . $content . ') failed - File not found)'; // . $this->_path($file);
+			return '(Image(' . $content . ') failed - File not found)' . $this->_path($file);
 		}
 	}
 
@@ -246,13 +246,13 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 		$key = strtolower(trim($matches[1]));
 		$val = trim($matches[2]);
 
-		$size   = '/^[0-9]+(%|px|em)?$/';
+		$size   = '/[0-9+](%|px|em)?$/';
 		$attrs  = '/(alt|altimage|desc|title|width|height|align|border|longdesc|class|id|usemap)=(.+)/';
 		$quoted = "/(?:[\"'])(.*)(?:[\"'])$/";
 
 		// Set width if just a pixel size is given 
 		// e.g., [[File(myfile.jpg, width=120px)]]
-		if (preg_match($size, $val, $matches) && $key != 'border') 
+		if (preg_match($size, $val, $matches)) 
 		{
 			if ($matches[0])
 			{
@@ -293,25 +293,16 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 		}
 		// Check for alignment, no key given
 		// e.g., [[File(myfile.jpg, left)]]
-		if (in_array($key, array('left', 'right', 'top', 'bottom', 'center'))) 
+		if (in_array($key, array('left', 'right', 'top', 'bottom'))) 
 		{
-			if ($key == 'center')
+			$this->attr['style']['float'] = $key;
+			if ($key == 'left')
 			{
-				$this->attr['style']['display'] = 'block';
-				$this->attr['style']['margin-right'] = 'auto';
-				$this->attr['style']['margin-left'] = 'auto';
+				$this->attr['style']['margin-right'] = '1em';
 			}
-			else 
+			else if ($key == 'right')
 			{
-				$this->attr['style']['float'] = $key;
-				if ($key == 'left')
-				{
-					$this->attr['style']['margin-right'] = '1em';
-				}
-				else if ($key == 'right')
-				{
-					$this->attr['style']['margin-left'] = '1em';
-				}
+				$this->attr['style']['margin-left'] = '1em';
 			}
 			return;
 		}
@@ -328,14 +319,6 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 			else 
 			{
 				$this->attr['style']['float'] = $val;
-				if ($val == 'left')
-				{
-					$this->attr['style']['margin-right'] = '1em';
-				}
-				else if ($val == 'right')
-				{
-					$this->attr['style']['margin-left'] = '1em';
-				}
 			}
 		} 
 		else if ($key == 'border') 
@@ -389,26 +372,17 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 
 		// Check for alignment, no key given
 		// e.g., [[File(myfile.jpg, left)]]
-		if (in_array($key, array('left', 'right', 'top', 'bottom', 'center'))) 
+		if (in_array($key, array('left', 'right', 'top', 'bottom'))) 
 		{
-			if ($key == 'center')
+			$this->attr['style']['display'] = 'block';
+			$this->attr['style']['float'] = $key;
+			if ($key == 'left')
 			{
-				$this->attr['style']['display'] = 'block';
-				$this->attr['style']['margin-right'] = 'auto';
-				$this->attr['style']['margin-left'] = 'auto';
+				$this->attr['style']['margin-right'] = '1em';
 			}
-			else 
+			else if ($key == 'right')
 			{
-				$this->attr['style']['display'] = 'block';
-				$this->attr['style']['float'] = $key;
-				if ($key == 'left')
-				{
-					$this->attr['style']['margin-right'] = '1em';
-				}
-				else if ($key == 'right')
-				{
-					$this->attr['style']['margin-left'] = '1em';
-				}
+				$this->attr['style']['margin-left'] = '1em';
 			}
 			return;
 		}
@@ -474,10 +448,6 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 		
 		$file = trim($file, DS);
 		
-		if (JRequest::getVar('format') == 'pdf')
-		{
-			return $this->_path($file);
-		}
 		$link  = DS . substr($this->option, 4, strlen($this->option)) . DS;
 		if ($this->scope) 
 		{
@@ -511,7 +481,10 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 			}
 			$styles = implode('; ', $s);
 		}
-		$attr['style'] = '';
+		else 
+		{
+			$attr['style'] = '';
+		}
 
 		$attribs = array();
 		foreach ($attr as $k => $v)
@@ -519,7 +492,7 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 			$k = strtolower($k);
 			if ($k != 'href' && $k != 'rel' && $k != 'desc' && $v)
 			{
-				$attribs[] = $k . '="' . trim($v, '"') . '"';
+				$attribs[] = $k . '="' . $v . '"';
 			}
 		}
 
