@@ -31,6 +31,8 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+ximport('Hubzero_Plugin');
+
 /**
  * Account Plugin class for members
  *
@@ -38,18 +40,25 @@ defined('_JEXEC') or die('Restricted access');
  * as well as uploading/managing ssh keys, and adding or remove linked accounts
  *
  */
-class plgMembersAccount extends \Hubzero\Plugin\Plugin
+class plgMembersAccount extends Hubzero_Plugin
 {
 	/**
-	 * Affects constructor behavior. If true, language files will be loaded automatically.
-	 *
-	 * @var    boolean
+	 * Constructor
+	 * 
+	 * @param      object &$subject Event observer
+	 * @param      array  $config   Optional config values
+	 * @return     void
 	 */
-	protected $_autoloadLanguage = true;
+	public function __construct(&$subject, $config)
+	{
+		parent::__construct($subject, $config);
+
+		$this->loadLanguage();
+	}
 
 	/**
 	 * Event call to determine if this plugin should return data
-	 *
+	 * 
 	 * @param      object  $user   JUser
 	 * @param      object  $member MembersProfile
 	 * @return     array   Plugin  name
@@ -63,7 +72,6 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		if ($user->get('id') == $member->get('uidNumber'))
 		{
 			$areas['account'] = JText::_('PLG_MEMBERS_ACCOUNT');
-			$areas['icon'] = 'f085';
 		}
 
 		return $areas;
@@ -71,7 +79,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Event call to return data for a specific member
-	 *
+	 * 
 	 * @param      object  $user   JUser
 	 * @param      object  $member MembersProfile
 	 * @param      string  $option Component name
@@ -98,6 +106,9 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 			'metadata'=>''
 		);
 
+		// Imports (needed for view and metadata)
+		ximport('Hubzero_User_Password');
+
 		// Initialize a few things (needed for view and metadata)
 		$this->member = $member;
 
@@ -113,6 +124,20 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 				die('insecure connection and redirection failed');
 			}
 
+			// Import a few things (just needed for views)
+			ximport('Hubzero_Document');
+			ximport('Hubzero_Plugin_View');
+			ximport('Hubzero_Auth_Link');
+			ximport('Hubzero_Auth_Domain');
+
+			// Add stylesheet
+			Hubzero_Document::addPluginStylesheet('members', 'account');
+			Hubzero_Document::addPluginScript('members', 'account');
+
+			// Add providers stylesheet
+			$doc =& JFactory::getDocument();
+			$doc->addStylesheet(DS . 'components' . DS . 'com_user' . DS . 'assets' . DS . 'css' . DS . 'providers.css');
+
 			// Initialize variables (just needed for views)
 			$action       = JRequest::getWord('action', 'view');
 			$this->user   = $user;
@@ -139,26 +164,26 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		}
 
 		// Build the HTML for the account metadat portion
-		if ($returnmeta)
+		if($returnmeta)
 		{
 			// Make sure only I can see this
-			if ($member->get('uidNumber') == $user->get("id"))
+			if($member->get('uidNumber') == $user->get("id"))
 			{
 				// Make sure a password is set and information has been found about it
-				if ($passinfo = $this->getPassInfo())
+				if($passinfo = $this->getPassInfo())
 				{
 					// If that password is within the warning or expiration period...
-					if ($passinfo['diff'] <= $passinfo['warning'] && $passinfo['diff'] > 0)
+					if($passinfo['diff'] <= $passinfo['warning'] && $passinfo['diff'] > 0)
 					{
 						$title = 'Your password expires in ' . $passinfo['diff'] . ' days!';
-						$link  = JRoute::_($member->getLink() . '&active=account#password');
+						$link  = JRoute::_('index.php?option=com_members&id=' . $member->get('uidNumber') . '&active=account#password');
 
 						$arr['metadata']['alert'] = '<a class="alrt" href="' . $link . '"><span><h5>Password Expiration</h5>' . $title . '</span></a>';
 					}
-					else if ($passinfo['diff'] < 0)
+					else if($passinfo['diff'] < 0)
 					{
 						$title = 'Your password has expired!';
-						$link  = JRoute::_($member->getLink() . '&active=account#password');
+						$link  = JRoute::_('index.php?option=com_members&id=' . $member->get('uidNumber') . '&active=account#password');
 
 						$arr['metadata']['alert'] = '<a class="alrt" href="' . $link . '"><span><h5>Password Expiration</h5>' . $title . '</span></a>';
 					}
@@ -175,13 +200,13 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Primary/default view function
-	 *
+	 * 
 	 * @return object Return
 	 */
 	private function _view()
 	{
 		// Setup our view
-		$view = new \Hubzero\Plugin\View(
+		$view = new Hubzero_Plugin_View(
 			array(
 				'folder'  => 'members',
 				'element' => 'account',
@@ -191,27 +216,19 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 		// Get linked accounts, if any
 		$view->domains_avail = JPluginHelper::getPlugin('authentication');
-		$view->hzalaccounts  = \Hubzero\Auth\Link::find_by_user_id($this->user->get("id"));
+		$view->hzalaccounts  = Hubzero_Auth_Link::find_by_user_id($this->user->get("id"));
 
 		// Put the used domains into an array with details available from the providers (if applicable)
 		$view->domains_used = array();
 		$view->domain_names = array();
-		if ($view->hzalaccounts)
+		if($view->hzalaccounts)
 		{
-			$i = 0;
-			foreach ($view->hzalaccounts as $authenticators)
+			foreach($view->hzalaccounts as $authenticators)
 			{
 				JPluginHelper::importPlugin('authentication');
 
 				$plugin = JPluginHelper::getPlugin('authentication', $authenticators['auth_domain_name']);
 
-				// Make sure we got the plugin
-				if (!is_object($plugin))
-				{
-					unset($view->hzalaccounts[$i]);
-					continue;
-				}
-
 				$className = 'plg'.$plugin->type.$plugin->name;
 
 				$details = array();
@@ -226,28 +243,25 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 				$view->domains_used[] = array('name' => $authenticators['auth_domain_name'], 'details' => $details);
 				$view->domain_names[] = $authenticators['auth_domain_name'];
-
-				// Increment index
-				$i++;
 			}
 		}
 
 		// Get unused domains
 		$view->domains_unused = array();
-		foreach ($view->domains_avail as $domain)
+		foreach($view->domains_avail as $domain)
 		{
-			if ($domain->name != 'hubzero' && !in_array($domain->name, $view->domain_names))
+			if($domain->name != 'hubzero' && !in_array($domain->name, $view->domain_names))
 			{
 				$view->domains_unused[] = $domain;
 			}
 		}
 
 		// Determine what type of password change the user needs
-		$hzup = \Hubzero\User\Password::getInstance($this->member->get('uidNumber'));
-		if (!empty($hzup->passhash))
+		$hzup = Hubzero_User_Password::getInstance($this->member->get('uidNumber'));
+		if(!empty($hzup->passhash))
 		{
 			// A password has already been set, now check if they're logged in with a linked account
-			if (array_key_exists('auth_link_id', $this->user))
+			if(array_key_exists('auth_link_id', $this->user))
 			{
 				// Logged in with linked account
 				$view->passtype = 'changelocal';
@@ -271,11 +285,12 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$view->key = $this->readKey();
 
 		// Get the password rules
-		$password_rules = \Hubzero\Password\Rule::getRules();
+		ximport('Hubzero_Password_Rule');
+		$password_rules = Hubzero_Password_Rule::getRules();
 
 		// Get the password rule descriptions
 		$view->password_rules = array();
-		foreach ($password_rules as $rule)
+		foreach($password_rules as $rule)
 		{
 			if (!empty($rule['description']))
 			{
@@ -286,7 +301,6 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		// A few more things...
 		$view->option        = $this->option;
 		$view->member        = $this->member;
-		$view->params        = $this->params;
 		$view->notifications = ($this->getPluginMessage()) ? $this->getPluginMessage() : array();
 
 		// Set any errors
@@ -307,7 +321,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Send out local password set confirmation token
-	 *
+	 * 
 	 * @return void - redirect to confirm token view
 	 */
 	private function sendtoken()
@@ -315,12 +329,14 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		// Import helpers/classes
 		jimport('joomla.mail.helper');
 		jimport('joomla.user.helper');
+		ximport('Hubzero_Auth_Link');
+		ximport('Hubzero_User_Password');
 
 		// Make sure they're logged in
 		if ($this->user->get('guest'))
 		{
 			$this->setRedirect(
-				JRoute::_('index.php?option=com_users&view=login&return=' .
+				JRoute::_('index.php?option=com_login&return=' .
 					base64_encode(JRoute::_('index.php?option=' . $this->option . '&task=myaccount&active=account&action=sendtoken'))),
 				JText::_('You must be a logged in to access this area.'),
 				'warning'
@@ -329,8 +345,8 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		}
 
 		// Make sure this is an auth link account (i.e. no password set)
-		$hzup = \Hubzero\User\Password::getInstance($this->member->get('uidNumber'));
-		if (!empty($hzup->passhash))
+		$hzup = Hubzero_User_Password::getInstance($this->member->get('uidNumber'));
+		if(!empty($hzup->passhash))
 		{
 			JError::raiseError(404, JText::_('PLG_MEMBERS_ACCOUNT_NOT_LINKED_ACCOUNT'));
 			return;
@@ -349,7 +365,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 		// Redirect user to confirm token view page
 		$this->setRedirect(
-			JRoute::_($this->member->getLink() . '&active=account&task=confirmtoken'),
+			JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=account&task=confirmtoken'),
 			JText::_('Please check the email associated with this account (' . $this->member->get('email') . ') for your confirmation token!'),
 			'warning'
 		);
@@ -359,19 +375,20 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Confirm the password set token
-	 *
+	 * 
 	 * @return void - redirect to set local password view
 	 */
 	private function confirmtoken()
 	{
-		$app = JFactory::getApplication();
+		// Get global mainframe (for user state) and import needed classes
+		global $mainframe;
 		jimport('joomla.user.helper');
 
 		// Check if they're logged in
 		if ($this->user->get('guest'))
 		{
 			$this->setRedirect(
-				JRoute::_('index.php?option=com_users&view=login&return=' .
+				JRoute::_('index.php?option=com_login&return=' .
 					base64_encode(JRoute::_('index.php?option=' . $this->option . '&task=myaccount&active=account&action=confirmtoken'))),
 				JText::_('You must be a logged in to access this area.'),
 				'warning'
@@ -384,7 +401,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$change = JRequest::getVar('change', '', 'post');
 
 		// Create the view
-		$view = new \Hubzero\Plugin\View(
+		$view = new Hubzero_Plugin_View(
 			array(
 				'folder'  => 'members',
 				'element' => 'account',
@@ -396,7 +413,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$view->id     = $this->user->get('id');
 
 		// Blank form request (no data submitted)
-		if (empty($change))
+		if(empty($change))
 		{
 			$view->notifications = ($this->getPluginMessage()) ? $this->getPluginMessage() : array();
 			return $view->loadTemplate();
@@ -406,7 +423,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		JRequest::checkToken() or jexit('Invalid Token');
 
 		// Make sure the token is the proper length
-		if (strlen($token) != 32)
+		if(strlen($token) != 32)
 		{
 			// Oops, token wasn't the correct length (probably a copy/paste error)
 			$this->addPluginMessage(JText::_('Invalid token length, please re-input token'), 'error');
@@ -448,11 +465,11 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 		// All checks pass...
 		// Push the token into the session
-		$app->setUserState($this->option . 'token', $crypt . ':' . $salt);
+		$mainframe->setUserState($this->option . 'token', $crypt . ':' . $salt);
 
 		// Redirect user to set local password view
 		$this->setRedirect(
-			JRoute::_($this->member->getLink() . '&active=account&task=setlocalpass'),
+			JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=account&task=setlocalpass'),
 			JText::_('Please provide a new password'),
 			'warning'
 		);
@@ -462,18 +479,19 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Set local password
-	 *
+	 * 
 	 * @return void - redirect to members account page
 	 */
 	private function setlocalpass()
 	{
-		$app = JFactory::getApplication();
+		// Get global mainframe (for user state)
+		global $mainframe;
 
 		// Logged in?
 		if ($this->user->get('guest'))
 		{
 			$this->setRedirect(
-				JRoute::_('index.php?option=com_users&view=login&return=' .
+				JRoute::_('index.php?option=com_login&return=' .
 					base64_encode(JRoute::_('index.php?option=' . $this->option . '&task=myaccount&active=account&action=setlocalpass'))),
 				JText::_('You must be a logged in to access this area.'),
 				'warning'
@@ -482,7 +500,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		}
 
 		// Get the token from the user state variable
-		$token = $app->getUserState($this->option . 'token');
+		$token = $mainframe->getUserState($this->option . 'token');
 
 		// First check to make sure they're not trying to jump to this page without first verifying their token
 		if (is_null($token))
@@ -502,7 +520,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$change    = JRequest::getVar('change', '', 'post');
 
 		// Create the view
-		$view = new \Hubzero\Plugin\View(
+		$view = new Hubzero_Plugin_View(
 			array(
 				'folder'  => 'members',
 				'element' => 'account',
@@ -516,11 +534,12 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$view->id     = $this->user->get('id');
 
 		// Get the password rules
-		$password_rules = \Hubzero\Password\Rule::getRules();
+		ximport('Hubzero_Password_Rule');
+		$password_rules = Hubzero_Password_Rule::getRules();
 
 		// Get the password rule descriptions
 		$view->password_rules = array();
-		foreach ($password_rules as $rule)
+		foreach($password_rules as $rule)
 		{
 			if (!empty($rule['description']))
 			{
@@ -539,21 +558,24 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		JRequest::checkToken() or jexit('Invalid Token');
 
 		// Load some needed libraries
+		ximport('Hubzero_Registration_Helper');
+		ximport('Hubzero_User_Helper');
+		ximport('Hubzero_User_Profile');
 		jimport('joomla.user.helper');
 
 		// Initiate profile classs
-		$profile = new \Hubzero\User\Profile();
+		$profile = new Hubzero_User_Profile();
 		$profile->load($this->user->get('id'));
 
 		// Fire the onBeforeStoreUser trigger
 		JPluginHelper::importPlugin('user');
-		$dispatcher = JDispatcher::getInstance();
+		$dispatcher =& JDispatcher::getInstance();
 		$dispatcher->trigger('onBeforeStoreUser', array($this->user->getProperties(), false));
 
 		// Validate the password against password rules
 		if (!empty($password1))
 		{
-			$msg = \Hubzero\Password\Rule::validate($password1, $password_rules, $profile->get('username'));
+			$msg = Hubzero_Password_Rule::validate($password1, $password_rules, $profile->get('username'));
 		}
 		else
 		{
@@ -564,15 +586,15 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$passrules = false;
 		if (!$password1 || !$password2) // must enter password twice
 		{
-			$this->setError(JText::_('MEMBERS_PASS_MUST_BE_ENTERED_TWICE'));
-		}
+			$this->setError( JText::_('MEMBERS_PASS_MUST_BE_ENTERED_TWICE') );
+		} 
 		elseif ($password1 != $password2) // passwords don't match
 		{
-			$this->setError(JText::_('MEMBERS_PASS_NEW_CONFIRMATION_MISMATCH'));
-		}
+			$this->setError( JText::_('MEMBERS_PASS_NEW_CONFIRMATION_MISMATCH') );
+		} 
 		elseif (!empty($msg)) // password doesn't meet site requirements
 		{
-			$this->setError(JText::_('Password does not meet site password requirements. Please choose a password meeting all the requirements listed.'));
+			$this->setError( JText::_('Password does not meet site password requirements. Please choose a password meeting all the requirements listed.') );
 			$passrules = true;
 		}
 
@@ -582,12 +604,12 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 			$change = array();
 			$change['_missing']['password'] = $this->getError();
 
-			if (!empty($msg) && $passrules)
+			if(!empty($msg) && $passrules)
 			{
 				//$change = $msg;
 			}
 
-			if (JRequest::getInt('no_html', 0))
+			if(JRequest::getInt("no_html", 0))
 			{
 				echo json_encode($change);
 				exit();
@@ -600,7 +622,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		}
 
 		// No errors, so let's move on - encrypt the password and update the profile
-		$result = \Hubzero\User\Password::changePassword($profile->get('uidNumber'), $password1);
+		$result = Hubzero_User_Password::changePassword($profile->get('uidNumber'), $password1, true);
 
 		// Save the changes
 		if (!$result)
@@ -613,7 +635,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$dispatcher->trigger('onAfterStoreUser', array($this->user->getProperties(), false, null, $this->getError()));
 
 		// Flush the variables from the session
-		$app->setUserState($this->option . 'token', null);
+		$mainframe->setUserState($this->option . 'token', null);
 
 		// Redirect
 		if (JRequest::getInt('no_html', 0))
@@ -621,7 +643,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 			echo json_encode(
 				array(
 					"success" => true,
-					"redirect" => JRoute::_($this->member->getLink() . '&active=account'))
+					"redirect" => JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=account'))
 				);
 			exit();
 		}
@@ -629,7 +651,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		{
 			// Redirect user to confirm view page
 			$this->setRedirect(
-				JRoute::_($this->member->getLink() . '&active=account'),
+				JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=account'),
 				JText::_('Password reset successful'),
 				'passed'
 			);
@@ -644,30 +666,33 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Remove linked account
-	 *
+	 * 
 	 * @return void
 	 */
 	private function _unlink()
 	{
+		// Import a few things
+		ximport('Hubzero_User_Password');
+		
 		// Get the id of the account to be unlinked
 		$hzal_id = JRequest::getInt('hzal_id', null);
 
 		// Get instance
-		$hzal = \Hubzero\Auth\Link::find_by_id($hzal_id);
+		$hzal = Hubzero_Auth_Link::find_by_id($hzal_id);
 
 		// Determine what type of password change the user needs
-		$hzup = \Hubzero\User\Password::getInstance($this->member->get('uidNumber'));
-		if (empty($hzup->passhash) && count(\Hubzero\Auth\Link::find_by_user_id($this->member->get('uidNumber'))) <= 1)
+		$hzup = Hubzero_User_Password::getInstance($this->member->get('uidNumber'));
+		if(empty($hzup->passhash) && count(Hubzero_Auth_Link::find_by_user_id($this->member->get('uidNumber'))) <= 1)
 		{
 			$this->setRedirect(
-				JRoute::_($this->member->getLink() . '&active=account'),
+				JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=account'),
 				JText::_('PLG_MEMBERS_ACCOUNT_CANT_REMOVE_ONLY_ACCESS'),
 				'warning'
 			);
 		}
 
 		// Delete the auth_link
-		if (!$hzal->delete())
+		if(!$hzal->delete())
 		{
 			JError::raiseError(500, JText::_('PLG_MEMBERS_UNLINK_FAILED'));
 			return;
@@ -675,7 +700,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 		// Set the redirect
 		$this->setRedirect(
-			JRoute::_($this->member->getLink() . '&active=account'),
+			JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=account'),
 			JText::_('PLG_MEMBERS_ACCOUNT_UNLINKED'),
 			'passed'
 		);
@@ -683,15 +708,15 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Get information about the password expiration
-	 *
+	 * 
 	 * @return array - password expiration information
 	 */
 	private function getPassInfo()
 	{
-		$hzup = \Hubzero\User\Password::getInstance($this->member->get('uidNumber'));
+		$hzup = Hubzero_User_Password::getInstance($this->member->get('uidNumber'));
 
 		// Check to see if password expiration is even enforced
-		if (empty($hzup->passhash) || $hzup->shadowMax === NULL)
+		if(empty($hzup->passhash) || $hzup->shadowMax === NULL)
 		{
 			return false;
 		}
@@ -700,11 +725,11 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$chgtime = intval($chgtime / 86400);
 		$diff    = ($hzup->shadowLastChange + $hzup->shadowMax) - $chgtime;
 
-		if ($diff > $hzup->shadowWarning)
+		if($diff > $hzup->shadowWarning)
 		{
 			$message_style = 'info';
 		}
-		else if ($diff <= $hzup->shadowWarning && $diff > 0)
+		else if($diff <= $hzup->shadowWarning && $diff > 0)
 		{
 			$message_style = 'warning';
 		}
@@ -713,17 +738,12 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 			$message_style = 'error';
 		}
 
-		return array(
-			'diff'          => $diff,
-			'warning'       => $hzup->shadowWarning,
-			'max'           => $hzup->shadowMax,
-			'message_style' => $message_style
-		);
+		return array("diff" => $diff, "warning" => $hzup->shadowWarning, "max" => $hzup->shadowMax, "message_style" => $message_style);
 	}
 
 	/**
 	 * Upload SSH key
-	 *
+	 * 
 	 * @return void
 	 */
 	private function _uploadKey()
@@ -738,30 +758,21 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$ssh  = DS . '.ssh';
 		$auth = DS . 'authorized_keys';
 
-		// Real home directory
-		$homeDir = $this->member->get('homeDirectory');
-
 		// First, make sure webdav is there and that the necessary folders are there
-		if (!JFolder::exists($base))
+		if(!JFolder::exists($base))
 		{
 			JError::raiseError(500, JText::_('PLG_MEMBERS_ACCOUNT_KEY_UPLOAD_NOT_AVAILABLE'));
 			return;
 		}
-		if (!JFolder::exists($homeDir))
+		if(!JFolder::exists($base.$user))
 		{
-			// Try to create their home directory
-			require_once(JPATH_ROOT . DS .'components' . DS . 'com_tools' . DS . 'helpers' . DS . 'utils.php');
-
-			if (!ToolsHelperUtils::createHomeDirectory($this->member->get('username')))
-			{
-				JError::raiseError(500, JText::_('PLG_MEMBERS_ACCOUNT_KEY_UPLOAD_NO_HOME_DIRECTORY'));
-				return;
-			}
+			JError::raiseError(500, JText::_('PLG_MEMBERS_ACCOUNT_KEY_UPLOAD_NO_HOME_DIRECTORY'));
+			return;
 		}
-		if (!JFolder::exists($base . $user . $ssh))
+		if(!JFolder::exists($base.$user.$ssh))
 		{
 			// User doesn't have an ssh directory, so try to create one (with appropriate permissions)
-			if (!JFolder::create($base . $user . $ssh, 0700))
+			if(!JFolder::create($base.$user.$ssh, 0700))
 			{
 				JError::raiseError(500, JText::_('PLG_MEMBERS_ACCOUNT_KEY_UPLOAD_CREATE_FOLDER_FAILED'));
 				return;
@@ -772,18 +783,18 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$content = JRequest::getVar('keytext', '');
 
 		// Write to the file
-		if (!JFile::write($base . $user . $ssh . $auth, $content) && $content != '')
+		if(!JFile::write($base.$user.$ssh.$auth, $content) && $content != '')
 		{
 			JError::raiseError(500, JText::_('PLG_MEMBERS_ACCOUNT_KEY_UPLOAD_WRITE_FAILED'));
 			return;
 		}
 
 		// Set correct permissions on authorized_keys file
-		JPath::setPermissions($base . $user . $ssh . $auth, '0600');
+		JPath::setPermissions($base.$user.$ssh.$auth, '0600');
 
 		// Set the redirect
 		$this->setRedirect(
-			JRoute::_($this->member->getLink() . '&active=account'),
+			JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&active=account'),
 			JText::_('PLG_MEMBERS_ACCOUNT_KEY_UPLOAD_SUCCESSFUL'),
 			'passed'
 		);
@@ -791,7 +802,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Read SSH key
-	 *
+	 * 
 	 * @return string - .ssh/authorized_keys file content
 	 */
 	private function readKey()
@@ -806,62 +817,35 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		$ssh  = DS . '.ssh';
 		$auth = DS . 'authorized_keys';
 
-		// Real home directory
-		$homeDir = $this->member->get('homeDirectory');
-
 		$key = '';
 
 		// First, make sure webdav is there and that the necessary folders are there
-		if (!JFolder::exists($base))
+		if(!JFolder::exists($base))
 		{
-			// Not sure what to do here
-			return $key = false;
+			return $key;
 		}
-		if (!JFolder::exists($homeDir))
+		if(!JFolder::exists($base.$user))
 		{
-			// Try to create their home directory
-			require_once(JPATH_ROOT . DS .'components' . DS . 'com_tools' . DS . 'helpers' . DS . 'utils.php');
-
-			if (!ToolsHelperUtils::createHomeDirectory($this->member->get('username')))
-			{
-				return $key = false;
-			}
+			return $key;
 		}
-		if (!JFolder::exists($base . $user . $ssh))
+		if(!JFolder::exists($base.$user.$ssh))
 		{
-			// User doesn't have an ssh directory, so try to create one (with appropriate permissions)
-			if (!JFolder::create($base . $user . $ssh, 0700))
-			{
-				return $key = false;
-			}
+			return $key;
 		}
-		if (!JFile::exists($base . $user . $ssh . $auth))
+		if(!JFile::exists($base.$user.$ssh.$auth))
 		{
-			// Try to create their authorized keys file
-			$content = ''; // J25 passes param by reference so couldn't use constant below
-			JFile::write($base . $user . $ssh . $auth, $content);
-			if (!JFile::exists($base . $user . $ssh . $auth))
-			{
-				return $key = false;
-			}
-			else
-			{
-				// Set correct permissions on authorized_keys file
-				JPath::setPermissions($base . $user . $ssh . $auth, '0600');
-
-				return $key;
-			}
+			return $key;
 		}
 
 		// Read the file contents
-		$key = JFile::read($base . $user . $ssh . $auth);
+		$key = JFile::read($base.$user.$ssh.$auth);
 
 		return $key;
 	}
 
 	/**
 	 * Set redirect
-	 *
+	 * 
 	 * @return void
 	 */
 	private function setRedirect($url, $msg=null, $type='message')
@@ -875,13 +859,13 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Save password change token to the database
-	 *
+	 * 
 	 * @return bool - true if token save successful
 	 */
 	private function setToken($hashedToken)
 	{
 		// Create the database object and set the token
-		$db     = JFactory::getDBO();
+		$db     =& JFactory::getDBO();
 		$query	= 'UPDATE #__users'
 				. ' SET activation = ' . $db->Quote($hashedToken)
 				. ' WHERE id = ' . (int) $this->user->get('id')
@@ -902,42 +886,36 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Retrieve activation token from the database
-	 *
+	 * 
 	 * @return object - id and activation token for user
 	 */
 	private function getToken()
 	{
 		// Create database object and check that token matches that of the user stored in the db
-		$db = JFactory::getDBO();
-		$db->setQuery('SELECT id, activation FROM `#__users` WHERE block = 0 AND username = ' . $db->Quote($this->user->get('username')));
+		$db =& JFactory::getDBO();
+		$db->setQuery('SELECT id, activation FROM #__users WHERE block = 0 AND username = '.$db->Quote($this->user->get('username')));
 
 		return $db->loadObject();
 	}
 
 	/**
 	 * Send token email
-	 *
+	 * 
 	 * @return bool - true if email send successfully
 	 */
 	private function sendEmail($token)
 	{
-		$jconfig = JFactory::getConfig();
+		ximport('Hubzero_Toolbox');
 
 		// Create the email with the new token
 		$url      = rtrim(JURI::base(),'/');
-		$return   = $url . JRoute::_($this->member->getLink() . '&acitve=account&task=confirmtoken');
+		$return   = $url . JRoute::_('index.php?option=' . $this->option . '&id=' . $this->member->get('uidNumber') . '&acitve=account&task=confirmtoken');
 		$subject  = 'Set local password, confirmation token for ' . $url;
 		$message  = 'You have requested to set your local password at ' . $url . "\n\n";
 		$message .= 'Your reset token is: ' . $token;
 
-		$msg = new \Hubzero\Mail\Message();
-		$msg->setSubject($subject)
-		    ->addTo($this->user->get('email'))
-		    ->addFrom($jconfig->getValue('config.mailfrom'), $jconfig->getValue('config.sitename') . ' Administrator')
-		    ->setBody($message);
-
 		// Send the email
-		if (!$msg->send())
+		if (!Hubzero_Toolbox::send_email($this->user->get('email'), $subject, $message))
 		{
 			JError::raiseError(500, JText::_('PLG_MEMBERS_ACCOUNT_CONFIRMATION_EMAIL_NOT_SENT'));
 			return;
@@ -948,18 +926,19 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Check password fuction for ajax password rules validation
-	 *
+	 * 
 	 * @return string - html rules section with classes for passed/error on each rule
 	 */
 	public function checkPass()
 	{
 		// Get the password rules
-		$password_rules = \Hubzero\Password\Rule::getRules();
+		ximport('Hubzero_Password_Rule');
+		$password_rules = Hubzero_Password_Rule::getRules();
 
 		$pw_rules = array();
 
 		// Get the password rule descriptions
-		foreach ($password_rules as $rule)
+		foreach($password_rules as $rule)
 		{
 			if (!empty($rule['description']))
 			{
@@ -973,7 +952,7 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		// Validate the password
 		if (!empty($pw))
 		{
-			$msg = \Hubzero\Password\Rule::validate($pw, $password_rules, $this->member->get('username'));
+			$msg = Hubzero_Password_Rule::validate($pw, $password_rules, $this->member->get('username'));
 		}
 		else
 		{
@@ -981,30 +960,24 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		}
 
 		// Iterate through the rules and add the appropriate classes (passed/error)
-		if (count($pw_rules) > 0)
-		{
+		if (count($pw_rules) > 0) {
 			foreach ($pw_rules as $rule)
 			{
 				if (!empty($rule))
 				{
-					if (!empty($msg) && is_array($msg))
-					{
+					if (!empty($msg) && is_array($msg)) {
 						$err = in_array($rule, $msg);
-					}
-					else
-					{
+					} else {
 						$err = '';
 					}
 					$mclass = ($err)  ? ' class="error"' : 'class="passed"';
 					echo "<li $mclass>".$rule."</li>";
 				}
 			}
-			if (!empty($msg) && is_array($msg))
-			{
+			if (!empty($msg) && is_array($msg)) {
 				foreach ($msg as $message)
 				{
-					if (!in_array($message, $pw_rules))
-					{
+					if (!in_array($message, $pw_rules)) {
 						echo '<li class="error">'.$message."</li>";
 					}
 				}
@@ -1014,4 +987,4 @@ class plgMembersAccount extends \Hubzero\Plugin\Plugin
 		// Exit - don't go any further (i.e. no joomla template stuff)
 		exit;
 	}
-}
+}
\ No newline at end of file
