@@ -58,7 +58,7 @@ class plgYSearchContent extends YSearchPlugin
 			$addtl_where[] = "(c.title NOT LIKE '%$forb%' AND c.introtext NOT LIKE '%$forb%' AND c.`fulltext` NOT LIKE '%$forb%')";
 		}
 
-		$user = JFactory::getUser();
+		$user =& JFactory::getUser();
 		if (version_compare(JVERSION, '1.6', 'ge'))
 		{
 			$addtl_where[] = '(c.access IN (' . implode(',', $user->getAuthorisedViewLevels()) . '))';
@@ -81,27 +81,27 @@ class plgYSearchContent extends YSearchPlugin
 				c.title,
 				concat(coalesce(c.introtext, ''), coalesce(c.`fulltext`, '')) AS description,
 				CASE
-					WHEN s.name OR ca.name OR c.alias THEN
+					WHEN s.alias!='' OR ca.alias!='' OR c.alias!='' THEN 
 						concat(
-							CASE WHEN s.name THEN concat('/', s.name) ELSE '' END,
-							CASE WHEN ca.name AND ca.name != s.name THEN concat('/', ca.name) ELSE '' END,
-							CASE WHEN c.alias THEN concat('/', c.alias) ELSE '' END
+							CASE WHEN s.alias!='' THEN concat('/', s.alias) ELSE '' END, 
+							CASE WHEN ca.alias!='' AND ca.alias != s.alias THEN concat('/', ca.alias) ELSE '' END, 
+							CASE WHEN c.alias!='' AND c.alias != ca.alias THEN concat('/', c.alias) ELSE '' END
 						)
-					ELSE concat('index.php?option=com_content&view=article&id=', c.id) 
+					ELSE concat('/content/article/', c.id) 
 				END AS link,
 				$weight AS weight,
 				publish_up AS date,
 				ca.title AS section,
-				(SELECT group_concat(u1.name separator '\\n') FROM #__author_assoc anames INNER JOIN #__xprofiles u1 ON u1.uidNumber = anames.authorid WHERE subtable = 'content' AND subid = c.id ORDER BY anames.ordering) AS contributors,
-				(SELECT group_concat(ids.authorid separator '\\n') FROM #__author_assoc ids WHERE subtable = 'content' AND subid = c.id ORDER BY ids.ordering) AS contributor_ids
-			FROM #__content c 
-			LEFT JOIN #__sections s 
+				(SELECT group_concat(u1.name separator '\\n') FROM jos_author_assoc anames INNER JOIN jos_xprofiles u1 ON u1.uidNumber = anames.authorid WHERE subtable = 'content' AND subid = c.id ORDER BY anames.ordering) AS contributors,
+				(SELECT group_concat(ids.authorid separator '\\n') FROM jos_author_assoc ids WHERE subtable = 'content' AND subid = c.id ORDER BY ids.ordering) AS contributor_ids
+			FROM jos_content c 
+			LEFT JOIN jos_sections s 
 				ON s.id = c.sectionid
-			LEFT JOIN #__categories ca
+			LEFT JOIN jos_categories ca
 				ON ca.id = c.catid
 			WHERE 
 				state = 1 AND 
-				(publish_up AND UTC_TIMESTAMP() > publish_up) AND (NOT publish_down OR UTC_TIMESTAMP() < publish_down) 
+				(publish_up AND NOW() > publish_up) AND (NOT publish_down OR NOW() < publish_down) 
 				AND $weight > 0".
 				($addtl_where ? ' AND ' . join(' AND ', $addtl_where) : '') .
 			" ORDER BY $weight DESC";
@@ -117,19 +117,19 @@ class plgYSearchContent extends YSearchPlugin
 							CASE WHEN ca.alias THEN concat('/', ca.alias) ELSE '' END, 
 							CASE WHEN c.alias THEN concat('/', c.alias) ELSE '' END
 						)
-					ELSE concat('index.php?option=com_content&view=article&id=', c.id) 
+					ELSE concat('/content/article/', c.id) 
 				END AS link,
 				$weight AS weight,
 				publish_up AS date,
 				ca.title AS section,
-				(SELECT group_concat(u1.name separator '\\n') FROM #__author_assoc anames INNER JOIN #__xprofiles u1 ON u1.uidNumber = anames.authorid WHERE subtable = 'content' AND subid = c.id ORDER BY anames.ordering) AS contributors,
-				(SELECT group_concat(ids.authorid separator '\\n') FROM #__author_assoc ids WHERE subtable = 'content' AND subid = c.id ORDER BY ids.ordering) AS contributor_ids
-			FROM #__content c 
-			LEFT JOIN #__categories ca
+				(SELECT group_concat(u1.name separator '\\n') FROM jos_author_assoc anames INNER JOIN jos_xprofiles u1 ON u1.uidNumber = anames.authorid WHERE subtable = 'content' AND subid = c.id ORDER BY anames.ordering) AS contributors,
+				(SELECT group_concat(ids.authorid separator '\\n') FROM jos_author_assoc ids WHERE subtable = 'content' AND subid = c.id ORDER BY ids.ordering) AS contributor_ids
+			FROM jos_content c 
+			LEFT JOIN jos_categories ca
 				ON ca.id = c.catid
 			WHERE 
 				state = 1 AND 
-				(publish_up AND UTC_TIMESTAMP() > publish_up) AND (NOT publish_down OR UTC_TIMESTAMP() < publish_down) 
+				(publish_up AND NOW() > publish_up) AND (NOT publish_down OR NOW() < publish_down) 
 				AND $weight > 0".
 				($addtl_where ? ' AND ' . join(' AND ', $addtl_where) : '') .
 			" ORDER BY $weight DESC";
